import java.text.SimpleDateFormat
import java.util.Date

plugins {
    alias(libs.plugins.android.application)
    alias(libs.plugins.kotlin.android)
    alias(libs.plugins.kotlin.compose)
    alias(libs.plugins.devtools.ksp)
    id("kotlin-kapt")
    id("com.google.dagger.hilt.android")
    id("kotlinx-serialization")
}

android {
    namespace = "com.ubsidifinance"
    compileSdk = 35

    defaultConfig {
        applicationId = "com.ubsidifinance"
        minSdk = 24
        targetSdk = 35
        versionCode = 1
        versionName = "1.0"

        testInstrumentationRunner = "androidx.test.runner.AndroidJUnitRunner"
    }

    buildTypes {
        release {
            isMinifyEnabled = true
            isShrinkResources = true
            proguardFiles(
                getDefaultProguardFile("proguard-android-optimize.txt"),
                "proguard-rules.pro"
            )
            buildConfigField(
                "String",
                "stripe_publishkeyTest",
                "\"pk_test_AdQkfvDPjhh5OBqmlJ5DGCub\""
            )
            buildConfigField(
                "String",
                "connect_stripe_private_key",
                "\"sk_test_51IrrKlIa6rlUIwjlxnhay21q1Ka4CXSEvHJbvoDepvsp3xJG98f13nmYzbMbrPpAc8iE7jmKBqQ3fpWMJKOJi3LZ00nBGPxq1J\""
            )
            buildConfigField(
                "String",
                "stripe_publishkey",
                "\"sk_test_51IrrKlIa6rlUIwjlxnhay21q1Ka4CXSEvHJbvoDepvsp3xJG98f13nmYzbMbrPpAc8iE7jmKBqQ3fpWMJKOJi3LZ00nBGPxq1J\""
            )
            buildConfigField(
                "String",
                "connect_stripe_public_key",
                "\"pk_test_51IrrKlIa6rlUIwjl9je80bHmFyIfIB6a236GR5JqGpUdX1NVvtPGgBO0LmUnMn0ggjpHmDlUTYFz8jr6VMN2YrxZ00SSRruIEe\""
            )
            buildConfigField("String", "aes_iv", "\"v@XI!kaW3BK,@8ki\"")
            buildConfigField("String", "aes_key", "\"Kp+O[BZFh;31#&hvw.nj,Z!j0{h6!QFn\"")
        }

        debug {
            android.buildFeatures.buildConfig = true
            resValue("string", "PORT_NUMBER", "8085")
            resValue("string", "maps_api_key", "AIzaSyCkQ3cXzENbHUcwV7y-cGbLeX_aJ32PLYw")
            buildConfigField(
                "String",
                "stripe_publishkeyTest",
                "\"pk_test_AdQkfvDPjhh5OBqmlJ5DGCub\""
            )
            buildConfigField(
                "String",
                "connect_stripe_private_key",
                "\"sk_test_51IrrKlIa6rlUIwjlxnhay21q1Ka4CXSEvHJbvoDepvsp3xJG98f13nmYzbMbrPpAc8iE7jmKBqQ3fpWMJKOJi3LZ00nBGPxq1J\""
            )
            buildConfigField(
                "String",
                "stripe_publishkey",
                "\"sk_test_51IrrKlIa6rlUIwjlxnhay21q1Ka4CXSEvHJbvoDepvsp3xJG98f13nmYzbMbrPpAc8iE7jmKBqQ3fpWMJKOJi3LZ00nBGPxq1J\""
            )
            buildConfigField(
                "String",
                "connect_stripe_public_key",
                "\"pk_test_51IrrKlIa6rlUIwjl9je80bHmFyIfIB6a236GR5JqGpUdX1NVvtPGgBO0LmUnMn0ggjpHmDlUTYFz8jr6VMN2YrxZ00SSRruIEe\""
            )
            buildConfigField("String", "aes_iv", "\"v@XI!kaW3BK,@8ki\"")
            buildConfigField("String", "aes_key", "\"Kp+O[BZFh;31#&hvw.nj,Z!j0{h6!QFn\"")
        }

        android {
            applicationVariants.all {
                outputs.all {
                    if (this is com.android.build.gradle.internal.api.ApkVariantOutputImpl) {
                        val formattedDate = SimpleDateFormat("d-M-yyyy_HH-mm").format(Date())
                        val baseName = buildType.name.firstOrNull() ?: 'X'
                        val appName = "Finance"
                        outputFileName =
                            "$appName-${baseName}-v${versionCode}_${versionName}-$formattedDate.apk"
                    }
                }

            }
        }

    }
    compileOptions {
        sourceCompatibility = JavaVersion.VERSION_11
        targetCompatibility = JavaVersion.VERSION_11
    }
    kotlinOptions {
        jvmTarget = "11"
    }
    buildFeatures {
        compose = true
    }
}

dependencies {

    implementation(libs.androidx.core.ktx)
    implementation(libs.androidx.lifecycle.runtime.ktx)
    implementation(libs.androidx.activity.compose)
    implementation(platform(libs.androidx.compose.bom))
    implementation(libs.androidx.ui)
    implementation(libs.androidx.ui.graphics)
    implementation(libs.androidx.ui.tooling.preview)
    implementation(libs.androidx.material3)
    testImplementation(libs.junit)
    androidTestImplementation(libs.androidx.junit)
    androidTestImplementation(libs.androidx.espresso.core)
    androidTestImplementation(platform(libs.androidx.compose.bom))
    androidTestImplementation(libs.androidx.ui.test.junit4)
    debugImplementation(libs.androidx.ui.tooling)
    debugImplementation(libs.androidx.ui.test.manifest)
    implementation("androidx.appcompat:appcompat:1.7.0")

    //navigation
    implementation(libs.androidx.navigation.compose)
    implementation(libs.androidx.lifecycle.viewmodel.compose)

    //Gson
    implementation(libs.gson)
    implementation(libs.kotlinx.serialization.json)

    //Coil
    implementation(libs.coil.compose)
    implementation(libs.coil.gif)
    implementation(libs.coil.network.okhttp)

    // Biometric
    implementation(libs.androidx.biometric)

    // Camera || ML Kit
    implementation(libs.androidx.camera.lifecycle)
    implementation(libs.androidx.camera.view)
    implementation(libs.androidx.camera.mlkit.vision)
    implementation(libs.androidx.camera.camera2)
    implementation(libs.face.detection)

    //Calendar
    implementation("com.kizitonwose.calendar:compose:2.6.2")

    // retrofit
    implementation(libs.retrofit)
    implementation(libs.logging.interceptor)
    implementation(libs.retrofit2.gson)
    implementation("com.airbnb.android:lottie-compose:6.6.6")
    implementation("com.jakewharton.retrofit:retrofit2-kotlinx-serialization-converter:1.0.0")

    //hilt
    implementation(libs.androidx.hilt.navigation.compose)
    implementation(libs.hilt.android)
    ksp(libs.hilt.android.compiler)

    //Phone
    implementation(libs.libPhoneNumber)

}