package com.ubsidifinance.base

import com.ubsidifinance.utils.parseError
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow
import kotlinx.coroutines.flow.flowOn
import retrofit2.Response

sealed class ApiResult<out T> {
    data object Loading : ApiResult<Nothing>()
    data class Success<T>(val data: T) : ApiResult<T>()
    data class Error(val message: String) : ApiResult<Nothing>()
}

inline fun <T> safeApiFlow(
    crossinline apiCall: suspend () -> Response<T>
): Flow<ApiResult<T>> = flow {
    emit(ApiResult.Loading)
    try {
        val response = apiCall()
        if (response.isSuccessful) {
            emit(ApiResult.Success(response.body()!!))
        } else {
            val error = response.errorBody()?.parseError()
            emit(ApiResult.Error(error?.message ?: "Unknown error"))
        }
    } catch (e: Exception) {
        e.printStackTrace()
        emit(ApiResult.Error(e.message ?: "Unknown error"))
    }
}.flowOn(Dispatchers.IO)
