package com.ubsidifinance.base

import androidx.compose.foundation.layout.ColumnScope
import androidx.compose.foundation.layout.navigationBarsPadding
import androidx.compose.foundation.layout.statusBarsPadding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.ModalBottomSheet
import androidx.compose.material3.ModalBottomSheetDefaults
import androidx.compose.material3.ModalBottomSheetProperties
import androidx.compose.material3.SheetState
import androidx.compose.material3.rememberModalBottomSheetState
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Shape
import androidx.compose.ui.unit.dp

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun BaseBottomSheetDialog(
    modifier: Modifier = Modifier,
    onDismiss: () -> Unit,
    shape: Shape = RoundedCornerShape(topEnd = 24.dp, topStart = 24.dp),
    properties: ModalBottomSheetProperties = ModalBottomSheetDefaults.properties(),
    sheetState: SheetState = rememberModalBottomSheetState(skipPartiallyExpanded = true),
    content: @Composable (ColumnScope.() -> Unit)
) {

    ModalBottomSheet(
        onDismissRequest = onDismiss, sheetState = sheetState,
        modifier = modifier
            .statusBarsPadding()
            .navigationBarsPadding(),
        dragHandle = null,
        properties = properties,
        shape = shape,
        containerColor = MaterialTheme.colorScheme.background,
        content = content
    )
}
