package com.ubsidifinance.base

import android.content.Context
import android.os.Bundle
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.consumeWindowInsets
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.fragment.app.FragmentActivity
import androidx.navigation.compose.rememberNavController
import com.ubsidifinance.dailog.SnackBarPopup
import com.ubsidifinance.navigation.NavHost
import com.ubsidifinance.network.WifiService
import com.ubsidifinance.ui.theme.UbsidiFinanceTheme
import dagger.hilt.android.AndroidEntryPoint
import javax.inject.Inject

@AndroidEntryPoint
class MainActivity : FragmentActivity() {
    @Inject
    lateinit var wifiService: WifiService
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            UbsidiFinanceTheme {
                val controller = rememberNavController()
                val hostController = rememberNavController()
                val isOnline by wifiService.connectivityStatus.collectAsState(initial = false)

                if (!isOnline) {
                    SnackBarPopup(
                        message = "Internet is not available",
                        duration = Long.MAX_VALUE,
                        isError = true,
                        isShowCancelButton = false
                    )
                }

                Scaffold(
                    containerColor = MaterialTheme.colorScheme.background,
                    modifier = Modifier
                        .fillMaxSize()
                ) { innerPadding ->
                    NavHost(
                        navHostController = hostController,
                        navController = controller,
                        modifier = Modifier
                            .padding(innerPadding)
                            .consumeWindowInsets(innerPadding)
                    )
                }
            }
        }
    }

    override fun attachBaseContext(newBase: Context?) {
        if (newBase!!.resources!!.configuration.screenWidthDp < 375) {
            newBase.resources?.configuration?.fontScale = 0.85f
        } else {
            newBase.resources?.configuration?.fontScale = 0.9f
        }
        super.attachBaseContext(newBase)
    }
}
