package com.ubsidifinance.component

import androidx.compose.foundation.background
import androidx.compose.foundation.horizontalScroll
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.RowScope
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalDensity
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.ui.theme.grey_757575
import com.ubsidifinance.ui.theme.grey_B3B3B3

private val defaultMaxHeight = 150.dp

@Composable
internal fun BarChart(
    modifier: Modifier = Modifier,
    values: List<Float>,
    maxHeight: Dp = defaultMaxHeight
) {

    assert(values.isNotEmpty()) { "Input values are empty" }

    val borderColor = MaterialTheme.colorScheme.primary
    val density = LocalDensity.current
    val strokeWidth = with(density) { 1.dp.toPx() }

    val scrollState = rememberScrollState()
    Row(
        modifier = modifier.then(
            Modifier
                .fillMaxWidth()
                .horizontalScroll(scrollState)

                .height(maxHeight)

        ),
        horizontalArrangement = Arrangement.Start,
        verticalAlignment = Alignment.Bottom
    ) {
        values.forEachIndexed { i, item ->
            Bar(
                list[i],
                value = item,
                color = grey_B3B3B3,
                maxHeight = maxHeight
            )
        }
    }
}

@Composable
private fun RowScope.Bar(
    title: String,
    value: Float,
    color: Color,
    maxHeight: Dp
) {

    val itemHeight = remember(value) { value * maxHeight.value / 100 }

    Column(modifier = Modifier.weight(1f), horizontalAlignment = Alignment.CenterHorizontally) {
        Spacer(
            modifier = Modifier
                .padding(horizontal = 3.dp)
                .height(itemHeight.dp)
                .fillMaxWidth()
                .background(color, RoundedCornerShape(8.dp))
        )

        TextComponent(
            text = title,
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            fontSize = 14.sp,
            color = grey_757575,
            modifier = Modifier.padding(top = 12.dp)
        )
    }
}

val list = listOf("Jan", "Feb", "Mar", "Apr", "May", "Jun")
