package com.ubsidifinance.component

import androidx.annotation.DrawableRes
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ElevatedButton
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextFieldDefaults
import androidx.compose.material3.Switch
import androidx.compose.material3.SwitchDefaults
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldColors
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.focus.FocusRequester
import androidx.compose.ui.focus.focusRequester
import androidx.compose.ui.focus.onFocusChanged
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Shape
import androidx.compose.ui.graphics.SolidColor
import androidx.compose.ui.graphics.painter.Painter
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.platform.LocalSoftwareKeyboardController
import androidx.compose.ui.platform.SoftwareKeyboardController
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.TextUnit
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import coil3.compose.AsyncImage
import coil3.gif.GifDecoder
import coil3.request.ImageRequest
import com.ubsidifinance.R
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.green_27A376
import com.ubsidifinance.ui.theme.grey_B3B3B3
import com.ubsidifinance.ui.theme.grey_CBD5E0
import com.ubsidifinance.ui.theme.grey_D9D9D9
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.ui.theme.grey_e3e3e3
import com.ubsidifinance.ui.theme.red_900B09
import com.ubsidifinance.ui.theme.red_E22D57
import com.ubsidifinance.ui.theme.transparent
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.toNonNullString


@Composable
fun TextComponent(
    modifier: Modifier = Modifier,
    text: String?,
    color: Color = Color.Unspecified,
    fontFamily: FontFamily? = null,
    fontSize: TextUnit = TextUnit.Unspecified,
    style: TextStyle = TextStyle(),
    fontWeight: FontWeight? = null,
    maxLines: Int = Int.MAX_VALUE
) {

    Text(
        text = text.toNonNullString(),
        fontWeight = fontWeight,
        fontSize = fontSize,
        style = style,
        color = color,
        maxLines = maxLines,
        modifier = modifier,
        fontFamily = fontFamily
    )

}

@Composable
fun RequiredTextLabelComponent(
    modifier: Modifier = Modifier,
    text: String?,
    color: Color = Color.Unspecified,
    fontFamily: FontFamily? = null,
    fontSize: TextUnit = TextUnit.Unspecified,
    style: TextStyle = TextStyle(),
    fontWeight: FontWeight? = null,
    maxLines: Int = Int.MAX_VALUE
) {

    Row(verticalAlignment = Alignment.CenterVertically) {
        Text(
            text = text.toNonNullString(),
            fontWeight = fontWeight,
            fontSize = fontSize,
            style = style,
            color = color,
            maxLines = maxLines,
            modifier = modifier,
            fontFamily = fontFamily
        )

        Text(
            text = " *",
            fontWeight = fontWeight,
            fontSize = fontSize,
            style = style,
            color = red_E22D57,
            maxLines = maxLines,
            modifier = modifier,
            fontFamily = fontFamily
        )
    }
}


@Composable
fun HorizontalDividerComponent(
    modifier: Modifier = Modifier,
    thickness: Dp = 0.3.dp,
    color: Color = grey_D9D9D9
) {
    HorizontalDivider(
        modifier = modifier,
        thickness = thickness,
        color = color
    )

}

@Composable
fun IconButtonComponent(
    onClick: () -> Unit,
    modifier: Modifier = Modifier,
    painter: Painter,
    borderColor: Color = Color.Unspecified,
    shape: Shape = RoundedCornerShape(40.dp),
    color: Color = Color.Unspecified,
) {
    Box(
        modifier = modifier
            .clip(shape)
            .border(1.dp, borderColor, shape)
            .clickable(onClick = onClick)
            .background(color)
    ) {
        Image(
            painter = painter,
            contentDescription = null,
            modifier = Modifier.padding(horizontal = 30.dp, vertical = 15.dp)
        )
    }
}

@Composable
fun TextFieldComponent(
    modifier: Modifier = Modifier,
    newModifier: Modifier = Modifier,
    value: String,
    placeholder: String = "",
    singleLine: Boolean = true,
    readOnly: Boolean = false,
    maxLines: Int = if (singleLine) 1 else Int.MAX_VALUE,
    minLines: Int = 1,
    isError: Boolean = false,
    keyboardActions: KeyboardActions = KeyboardActions(),
    shape: Shape = MaterialTheme.shapes.extraSmall,
    suffix: @Composable (() -> Unit)? = null,
    focusable: Boolean = false,
    border: Boolean = true,
    backgroundColor: Color = Color.Unspecified,
    focusRequester: FocusRequester = FocusRequester(),
    prefix: @Composable (() -> Unit)? = null,
    visualTransformation: VisualTransformation = VisualTransformation.None,
    textStyle: TextStyle = MaterialTheme.typography.bodySmall.copy(color = MaterialTheme.colorScheme.secondary),
    keyboardOptions: KeyboardOptions = KeyboardOptions(
        keyboardType = KeyboardType.Text,
        imeAction = ImeAction.Next
    ),
    colors: TextFieldColors = OutlinedTextFieldDefaults.colors(
        focusedBorderColor = MaterialTheme.colorScheme.primary,
        unfocusedBorderColor = grey_D9D9D9,
//        unfocusedContainerColor = MaterialTheme.colorScheme.primaryContainer,
//        focusedContainerColor = MaterialTheme.colorScheme.primaryContainer,
    ),
    onValueChange: (String) -> Unit
) {
    var isFocused by remember { mutableStateOf(focusable) }
    val borderColor = when {
        isError -> Color.Red
        isFocused -> MaterialTheme.colorScheme.primary
        else -> grey_D9D9D9
    }

    BasicTextField(
        value = value,
        visualTransformation = visualTransformation,
        textStyle = textStyle,
        onValueChange = onValueChange,
        maxLines = maxLines,
        minLines = minLines,
        readOnly = readOnly,
        singleLine = singleLine,
        cursorBrush = SolidColor(blue316AFF),
        keyboardActions = keyboardActions,
        keyboardOptions = keyboardOptions,
        modifier = newModifier
            .fillMaxWidth()
            .padding(top = 6.dp)
            .border(
                width = if (border) 1.dp else 0.dp,
                color = if (border) borderColor else transparent,
                shape = shape
            )
            .background(backgroundColor, shape)
            .focusRequester(focusRequester)
            .onFocusChanged {
                isFocused = it.isFocused
            }
            .padding(horizontal = 12.dp, vertical = 14.dp),
        decorationBox = { innerTextField ->
            Row(verticalAlignment = Alignment.CenterVertically) {
                prefix?.invoke()
                Box(
                    modifier = Modifier
                        .weight(1F)
                        .padding(horizontal = 10.dp)
                ) {
                    if (value.isEmpty()) {
                        TextComponent(
                            text = placeholder,
                            fontSize = 14.sp,
                            color = grey_B3B3B3,
                            fontFamily = FontFamily(
                                Font(
                                    R.font.inter_medium,
                                    FontWeight.W600
                                )
                            )
                        )
                    }
                    innerTextField()
                }
                suffix?.invoke()
            }
        }
    )
}

@Composable
fun ButtonComponent(
    modifier: Modifier = Modifier,
    text: String?,
    enable: Boolean = true,
    onClick: () -> Unit,
    colors: ButtonColors = ButtonDefaults.buttonColors(
        containerColor = MaterialTheme.colorScheme.primary,
        contentColor = Color.White,
        disabledContentColor = grey_B3B3B3,
        disabledContainerColor = MaterialTheme.colorScheme.onSurfaceVariant
    ),
) {
    ElevatedButton(
        onClick = onClick,
        enabled = enable,
        colors = colors,
        contentPadding = PaddingValues(horizontal = 16.dp, vertical = 16.dp),
        shape = RoundedCornerShape(14.dp),
        modifier = modifier
    ) {
        TextComponent(
            text = text,
            modifier = Modifier.fillMaxWidth(),
            style = TextStyle(
                fontSize = 16.sp,
                textAlign = TextAlign.Center,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W500))
            ),
        )
    }
}

@Composable
fun SwitchComponent(
    modifier: Modifier = Modifier,
    checked: Boolean,
    onCheckChange: (Boolean) -> Unit
) {

    Switch(
        colors = SwitchDefaults.colors(
            checkedTrackColor = green_27A376,
            checkedThumbColor = transparent,
            uncheckedTrackColor = grey_CBD5E0,
            uncheckedThumbColor = grey_e3e3e3,
            uncheckedBorderColor = transparent
        ),
        checked = checked,
        thumbContent = {
            Icon(
                tint = if (checked) green_27A376 else grey_CBD5E0,
                painter = painterResource(if (checked) R.drawable.ic_check else R.drawable.ic_horizontal_line),
                contentDescription = "",
                modifier = modifier
                    .background(white, CircleShape)
                    .size(22.dp)
                    .padding(5.dp)
            )
        },
        onCheckedChange = onCheckChange
    )

}

@Composable
fun OTPTextField(
    modifier: Modifier = Modifier,
    focusRequester: FocusRequester = FocusRequester(),
    isError: Boolean = false,
    taxDigitLength: Int = 4,
    onOtpSubmit: (String) -> Unit
) {
    var otpCode by remember {
        mutableStateOf("")
    }
    val sfocusRequester = remember { focusRequester }

    BasicTextField(
        value = otpCode,
        modifier = modifier.focusRequester(sfocusRequester),
        onValueChange = {
            if (it.length <= taxDigitLength) {
                otpCode = it
                onOtpSubmit.invoke(otpCode)
            }
        },
        keyboardOptions = KeyboardOptions(
            keyboardType = KeyboardType.NumberPassword,
            imeAction = ImeAction.Done
        )
    ) {
        Row(
            horizontalArrangement = Arrangement.Center,
            modifier = modifier
                .fillMaxWidth()
                .padding(top = 24.dp)
        ) {
            repeat(taxDigitLength) { index ->
                val number = when {
                    index >= otpCode.length -> ""
                    else -> otpCode[index].toString()
                }
                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = modifier
                        .weight(1f)
                        .padding(end = 8.dp)
                ) {

                    Box(
                        modifier = if ((otpCode.isEmpty() && index == 0) || index == otpCode.length) {
                            modifier
                                .height(54.dp)
                                .fillMaxWidth()
                                .border(
                                    1.dp,
                                    MaterialTheme.colorScheme.primary,
                                    RoundedCornerShape(10.dp)
                                )
                                .padding(1.dp)
                                .clip(RoundedCornerShape(10.dp))

                        } else if (isError) {
                            modifier
                                .height(54.dp)
                                .fillMaxWidth()
                                .padding(1.dp)
                                .border(
                                    1.dp,
                                    red_900B09,
                                    RoundedCornerShape(10.dp)
                                )
                                .clip(RoundedCornerShape(10.dp))
                        } else {
                            modifier
                                .height(54.dp)
                                .fillMaxWidth()
                                .padding(1.dp)
                                .border(
                                    1.dp,
                                    MaterialTheme.colorScheme.surfaceContainerLow,
                                    RoundedCornerShape(10.dp)
                                )
                                .clip(RoundedCornerShape(10.dp))
                        }, contentAlignment = Alignment.Center
                    ) {

                        Text(
                            text = if (number != "") number else "0",
                            fontSize = 14.sp,
                            color = if (number != "") MaterialTheme.colorScheme.inversePrimary else MaterialTheme.colorScheme.scrim,
                            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500)),
                        )

                    }

                    Spacer(modifier = modifier.padding(start = 10.dp))
                }
            }
        }
    }
}


@Composable
fun DrawableGifView(@DrawableRes resId: Int, modifier: Modifier = Modifier) {
    val context = LocalContext.current
    val gifUri = remember(resId) {
        "android.resource://${context.packageName}/$resId"
    }

    AsyncImage(
        model = ImageRequest.Builder(context)
            .data(gifUri)
            .decoderFactory(GifDecoder.Factory())
            .build(),
        contentDescription = "GIF from drawable",
        contentScale = ContentScale.Fit,
        modifier = modifier
    )
}

@Composable
fun IndicatorComponent(
    modifier: Modifier = Modifier,
    totalSize: Int = 0,
    selectedIndex: Int = 0,
    selectColor: Color = blue316AFF,
    unSelectColor: Color = grey_D9D9D9,
) {
    Row(
        horizontalArrangement = Arrangement.Center,
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
    ) {
        repeat(totalSize) {
            Box(
                modifier = Modifier
                    .width(if (it != selectedIndex) 6.dp else 18.dp)
                    .height(6.dp)
                    .border(
                        width = 6.dp,
                        color = if (it != selectedIndex) unSelectColor else selectColor,
                        shape = if (it != selectedIndex) CircleShape else RoundedCornerShape(
                            3.dp
                        )
                    )
            )
            Spacer(modifier = Modifier.padding(start = 6.dp))
        }
    }
}

@Composable
fun ActionBarWithBackButton(
    modifier: Modifier = Modifier,
    onBack: () -> Unit = {},
    isVisibleBack: Boolean = true,
    title: String? = null
) {
    Box(
        modifier
            .fillMaxWidth()
            .height(48.dp), contentAlignment = Alignment.CenterStart
    ) {
        if (isVisibleBack) {
            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = Modifier
                    .clip(CircleShape)
                    .clickable(onClick = onBack)
                    .size(24.dp)
                    .padding(5.dp),
                tint = MaterialTheme.colorScheme.inversePrimary
            )
        }

        TextComponent(
            text = title,
            modifier = modifier.align(Alignment.Center),
            color = MaterialTheme.colorScheme.inversePrimary,
            fontSize = 22.sp,
            fontFamily = FontFamily(
                Font(R.font.inter_bold, FontWeight.W600)
            )
        )
    }
}

@Composable
fun keyboardController(): SoftwareKeyboardController? {
    return LocalSoftwareKeyboardController.current
}
