package com.ubsidifinance.component

import androidx.compose.animation.core.animateFloatAsState
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.ProgressIndicatorDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableFloatStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.StrokeCap
import androidx.compose.ui.unit.dp
import com.ubsidifinance.ui.theme.blue316AFF
import kotlinx.coroutines.delay
import kotlinx.coroutines.isActive
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ProgressIndicatorDefaults.drawStopIndicator
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.draw.clip
import com.ubsidifinance.ui.theme.transparent

@Composable
fun HeaderProgress(
    modifier: Modifier = Modifier,
    currentPage: Int = 1,
    totalPage: Int = 12
) {
    val mProgress = if (currentPage != 1) (currentPage - 1).toFloat() / totalPage.toFloat() else 0f
    var progress by rememberSaveable { mutableFloatStateOf(mProgress) }
    val toProgress by remember { mutableFloatStateOf(currentPage.toFloat() / totalPage.toFloat()) }

    val animatedProgress by animateFloatAsState(
        targetValue = progress,
        animationSpec = ProgressIndicatorDefaults.ProgressAnimationSpec,
        label = ""
    )

    Column(modifier = modifier.fillMaxWidth()) {

        LaunchedEffect(key1 = Unit) {
            delay(400)
            while (progress < toProgress && isActive) {
                progress += 0.01f
            }
        }

        Box(
            modifier = Modifier
                .fillMaxWidth()
                .height(6.dp)
                .clip(RoundedCornerShape(50))
                .background(MaterialTheme.colorScheme.surfaceContainerLow)
        ) {
            LinearProgressIndicator(
                progress = { animatedProgress },
                color = blue316AFF,
                trackColor = Color.Transparent,
                strokeCap = StrokeCap.Round,
                modifier = Modifier.fillMaxSize()
            ){
                drawStopIndicator(
                    drawScope = this,
                    stopSize = 0.dp,
                    color = transparent,
                    strokeCap = StrokeCap.Round
                )
            }
        }
    }
}
