package com.ubsidifinance.component


import androidx.compose.foundation.clickable
import androidx.compose.foundation.gestures.awaitEachGesture
import androidx.compose.foundation.gestures.awaitFirstDown
import androidx.compose.foundation.gestures.waitForUpOrCancellation
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.input.pointer.PointerEventPass
import androidx.compose.ui.input.pointer.pointerInput
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.tooling.preview.PreviewLightDark
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R

@PreviewLightDark
@Preview(showSystemUi = true)
@Composable
fun LabelWithTextFieldPreview() {

}

@Composable
fun LabelWithTextField(
    modifier: Modifier = Modifier,
    label: String,
    placeHolder: String = "",
    value: String,
    readOnly: Boolean = false,
    visualTransformation: VisualTransformation = VisualTransformation.None,
    suffix: @Composable (() -> Unit)? = null,
    onValueChange: (String) -> Unit,
    onClick: () -> Unit = {},
    keyboardOptions: KeyboardOptions = KeyboardOptions(
        keyboardType = KeyboardType.Text,
        imeAction = ImeAction.Next
    )
) {

    if(label.isNotEmpty()){
        TextComponent(
            text = label,
            fontSize = 14.sp,
            color = MaterialTheme.colorScheme.secondary,
            modifier = modifier,
            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
        )
    }

    TextFieldComponent(
        modifier = Modifier
            .fillMaxWidth()
            .padding(top = 6.dp)
            .pointerInput(value){
                awaitEachGesture {
                    awaitFirstDown(pass = PointerEventPass.Initial)
                    val upEvent = waitForUpOrCancellation(pass = PointerEventPass.Initial)
                    if (upEvent != null) {
                        onClick.invoke()
//                        showModal = true
                    }
                }
            },
        placeholder = placeHolder,
        value = value,
        readOnly = readOnly,
        keyboardOptions = keyboardOptions,
        onValueChange = onValueChange,
        suffix = suffix,
        visualTransformation = visualTransformation
    )

}