package com.ubsidifinance.component

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R

@Composable
fun PasswordRulesChecklist(password: String) {
    val rules = listOf(
        "6-20 characters" to (password.length in 6..20),
        "Includes numbers, lowercase letters" to (password.any { it.isDigit() } && password.any { it.isLowerCase() }),
        "No spaces" to (!password.contains(" ")),
        "Do not duplicate login name" to (!password.equals(
            "loginname",
            ignoreCase = true
        )) // replace with actual login
    )

    Column(
        modifier = Modifier
            .padding(vertical = 12.dp, horizontal = 2.dp)
    ) {
        rules.forEach { (text, isValid) ->
            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = Modifier.padding(vertical = 10.dp)
            ) {
                Icon(
                    painter = painterResource(R.drawable.ic_badges),
                    contentDescription = null,
                    tint = if (isValid) Color(0xFF4CAF50) else Color.Gray,
                    modifier = Modifier.size(5.dp)
                )
                Spacer(modifier = Modifier.width(8.dp))
                TextComponent(
                    text = text,
                    color = if (isValid) MaterialTheme.colorScheme.onSecondary else Color.Gray,
                    fontSize = 16.sp
                )
            }
        }
    }
}
