package com.ubsidifinance.component

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import androidx.navigation.NavDestination.Companion.hasRoute
import androidx.navigation.NavDestination.Companion.hierarchy
import androidx.navigation.compose.currentBackStackEntryAsState
import com.ubsidifinance.R
import com.ubsidifinance.navigation.CardNavigation
import com.ubsidifinance.navigation.Home
import com.ubsidifinance.navigation.Profile
import com.ubsidifinance.navigation.Transactions
import com.ubsidifinance.utils.TabTransferType

@Composable
fun BottomNavigationBar(
    navController: NavController,
) {

    val navBackStackEntry = navController.currentBackStackEntryAsState()
    val currentDestination = navBackStackEntry.value?.destination

    val items = listOf(
        R.drawable.ic_home,
        R.drawable.ic_chart,
        R.drawable.ic_card,
        R.drawable.ic_user
    )

    val routes = listOf(
        Home,
        Transactions(type = TabTransferType),
        CardNavigation,
        Profile
    )

    val labels = listOf("Home", "Stats", "Cards", "Profile")

    Surface(
        shape = RoundedCornerShape(topStart = 24.dp, topEnd = 24.dp),
        color = MaterialTheme.colorScheme.primaryContainer,
        tonalElevation = 4.dp,
        shadowElevation = 20.dp,
        modifier = Modifier
            .fillMaxWidth()

    ) {
        Box(
            modifier = Modifier
                .padding(16.dp)
        ) {
            Surface(
                modifier = Modifier
                    .fillMaxWidth()
                    .height(64.dp),
                shape = RoundedCornerShape(20.dp),
                color = MaterialTheme.colorScheme.onPrimaryContainer,
                shadowElevation = 0.dp
            ) {
                Row(
                    horizontalArrangement = Arrangement.SpaceAround,
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = Modifier.fillMaxSize()
                ) {
                    items.forEachIndexed { index, icon ->
                        IconButton(onClick = {
                            navController.navigate(routes[index]) {
                                navController.graph.startDestinationRoute?.let { route ->
                                    popUpTo(route) {
                                        saveState = true
                                    }
                                }
                                restoreState = true
                                launchSingleTop = true
                            }
                        }) {
                            Icon(
                                modifier = Modifier.size(24.dp),
                                painter = painterResource(icon),
                                contentDescription = labels[index],
                                tint = if (currentDestination?.hierarchy?.any { it.hasRoute(routes[index]::class) } == true) MaterialTheme.colorScheme.onSecondary else MaterialTheme.colorScheme.scrim
                            )
                        }
                    }
                }
            }
        }
    }
}
