package com.ubsidifinance.dailog

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Card
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.Dialog
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.CountryModel
import com.ubsidifinance.model.state.MobileNumberUiState
import com.ubsidifinance.ui.register.mobile.PhoneNumberViewmodel

@Composable
fun CountryDialog(
    modifier: Modifier = Modifier,
    viewmodel: PhoneNumberViewmodel,
    onDismissRequest: () -> Unit,
) {

    val state = viewmodel.uiEvent.value

    Dialog(onDismissRequest = onDismissRequest) {

        Card(
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp),
            shape = RoundedCornerShape(16.dp),
        ) {
            Column(
                modifier = modifier
                    .background(MaterialTheme.colorScheme.background)
                    .padding(32.dp)
            ) {

                TextComponent(
                    text = "Select Country",
                    color = MaterialTheme.colorScheme.secondary,
                    modifier = modifier.padding(bottom = 12.dp),
                    fontSize = 24.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_bold, FontWeight.W500)
                    )
                )

                TextFieldComponent(
                    value = state.countrySearch,
                    placeholder = "Search",
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Search
                    ),
                    modifier = modifier.padding(vertical = 24.dp)
                ) { value ->
                    viewmodel.onEvent(MobileNumberUiState.OnCountryValueChange(value))
                }

                LazyColumn {
                    items(
                        state.filterCountryList,
                        key = { item -> item.code }) { item ->
                        CountryRowItem(model = item, onClick = {
                            viewmodel.onEvent(MobileNumberUiState.OnChangeSelectedCountry(item))
                            onDismissRequest.invoke()
                        })
                    }
                }

            }
        }

    }

}

@Composable
fun CountryRowItem(
    modifier: Modifier = Modifier,
    onClick: () -> Unit,
    model: CountryModel
) {

    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .clickable(onClick = onClick)
            .padding(vertical = 8.dp)
    ) {
        TextComponent(
            text = model.flag,
            fontSize = 24.sp,
        )

        TextComponent(
            text = "${model.name} (${model.code})",
            modifier = modifier
                .padding(horizontal = 10.dp)
                .weight(1f),
            fontSize = 14.sp,
            color = MaterialTheme.colorScheme.secondary,
            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
        )

        TextComponent(
            text = model.dial_code,
            modifier = modifier
                .padding(horizontal = 10.dp),
            fontSize = 14.sp,
            color = MaterialTheme.colorScheme.secondary,
            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
        )

    }

}