package com.ubsidifinance.dailog

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Card
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.Dialog
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.state.MobileNumberUiState
import com.ubsidifinance.ui.forget_password.mobile_number.ForgetPasswordMobileNumberViewmodel

@Composable
fun CountryDialogForgetPassword(
    navController: NavController,
    modifier: Modifier = Modifier,
    viewmodel: ForgetPasswordMobileNumberViewmodel,
    onDismissRequest: () -> Unit,
) {

    val state = viewmodel.uiEvent.value

    Dialog(onDismissRequest = onDismissRequest) {

        Card(
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp),
            shape = RoundedCornerShape(16.dp),
        ) {
            Column(
                modifier = modifier
                    .background(MaterialTheme.colorScheme.background)
                    .padding(32.dp)
            ) {

                Row(verticalAlignment = Alignment.CenterVertically) {
                    TextComponent(
                        text = "Select Country",
                        color = MaterialTheme.colorScheme.secondary,
                        modifier = modifier.padding(),
                        fontSize = 24.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_bold, FontWeight.W500)
                        )
                    )
                    Spacer(modifier = modifier.weight(1F))
                    Icon(
                        painter = painterResource(R.drawable.ic_close),
                        contentDescription = null,
                        tint = MaterialTheme.colorScheme.secondary,
                        modifier = modifier
                            .clickable {
                                onDismissRequest.invoke()
                            }
                    )
                }

                TextFieldComponent(
                    value = state.countrySearch,
                    placeholder = "Search",
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Search
                    ),
                    modifier = modifier.padding(vertical = 24.dp)
                ) { value ->
                    viewmodel.onEvent(MobileNumberUiState.OnCountryValueChange(value))
                }

                LazyColumn {
                    items(
                        state.filterCountryList,
                        key = { item -> item.code }) { item ->
                        CountryRowItem(model = item, onClick = {
                            viewmodel.onEvent(MobileNumberUiState.OnChangeSelectedCountry(item))
                            onDismissRequest.invoke()
                        })
                    }
                }

            }
        }

    }

}