package com.ubsidifinance.dailog

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Card
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.Dialog
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent

@Composable
fun CustomAlertDialog(
    modifier: Modifier = Modifier,
    text: String? = null,
    title: String? = null,
    onDismissRequest: () -> Unit,
    onConfirmation: () -> Unit,
) {
    Dialog(onDismissRequest = onDismissRequest) {

        Card(
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp),
            shape = RoundedCornerShape(16.dp),
        ) {
            Column(
                modifier = modifier
                    .background(MaterialTheme.colorScheme.background)
                    .padding(32.dp)
            ) {

                if (!title.isNullOrEmpty()) {
                    TextComponent(
                        text = title.toString(),
                        color = MaterialTheme.colorScheme.secondary,
                        modifier = modifier.padding(bottom = 12.dp),
                        fontSize = 24.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_bold, FontWeight.W500)
                        )
                    )
                }

                TextComponent(
                    text = text.toString(),
                    modifier = modifier.padding(bottom = 24.dp),
                    color = MaterialTheme.colorScheme.secondary,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_regular, FontWeight.W500)
                    )
                )

                ButtonComponent(
                    text = "Ok",
                    onClick = {
                        onDismissRequest.invoke()
                        onConfirmation.invoke()
                    })
            }
        }

    }

}