package com.ubsidifinance.dailog

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.OnboardingModel
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.utils.constListOfMenu

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MoreMenuDialog(
    modifier: Modifier = Modifier,
    onDismissRequest: () -> Unit,
    onConfirmRequest: () -> Unit,
) {

    val interaction = remember { MutableInteractionSource() }
    val listOfMenu = remember { mutableStateListOf<OnboardingModel>() }
    listOfMenu.apply {
        clear()
        addAll(constListOfMenu)
    }

    BaseBottomSheetDialog(onDismiss = onDismissRequest) {
        Column(modifier = modifier.padding(32.dp)) {

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .fillMaxWidth()
                    .padding(bottom = 24.dp),
                horizontalArrangement = Arrangement.SpaceBetween
            ) {
                TextComponent(
                    text = "Quick Actions",
                    fontSize = 22.sp,
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    color = MaterialTheme.colorScheme.surface
                )

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = "Close Button",
                    modifier = modifier
                        .clip(CircleShape)
                        .clickable(
                            indication = null,
                            interactionSource = interaction,
                            onClick = onDismissRequest
                        )
                        .size(20.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )
            }

            LazyVerticalGrid(
                columns = GridCells.Fixed(4),
                verticalArrangement = Arrangement.spacedBy(22.dp)
            ) {
                items(listOfMenu) { item ->
                    RowMenuItem(model = item, onClick = {
                        onDismissRequest.invoke()
                        onConfirmRequest.invoke()
                    })
                }
            }
        }
    }
}

@Composable
fun RowMenuItem(
    modifier: Modifier = Modifier,
    model: OnboardingModel,
    onClick: () -> Unit
) {
    val interactionSource = remember { MutableInteractionSource() }
    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = modifier.clickable(
            onClick = onClick,
            indication = null,
            interactionSource = interactionSource
        )
    ) {
        Icon(
            painter = painterResource(model.image),
            contentDescription = null,
            tint = blue316AFF,
            modifier = Modifier
                .size(44.dp)
                .clip(CircleShape)
                .rotate(model.rotation)
                .background(grey_F9F9F9, CircleShape)
                .padding(12.dp)
        )

        TextComponent(
            text = model.descriptions,
            style = TextStyle(
                fontSize = 12.sp,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                color = MaterialTheme.colorScheme.inversePrimary,
                textAlign = TextAlign.Center
            ),
            modifier = modifier.padding(top = 8.dp),
        )
    }
}