package com.ubsidifinance.dailog

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.Icon
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.Popup
import androidx.compose.ui.window.PopupProperties
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.white
import kotlinx.coroutines.delay

@Composable
fun SnackBarPopup(
    modifier: Modifier = Modifier,
    message: String = "",
    duration: Long = 5000,
    isError: Boolean = false,
    isShowCancelButton: Boolean = true,
    onDismiss: () -> Unit = {}
) {
    var isShowPopup by remember { mutableStateOf(true) }

    LaunchedEffect(isShowPopup) {
        delay(duration)
        isShowPopup = false
        onDismiss.invoke()
    }

    if (isShowPopup) {
        Popup(
            properties = PopupProperties(
                focusable = false,
                dismissOnBackPress = false,
                dismissOnClickOutside = false,
                excludeFromSystemGesture = true,
            )
        ) {

            Box(
                modifier = modifier
                    .fillMaxWidth()
                    .background(blue316AFF)
                    .padding(horizontal = 24.dp, vertical = 13.dp),
                contentAlignment = Alignment.TopStart
            ) {

                Row(verticalAlignment = Alignment.CenterVertically) {

                    if (!isError) {
                        Icon(
                            painter = painterResource(R.drawable.ic_check_circle),
                            contentDescription = null,
                            modifier = Modifier
                                .size(24.dp)
                                .padding(4.dp),
                            tint = white
                        )
                    } else {
                        Icon(
                            painter = painterResource(R.drawable.ic_close),
                            contentDescription = null,
                            modifier = Modifier
                                .padding(5.dp)
                                .border(1.dp, white, CircleShape)
                                .size(14.dp)
                                .padding(4.dp),
                            tint = white
                        )
                    }

                    TextComponent(
                        text = message,
                        fontSize = 12.sp,
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        color = white,
                        modifier = modifier
                            .padding(horizontal = 12.dp)
                            .weight(1f)
                    )

                    if (isShowCancelButton) {
                        Icon(
                            painter = painterResource(R.drawable.ic_close),
                            contentDescription = null,
                            modifier = Modifier
                                .size(24.dp)
                                .padding(6.dp),
                            tint = white
                        )
                    }
                }
            }
        }
    }
}