package com.ubsidifinance.model.state

import androidx.compose.runtime.Immutable

@Immutable
data class LoginState(
    val email: String = "",
    val password: String = "",
    val isVisiblePassword: Boolean = false,
    val isError: Boolean = false,
    val isLoading: Boolean = false,
    val isForgotPassword: Boolean = false,
    val error: String = "Error",
    val title: String = ""
)

sealed class LoginUiState {
    data class OnEmailChange(val text: String) : LoginUiState()
    data class OnPasswordChange(val text: String) : LoginUiState()
    data object OnPasswordVisibilityChange : LoginUiState()
    data object ClickOnSubmit : LoginUiState()
    data class OnError(val isError: Boolean, val title: String = "Error", val error: String = "") :
        LoginUiState()

    data class OnForgotPasswordDialog(val isShow: Boolean) : LoginUiState()
}

sealed class LoginScreenState {
    data class NavigateToNextScreen(val route: String) : LoginScreenState()
}