package com.ubsidifinance.navigation

import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.navigation.NavController
import androidx.navigation.NavHostController
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.toRoute
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.ui.billing_info.BillingInfoScreen
import com.ubsidifinance.ui.card_history.CardHistoryScreen
import com.ubsidifinance.ui.card_report.CardReportScreen
import com.ubsidifinance.ui.card_setting.CardSettingScreen
import com.ubsidifinance.ui.confirm_request.RequestSuccessOrFailScreen
import com.ubsidifinance.ui.confirm_transfer.PaymentSuccessOrFailScreen
import com.ubsidifinance.ui.contact_info.ContactInfoScreen
import com.ubsidifinance.ui.forget_password.mobile_number.ForgetPasswordMobileNumber
import com.ubsidifinance.ui.forget_password.reset_success.ResetPasswordSuccessScreen
import com.ubsidifinance.ui.forget_password.set_new_password.SetNewPasswordScreen
import com.ubsidifinance.ui.forget_password.verify_otp.VerifyOtpScreen
import com.ubsidifinance.ui.home_page.DashboardScreen
import com.ubsidifinance.ui.login.LoginScreen
import com.ubsidifinance.ui.notification.NotificationScreen
import com.ubsidifinance.ui.on_boarding.OnBoardingScreen
import com.ubsidifinance.ui.pin.PinScreen
import com.ubsidifinance.ui.register.business_info.BusinessInfoScreen
import com.ubsidifinance.ui.register.business_type.BusinessTypeScreen
import com.ubsidifinance.ui.register.capture_document.CaptureBackDocumentScreen
import com.ubsidifinance.ui.register.capture_document.CaptureDocumentScreen
import com.ubsidifinance.ui.register.capture_photo.CapturePhotoScreen
import com.ubsidifinance.ui.register.commit.CommitScreen
import com.ubsidifinance.ui.register.director_info.DirectorInfoScreen
import com.ubsidifinance.ui.register.face_recognize.FaceRecognizeScreen
import com.ubsidifinance.ui.register.mobile.PhoneNumberScreen
import com.ubsidifinance.ui.register.preview_document.PreviewDocumentScreen
import com.ubsidifinance.ui.register.register_id.RegisterIdScreen
import com.ubsidifinance.ui.register.select_id.SelectIdScreen
import com.ubsidifinance.ui.register.setup_pin.ConfirmPinScreen
import com.ubsidifinance.ui.register.setup_pin.SetUpPinScreen
import com.ubsidifinance.ui.register.success_register.SuccessRegisterScreen
import com.ubsidifinance.ui.register.verify_document.VerifyDocumentScreen
import com.ubsidifinance.ui.register.verify_mobile.VerifyMobileScreen
import com.ubsidifinance.ui.request_amount.RequestAmountScreen
import com.ubsidifinance.ui.splash.SplashScreen
import com.ubsidifinance.ui.transaction.SearchTransactionScreen
import com.ubsidifinance.ui.transaction_detail.TransactionDetailScreen
import com.ubsidifinance.ui.transfer.TransferScreen
import com.ubsidifinance.utils.businessInfoScreen
import com.ubsidifinance.utils.businessTypeScreen
import com.ubsidifinance.utils.captureBackDocumentScreen
import com.ubsidifinance.utils.captureDocumentScreen
import com.ubsidifinance.utils.capturePhotoScreen
import com.ubsidifinance.utils.confirmPinScreen
import com.ubsidifinance.utils.directorInfoScreen
import com.ubsidifinance.utils.faceRecognizeScreen
import com.ubsidifinance.utils.fromForgetPasswordScreen
import com.ubsidifinance.utils.previewDocumentScreen
import com.ubsidifinance.utils.registerIdScreen
import com.ubsidifinance.utils.selectIdScreen
import com.ubsidifinance.utils.setNewPasswordScreen
import com.ubsidifinance.utils.setUpPinScreen
import com.ubsidifinance.utils.verifyDocumentScreen
import com.ubsidifinance.utils.verifyMobileScreen

@Composable
fun NavHost(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    navHostController: NavController
) {

    NavHost(
        navController = navController,
        startDestination = Screens.Splash.name,
        modifier = modifier,
    ) {
        composable(route = Screens.Splash.name) {
            SplashScreen(navController = navController)
        }

        composable(route = Screens.OnBoarding.name) {
            OnBoardingScreen(navController = navController)
        }

        composable(route = Screens.Login.name) {
            LoginScreen(navController = navController)
        }

        composable(route = Screens.Pin.name) {
            PinScreen(navController = navController)
        }

        composable(route = Screens.RegisterCommit.name) {
            CommitScreen(navController = navController)
        }

        composable(route = Screens.PhoneNumber.name) {
            PhoneNumberScreen(navController = navController)
        }

        composable<RegisterModel> {
            val model = it.toRoute<RegisterModel>()
            if (model.type == verifyMobileScreen) {
                VerifyMobileScreen(navController = navController, registerModel = model)
            } else if (model.type == businessTypeScreen) {
                BusinessTypeScreen(navController = navController, registerModel = model)
            } else if (model.type == businessInfoScreen) {
                BusinessInfoScreen(navController = navController, registerModel = model)
            } else if (model.type == directorInfoScreen) {
                DirectorInfoScreen(navController = navController, registerModel = model)
            } else if (model.type == registerIdScreen) {
                RegisterIdScreen(navController = navController, registerModel = model)
            } else if (model.type == selectIdScreen) {
                SelectIdScreen(navController = navController, registerModel = model)
            } else if (model.type == captureDocumentScreen) {
                CaptureDocumentScreen(navController = navController, registerModel = model)
            } else if (model.type == captureBackDocumentScreen) {
                CaptureBackDocumentScreen(navController = navController, registerModel = model)
            } else if (model.type == previewDocumentScreen) {
                PreviewDocumentScreen(navController = navController, registerModel = model)
            } else if (model.type == faceRecognizeScreen) {
                FaceRecognizeScreen(navController = navController, registerModel = model)
            } else if (model.type == capturePhotoScreen) {
                CapturePhotoScreen(navController = navController, registerModel = model)
            } else if (model.type == verifyDocumentScreen) {
                VerifyDocumentScreen(navController = navController, registerModel = model)
            } else if (model.type == setNewPasswordScreen) {
                SetNewPasswordScreen(navController = navController, registerModel = model)
            } else if (model.type == fromForgetPasswordScreen) {
                VerifyOtpScreen(navController = navController, registerModel = model)
            } else if (model.type == setUpPinScreen) {
                SetUpPinScreen(navController = navController, registerModel = model)
            } else if (model.type == confirmPinScreen) {
                ConfirmPinScreen(navController = navController, registerModel = model)
            } else {
                return@composable
            }
        }

        composable(route = Screens.ForgotPassword.name) {
            ForgetPasswordMobileNumber(navController = navController)
        }

        composable(route = Screens.SuccessRegisterScreen.name) {
            SuccessRegisterScreen(navController = navController)
        }

        composable(route = Screens.ResetPasswordSuccessScreen.name) {
            ResetPasswordSuccessScreen(navController = navController)
        }

        composable(route = Screens.HomePage.name) {
            DashboardScreen(
                navController = navHostController,
                oldGraphNavController = navController
            )
        }

        composable<SearchTransaction> {
            SearchTransactionScreen(navController = navController)
        }

        composable<Notification> {
            NotificationScreen(navController = navController)
        }

        composable<TransactionDetail> {
            TransactionDetailScreen(navController = navController)
        }

        composable<TransferAmount> {
            TransferScreen(navController = navController)
        }

        composable<PaymentSuccessOrFail> {
            PaymentSuccessOrFailScreen(navController = navController)
        }

        composable<RequestAmount> {
            RequestAmountScreen(navController = navController)
        }

        composable<RequestSuccessOrFail> {
            RequestSuccessOrFailScreen(navController = navController)
        }

        composable<CardSetting> {
            CardSettingScreen(navController = navController)
        }

        composable<CardHistory> {
            CardHistoryScreen(navController = navController)
        }

        composable<BillingInfo> {
            BillingInfoScreen(navController = navController)
        }

        composable<ContactInfo> {
            ContactInfoScreen(navController = navController)
        }

        composable<CardReport> {
            CardReportScreen(navController = navController)
        }
    }

}