package com.ubsidifinance.network

import android.util.Log
import com.google.gson.Gson
import com.ubsidifinance.utils.EasyAES
import com.ubsidifinance.utils.Preferences
import com.ubsidifinance.utils.toNonNullString
import okhttp3.Interceptor
import okhttp3.Request
import okhttp3.Response
import okhttp3.ResponseBody
import okhttp3.ResponseBody.Companion.toResponseBody
import java.io.IOException
import javax.inject.Inject

class NetworkInterceptor @Inject constructor(private val preferences: Preferences) :
    Interceptor {
    override fun intercept(chain: Interceptor.Chain): Response {
        val originalRequest: Request = chain.request()
        val tokenRequestBuilder: Request.Builder = originalRequest.newBuilder()

        try {
            // Static headers
            tokenRequestBuilder.addHeader("package-name", "com.ubsidifinance")
            tokenRequestBuilder.addHeader("application_type", "Android")
            tokenRequestBuilder.addHeader("application_type_name", "Central")

            val headers: Map<String?, String?> = preferences.headerTokens

            for ((key, value) in headers) {
                tokenRequestBuilder.header(key!!, value!!)
            }

            var response = chain.proceed(tokenRequestBuilder.build())

            // Capture updated tokens
            val xToken = response.header("x-token")
            val xRefreshToken = response.header("x-refresh-token")

            Log.e("x-token-value", "$xToken")
            Log.e("x-refresh-token-value", "$xRefreshToken")

            if (!xToken.isNullOrBlank() && !xRefreshToken.isNullOrBlank()) {
                preferences.saveHeaderTokens(xToken, xRefreshToken)
            }

            // Handle encryption/decryption
            if (response.code == 200) {
                var encData = response.body?.string().orEmpty()
                Log.e("enc_data", "enc_data $encData")

                try {
                    encData = if (encData.length > 87) {
                        val sb = StringBuilder(encData)
                        sb.replace(0, 15, "")
                        sb.replace(8, 15, "")
                        sb.replace(14, 22, "")
                        sb.replace(22, 28, "")
                        sb.replace(28, 35, "")
                        sb.replace(sb.length - 18, sb.length - 3, "")
                        EasyAES.decryptString(sb.toString()).toNonNullString()
                    } else {
                        EasyAES.decryptString(encData).toNonNullString()
                    }
                } catch (e: Exception) {
                    e.printStackTrace()
                }

                response = response.newBuilder()
                    .body(encData.toResponseBody(response.body?.contentType()))
                    .build()
            }

            return response

        } catch (e: Exception) {
            e.printStackTrace()
            throw IOException(e.message)
        }
    }

}