package com.ubsidifinance.ui.billing_info

import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.BillingInfoUiState
import com.ubsidifinance.ui.select_card.SelectCardScreen
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.black2C2C2C
import com.ubsidifinance.ui.theme.grey_F5F5F5
import com.ubsidifinance.utils.isResume

@Composable
fun BillingInfoScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    viewmodel: BillingInfoViewmodel = hiltViewModel()
) {

    val scrollSate = rememberScrollState()
    val state = viewmodel.uiEvent.value
    var isSelectCardDialog by remember { mutableStateOf(false) }
    val interactionSource = remember { MutableInteractionSource() }

    if (isSelectCardDialog) {
        SelectCardScreen(
            onConfirmRequest = {},
            onDismissRequest = {
                isSelectCardDialog = false
            }
        )
    }

    Scaffold(
        modifier = modifier.padding(horizontal = 24.dp),
        topBar = {
            ActionBarWithBackButton(
                onBack = {
                    if (navController.isResume()) {
                        navController.popBackStack()
                    }
                },
                title = "Billing Information"
            )
        }) { innerPadding ->

        Column(
            modifier
                .padding(innerPadding)
                .fillMaxSize()
                .verticalScroll(scrollSate)
                .padding(bottom = 24.dp, top = 15.dp)
        ) {

            Column(modifier = modifier.weight(1f)) {
                Row(
                    modifier = modifier
                        .fillMaxWidth()
                        .clickable(
                            interactionSource = interactionSource,
                            indication = null,
                            onClick = {
                                isSelectCardDialog = true
                            }),
                    horizontalArrangement = Arrangement.SpaceBetween,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    TextComponent(
                        text = "Select Card",
                        color = MaterialTheme.colorScheme.onSecondary,
                        fontSize = 14.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_semi_bold, FontWeight.W500)
                        )
                    )

                    Row(verticalAlignment = Alignment.CenterVertically) {
                        TextComponent(
                            text = "Jamal Ahmed - 7723",
                            color = MaterialTheme.colorScheme.onSecondary,
                            fontSize = 14.sp,
                            fontFamily = FontFamily(
                                Font(R.font.inter_semi_bold, FontWeight.W500)
                            )
                        )

                        Icon(
                            painter = painterResource(R.drawable.ic_down_arrow),
                            contentDescription = null,
                            tint = MaterialTheme.colorScheme.onSecondary,
                            modifier = modifier
                                .padding(start = 10.dp, top = 2.dp)
                                .size(16.dp)
                                .padding(2.dp)
                                .align(Alignment.CenterVertically)
                        )

                    }

                }

                Spacer(modifier = modifier.height(20.dp))

                TextFieldComponent(
                    placeholder = "First Line of Address",
                    border = false,
                    textStyle = MaterialTheme.typography.bodySmall.copy(color = black2C2C2C),
                    backgroundColor = grey_F5F5F5,
                    value = state.firstLineAddress,
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Next
                    ),
                    onValueChange = {
                        viewmodel.onEvent(BillingInfoUiState.OnFirstLineAddressChange(it))
                    }
                )

                Spacer(modifier = modifier.height(27.dp))

                TextFieldComponent(
                    placeholder = "Apartment, Unit or Other",
                    border = false,
                    textStyle = MaterialTheme.typography.bodySmall.copy(color = black2C2C2C),
                    backgroundColor = grey_F5F5F5,
                    value = state.apartment,
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Next
                    ),
                    onValueChange = {
                        viewmodel.onEvent(BillingInfoUiState.OnApartmentChange(it))
                    }
                )

                Spacer(modifier = modifier.height(27.dp))

                TextFieldComponent(
                    placeholder = "Town or City",
                    border = false,
                    backgroundColor = grey_F5F5F5,
                    textStyle = MaterialTheme.typography.bodySmall.copy(color = black2C2C2C),
                    value = state.city,
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Next
                    ),
                    onValueChange = {
                        viewmodel.onEvent(BillingInfoUiState.OnCityChange(it))
                    }
                )
                Spacer(modifier = modifier.height(27.dp))

                TextFieldComponent(
                    placeholder = "Postcode",
                    border = false,
                    backgroundColor = grey_F5F5F5,
                    textStyle = MaterialTheme.typography.bodySmall.copy(color = black2C2C2C),
                    value = state.posCode,
                    keyboardOptions = KeyboardOptions(
                        keyboardType = KeyboardType.Text,
                        imeAction = ImeAction.Done
                    ),
                    onValueChange = {
                        viewmodel.onEvent(BillingInfoUiState.OnPostCodeChange(it))
                    }
                )
            }

            Row {
                ButtonComponent(
                    text = "Cancel",
                    colors = ButtonDefaults.buttonColors(
                        containerColor = MaterialTheme.colorScheme.surfaceBright,
                        contentColor = black1E1E1E,
                        disabledContentColor = Color.White,
                        disabledContainerColor = MaterialTheme.colorScheme.primary.copy(alpha = 0.5f)
                    ),
                    onClick = {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                    modifier = modifier
                        .weight(1f)
                        .padding(end = 13.dp)
                )

                ButtonComponent(
                    text = "Save",
                    onClick = {
                    },
                    modifier = modifier
                        .weight(1f)
                        .padding(start = 13.dp)
                )
            }

        }
    }
}