package com.ubsidifinance.ui.card

import androidx.compose.animation.core.Animatable
import androidx.compose.animation.core.LinearEasing
import androidx.compose.animation.core.tween
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.Icon
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.ProgressIndicatorDefaults.drawStopIndicator
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.StrokeCap
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.CardDetailModel
import com.ubsidifinance.ui.theme.black232323
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.transparent
import com.ubsidifinance.ui.theme.white

@Composable
fun CardPinView(
    modifier: Modifier = Modifier,
    model: CardDetailModel,
    onCloseClick: () -> Unit,
    onComplete: () -> Unit = {} ) {

    val progress = remember { Animatable(0f) }

    LaunchedEffect(Unit) {
        progress.animateTo(
            targetValue = 1f,
            animationSpec = tween(durationMillis = 30_000, easing = LinearEasing)
        )
        onComplete.invoke()
    }

    Column(
        modifier = modifier
            .padding(24.dp)
            .fillMaxSize(),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Row {
            Column(modifier.weight(1f)) {
                TextComponent(
                    text = "Card holder",
                    color = if (model.isLightCard) black232323 else white.copy(alpha = 0.5f),
                    fontSize = 12.sp,
                    fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
                )

                TextComponent(
                    text = "John Maguire",
                    color = if (model.isLightCard) black232323 else white,
                    fontSize = 24.sp,
                    modifier = modifier.padding(top = 4.dp),
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                )
            }
            Icon(
                painter = painterResource(R.drawable.ic_close),
                contentDescription = "Close Button",
                modifier = modifier
                    .clip(CircleShape)
                    .clickable(
                        onClick = onCloseClick
                    )
                    .size(20.dp)
                    .padding(4.dp),
                tint = white
            )
        }

        Column(modifier = modifier.align(Alignment.CenterHorizontally)) {
            TextComponent(
                text = "Card PIN",
                fontSize = 16.sp,
                modifier = modifier
                    .align(Alignment.CenterHorizontally),
                color = if (model.isLightCard) black232323 else white,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
            )
            TextComponent(
                text = "1 3 1 4",
                color = if (model.isLightCard) black232323 else white,
                fontSize = 32.sp,
                modifier = modifier.padding(top = 4.dp),
                fontFamily = FontFamily(
                    Font(
                        R.font.inter_bold,
                        FontWeight.W700
                    )
                )
            )
        }

        Column {
            TextComponent(
                text = "Time Remaining",
                fontSize = 14.sp,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                color = white,
                modifier = modifier.padding(bottom = 6.dp)
            )

            LinearProgressIndicator(
                progress = {  progress.value  },
                color = blue316AFF,
                trackColor = white,
                gapSize = 0.dp,
                strokeCap = StrokeCap.Square,
                modifier = Modifier,
            ) {
                drawStopIndicator(
                    drawScope = this,
                    stopSize = 0.dp,
                    color = transparent,
                    strokeCap = StrokeCap.Round
                )
            }
        }
    }
}