package com.ubsidifinance.ui.card

import androidx.compose.animation.core.Animatable
import androidx.compose.animation.core.FastOutSlowInEasing
import androidx.compose.animation.core.tween
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.LinearProgressIndicator
import androidx.compose.material3.ProgressIndicatorDefaults.drawStopIndicator
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.blur
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.StrokeCap
import androidx.compose.ui.graphics.graphicsLayer
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.CardDetailModel
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.black232323
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_757575
import com.ubsidifinance.ui.theme.grey_F5F5F5
import com.ubsidifinance.ui.theme.grey_e3e3e3
import com.ubsidifinance.ui.theme.transparent
import com.ubsidifinance.ui.theme.white

@Composable
fun CardTabDetailsRowItem(
    modifier: Modifier = Modifier,
    model: CardDetailModel,
    onUnlockCard: () -> Unit,
    onPinViewChange: () -> Unit,
    onComplete: () -> Unit = {}
) {

    var isFlipped by remember { mutableStateOf(model.isPinVisible) }
    val rotation = remember { Animatable(if (isFlipped) 180f else 0f) }
    val scale = if (rotation.value > 90f) -1f else 1f

    LaunchedEffect(model.isPinVisible) {
        isFlipped = model.isPinVisible
        rotation.animateTo(
            targetValue = if (isFlipped) 180f else 0f,
            animationSpec = tween(durationMillis = 600, easing = FastOutSlowInEasing)
        )
    }

    Column(modifier = modifier.padding(horizontal = 10.dp)) {
        Surface(
            shape = RoundedCornerShape(18.dp),
            color = if (model.isLightCard) white else black232323,
            tonalElevation = 2.dp,
            shadowElevation = 4.dp,
            modifier = Modifier
                .fillMaxWidth()
                .height(320.dp)
                .graphicsLayer {
                    rotationY = rotation.value
                    cameraDistance = 12 * density
                    scaleX = scale
                }
        ) {

            if (model.isPinVisible) {
                CardPinView(model = model, onCloseClick = onPinViewChange, onComplete =onComplete)
            } else {

                Column(
                    modifier
                        .fillMaxWidth()
                        .background(
                            if (model.isLightCard) white else black232323,
                            RoundedCornerShape(18.dp)
                        )
                        .blur(if (model.isCardLocked) 7.dp else 0.dp)
                        .padding(24.dp)
                ) {
                    Column(
                        modifier
                            .weight(1f),
                        verticalArrangement = Arrangement.SpaceBetween,
                    ) {
                        Row(
                            verticalAlignment = Alignment.CenterVertically,
                            horizontalArrangement = Arrangement.Absolute.SpaceBetween,
                            modifier = modifier
                                .fillMaxWidth()
                        ) {
                            Icon(
                                painter = painterResource(R.drawable.ic_visa),
                                contentDescription = "Card Type",
                                modifier = modifier.size(38.dp, 12.dp),
                                tint = if (model.isLightCard) black232323 else white
                                //                        contentScale = ContentScale.Fit
                            )

                            Icon(
                                painter = painterResource(R.drawable.img_ubsidi_logo),
                                contentDescription = "Ubsidi Logo",
                                modifier = modifier.size(65.dp, 25.dp),
                                tint = if (model.isLightCard) black232323 else white
                            )
                        }

                        Column(modifier = modifier.align(Alignment.CenterHorizontally)) {
                            TextComponent(
                                text = "Total balance",
                                fontSize = 12.sp,
                                modifier = modifier
                                    .align(Alignment.CenterHorizontally),
                                color = if (model.isLightCard) black232323 else white,
                                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
                            )
                            TextComponent(
                                text = "£52,432",
                                color = if (model.isLightCard) black232323 else white,
                                fontSize = 24.sp,
                                modifier = modifier.padding(top = 4.dp),
                                fontFamily = FontFamily(
                                    Font(
                                        R.font.inter_semi_bold,
                                        FontWeight.W600
                                    )
                                )
                            )
                        }

                        Spacer(modifier)

                    }

                    TextComponent(
                        text = "Card holder",
                        color = if (model.isLightCard) black232323 else white.copy(alpha = 0.5f),
                        fontSize = 12.sp,
                        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
                    )

                    TextComponent(
                        text = "John Maguire",
                        color = if (model.isLightCard) black232323 else white,
                        fontSize = 24.sp,
                        modifier = modifier.padding(top = 4.dp),
                        fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                    )

                }

                Box(
                    modifier
                        .fillMaxSize()
                        .background(
                            if (model.isLightCard) white.copy(alpha = if (model.isCardLocked) 0.9f else 0f) else black232323.copy(
                                alpha = if (model.isCardLocked) 0.9f else 0f
                            )
                        )
                )

                if (model.isCardLocked) {
                    Box(
                        contentAlignment = Alignment.Center,
                        modifier = modifier
                            .fillMaxSize()
                    ) {

                        Column(
                            horizontalAlignment = Alignment.CenterHorizontally,
                            modifier = modifier
                                .fillMaxWidth()
                                .padding(horizontal = 24.dp)
                        ) {
                            Icon(
                                painter = painterResource(R.drawable.ic_lock),
                                contentDescription = "Close Button",
                                modifier = modifier
                                    .align(Alignment.CenterHorizontally)
                                    .clip(CircleShape)
                                    .clickable(
                                        onClick = {}
                                    )
                                    .size(48.dp)
                                    .background(grey_F5F5F5, CircleShape)
                                    .padding(16.dp),
                                tint = blue316AFF
                            )

                            TextComponent(
                                text = "This card is locked",
                                color = white,
                                fontSize = 12.sp,
                                modifier = modifier
                                    .padding(top = 12.dp)
                                    .background(blue316AFF, RoundedCornerShape(30.dp))
                                    .clip(RoundedCornerShape(30.dp))
                                    .clickable(onClick = onUnlockCard)
                                    .padding(vertical = 6.dp, horizontal = 12.dp),
                                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
                            )

                            TextComponent(
                                text = "All transactions will be declined until you unlock the card.",
                                style = TextStyle(
                                    color = if (model.isLightCard) black232323 else white,
                                    fontSize = 12.sp,
                                    textAlign = TextAlign.Center,
                                    fontFamily = FontFamily(
                                        Font(
                                            R.font.inter_medium,
                                            FontWeight.W500
                                        )
                                    )
                                ),
                                modifier = modifier
                                    .align(Alignment.CenterHorizontally)
                                    .padding(top = 12.dp),

                                )
                        }

                    }
                }
            }

        }

        RemainingPaymentItemRow()
    }
}

@Composable
fun RemainingPaymentItemRow(modifier: Modifier = Modifier) {

    Row(
        modifier = modifier
            .fillMaxWidth()
            .padding(top = 20.dp)
            .background(grey_F5F5F5, RoundedCornerShape(16.dp))
            .padding(
                12.dp
            ),
        verticalAlignment = Alignment.CenterVertically
    ) {
        Image(
            painter = painterResource(R.drawable.img_payment_recap),
            contentDescription = "",
            modifier = modifier.size(37.dp, 20.dp),
            contentScale = ContentScale.Fit
        )

        Column(
            modifier
                .weight(1f)
                .padding(start = 8.dp)
        ) {

            TextComponent(
                text = "Monthly Payment Cap",
                fontSize = 14.sp,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                color = black1E1E1E,
                modifier = modifier.padding(bottom = 4.dp)
            )

            LinearProgressIndicator(
                progress = { 0.5f },
                color = blue316AFF,
                trackColor = grey_e3e3e3,
                gapSize = 0.dp,
                strokeCap = StrokeCap.Round,
                modifier = Modifier,
            ) {
                drawStopIndicator(
                    drawScope = this,
                    stopSize = 0.dp,
                    color = transparent,
                    strokeCap = StrokeCap.Round
                )
            }

            Row(modifier = modifier.padding(top = 4.dp)) {
                TextComponent(
                    text = "Remaining ",
                    fontSize = 14.sp,
                    fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                    color = grey_757575,
                    modifier = modifier
                )
                TextComponent(
                    text = "£500 ",
                    fontSize = 14.sp,
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                    color = black1E1E1E,
                    modifier = modifier
                )
                TextComponent(
                    text = "of ",
                    fontSize = 14.sp,
                    fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                    color = grey_757575,
                    modifier = modifier
                )

                TextComponent(
                    text = "£1000",
                    fontSize = 14.sp,
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                    color = black1E1E1E,
                    modifier = modifier
                )
            }
        }

    }
}