package com.ubsidifinance.ui.card

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.model.CardDetailModel
import com.ubsidifinance.model.CardTabState
import com.ubsidifinance.model.CardTabUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class CardViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(CardTabState())
    val uiEvent = _uiState

    init {
        _uiState.value = _uiState.value.copy(
            listOfCard = getCardList(),
        )
    }

    fun onEvent(event: CardTabUiState) {

        when (event) {

            is CardTabUiState.OnCardLock -> {
                val list = _uiState.value.listOfCard
                val newList =
                    list.map { it.copy(isCardLocked = if (it.id == event.cardDetailModel.id) true else it.isCardLocked) }
                _uiState.value = _uiState.value.copy(listOfCard = newList)
            }

            is CardTabUiState.OnCardUnLock -> {
                val list = _uiState.value.listOfCard
                val newList =
                    list.map { it.copy(isCardLocked = if (it.id == event.cardDetailModel.id) false else it.isCardLocked) }
                _uiState.value = _uiState.value.copy(listOfCard = newList)
            }

            is CardTabUiState.OnPinViewChange -> {
                val list = _uiState.value.listOfCard
                val newList =
                    list.map { it.copy(isPinVisible = if (it.id == event.cardDetailModel.id) event.isVisiblePin else it.isPinVisible) }
                _uiState.value = _uiState.value.copy(listOfCard = newList)
            }
        }

    }

    fun getCardList(): List<CardDetailModel> {
        val list = arrayListOf<CardDetailModel>()

        list.add(
            CardDetailModel(
                id = 1,
                name = "Sachin Patel",
                cardNumber = "**** **** **** 7723",
                expiry = "05/27"
            )
        )

        list.add(
            CardDetailModel(
                id = 2,
                name = "Sachin",
                cardNumber = "**** **** **** 7724",
                expiry = "05/27"
            )
        )

        return list
    }

}