package com.ubsidifinance.ui.card_report

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.withStyle
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.DonutChart
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.select_card.SelectCardScreen
import com.ubsidifinance.ui.theme.black2C2C2C
import com.ubsidifinance.ui.theme.blueAAC4FA
import com.ubsidifinance.ui.theme.green_56B784
import com.ubsidifinance.ui.theme.grey_5A5A5A
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.ui.theme.yellow_F3DC3D
import com.ubsidifinance.utils.isResume

@Composable
fun CardReportScreen(
    modifier: Modifier = Modifier,
    navController: NavController

) {

    val scrollSate = rememberScrollState()
    var isSelectCardDialog by remember { mutableStateOf(false) }
    val interactionSource = remember { MutableInteractionSource() }

    if (isSelectCardDialog) {
        SelectCardScreen(
            onConfirmRequest = {},
            onDismissRequest = {
                isSelectCardDialog = false
            }
        )
    }

    Scaffold(
        modifier = modifier.padding(horizontal = 24.dp),
        topBar = {
            ActionBarWithBackButton(
                onBack = {
                    if (navController.isResume()) {
                        navController.popBackStack()
                    }
                },
                title = "Card Report"
            )
        }) { innerPadding ->

        Column(
            modifier
                .padding(innerPadding)
                .fillMaxSize()
                .verticalScroll(scrollSate)
                .padding(vertical = 24.dp)
        ) {

            Row(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 7.dp)
                    .clickable(interactionSource = interactionSource, indication = null, onClick = {
                        isSelectCardDialog = true
                    }),
                horizontalArrangement = Arrangement.SpaceBetween,
                verticalAlignment = Alignment.CenterVertically
            ) {
                TextComponent(
                    text = "Select Card",
                    color = MaterialTheme.colorScheme.onSecondary,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_semi_bold, FontWeight.W500)
                    )
                )

                Row(verticalAlignment = Alignment.CenterVertically) {
                    TextComponent(
                        text = "Jamal Ahmed - 7723",
                        color = MaterialTheme.colorScheme.onSecondary,
                        fontSize = 14.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_semi_bold, FontWeight.W500)
                        )
                    )

                    Icon(
                        painter = painterResource(R.drawable.ic_down_arrow),
                        contentDescription = null,
                        tint = MaterialTheme.colorScheme.onSecondary,
                        modifier = modifier
                            .padding(start = 10.dp, top = 2.dp)
                            .size(16.dp)
                            .padding(2.dp)
                            .align(Alignment.CenterVertically)
                    )

                }

            }

            TextComponent(
                text = "Insights",
                color = MaterialTheme.colorScheme.surfaceContainerHigh,
                fontSize = 24.sp,
                fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W500)),
                modifier = Modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(top = 20.dp)
            )

            AmountTextComponent(
                text = "1,368",
                modifier = modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(top = 10.dp)
            )

            TextComponent(
                text = "May 2025",
                color = grey_5A5A5A,
                fontSize = 12.sp,
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                modifier = Modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(top = 10.dp)
            )

            Box(
                modifier = modifier
                    .padding(top = 50.dp)
                    .size(250.dp)
                    .align(Alignment.CenterHorizontally),
                contentAlignment = Alignment.Center
            ) {
                DonutChart(
                    modifier = modifier,
                    inputValues = listOf(10f, 30f, 20f), colors = listOf(
                        green_56B784,
                        yellow_F3DC3D,
                        blueAAC4FA
                    )
                )

                TextComponent(
                    text = "£1,368",
                    color = white,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W400)),
                    modifier = modifier
                        .background(black2C2C2C, RoundedCornerShape(7.dp))
                        .padding(horizontal = 10.dp, vertical = 7.dp)
                )
            }

            Row(
                horizontalArrangement = Arrangement.SpaceEvenly,
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 50.dp)
            ) {
                ColorBoxWithText(color = blueAAC4FA, text = "Inventory")

                ColorBoxWithText(color = yellow_F3DC3D, text = "Marketing")
            }


            ColorBoxWithText(
                color = green_56B784,
                text = "Repairs",
                modifier = modifier
                    .padding(top = 17.dp)
                    .align(Alignment.CenterHorizontally)
            )
        }
    }
}

@Composable
fun ColorBoxWithText(
    modifier: Modifier = Modifier,
    color: Color,
    text: String
) {

    Row(verticalAlignment = Alignment.CenterVertically, modifier = modifier) {
        Box(
            modifier = Modifier
                .size(28.dp, 21.dp)
                .background(color = color, RoundedCornerShape(3.dp))
        )

        TextComponent(
            text = text,
            color = MaterialTheme.colorScheme.onSecondary,
            fontSize = 14.sp,
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            modifier = Modifier
                .padding(start = 7.dp)
        )
    }
}

@Composable
fun AmountTextComponent(
    modifier: Modifier = Modifier,
    text: String,
    currency: String = "£"
) {
    Text(
        modifier = modifier,
        text = buildAnnotatedString {
            withStyle(
                style = SpanStyle(
                    color = MaterialTheme.colorScheme.surfaceContainerHigh,
                    fontSize = 21.sp,
                    fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold))
                )
            ) {
                append("$currency ")
            }
            withStyle(
                style = SpanStyle(
                    color = MaterialTheme.colorScheme.surfaceContainerHigh,
                    fontSize = 42.sp,
                    fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold))
                )
            ) {
                append(text)
            }
            withStyle(
                style = SpanStyle(
                    color = MaterialTheme.colorScheme.surfaceContainerHigh,
                    fontSize = 21.sp,
                    fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold))
                )
            ) {
                append(".00")
            }
        },
        fontSize = 18.sp
    )
}