package com.ubsidifinance.ui.category

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.R
import com.ubsidifinance.model.OnboardingModel
import com.ubsidifinance.model.state.CategoryState
import com.ubsidifinance.model.state.CategoryUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class CategoryViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(CategoryState())
    val uiEvent = _uiState

    init {
        _uiState.value = _uiState.value.copy(
            listOfCategory = getCategoryList(),
            listOfCategoryOriginal = getCategoryList()
        )
    }

    fun onEvent(event: CategoryUiState) {
        when (event) {
            is CategoryUiState.OnSearchChangeValue -> {
                filterList(event.text)
            }
        }
    }

    private fun filterList(search: String) {

        val list =
            _uiState.value.listOfCategoryOriginal.filter { it.title.contains(search, true) }

        _uiState.value = _uiState.value.copy(listOfCategory = list, searchText = search)

    }

    fun getCategoryList(): List<OnboardingModel> {
        val list = arrayListOf<OnboardingModel>()

        list.add(OnboardingModel(1, title = "Admin", image = R.drawable.ic_cat_user))
        list.add(OnboardingModel(2, title = "Bank Charges", image = R.drawable.ic_cat_bank_charge))
        list.add(OnboardingModel(3, title = "Director’s Wages", image = R.drawable.ic_cat_director))
        list.add(
            OnboardingModel(
                4,
                title = "Entertainment",
                image = R.drawable.ic_cat_entertainment
            )
        )
        list.add(OnboardingModel(5, title = "Equipment", image = R.drawable.ic_cat_home))
        list.add(OnboardingModel(6, title = "Food & Drink", image = R.drawable.ic_cat_food_drink))
        list.add(OnboardingModel(7, title = "Interest Payments", image = R.drawable.ic_cat_user))
        list.add(
            OnboardingModel(
                8,
                title = "Inventory/Stock",
                image = R.drawable.ic_cat_bank_charge
            )
        )
        list.add(OnboardingModel(9, title = "Marketing", image = R.drawable.ic_cat_director))
        list.add(OnboardingModel(10, title = "Other", image = R.drawable.ic_cat_entertainment))
        list.add(OnboardingModel(11, title = "Phone & Internet", image = R.drawable.ic_cat_home))
        list.add(
            OnboardingModel(
                12,
                title = "Professional Services",
                image = R.drawable.ic_cat_food_drink
            )
        )
        list.add(
            OnboardingModel(
                13,
                title = "Repairs & Maintenance",
                image = R.drawable.ic_cat_user
            )
        )
        list.add(OnboardingModel(14, title = "Staff", image = R.drawable.ic_cat_bank_charge))
        list.add(OnboardingModel(15, title = "Travel", image = R.drawable.ic_cat_director))
        list.add(OnboardingModel(16, title = "Vehicles", image = R.drawable.ic_cat_entertainment))
        list.add(OnboardingModel(17, title = "Workplace", image = R.drawable.ic_cat_home))
        list.add(
            OnboardingModel(
                18,
                title = "Investment Capital",
                image = R.drawable.ic_cat_food_drink
            )
        )
        list.add(
            OnboardingModel(
                19,
                title = "Loan Principal (In & Out)",
                image = R.drawable.ic_cat_food_drink
            )
        )
        list.add(OnboardingModel(20, title = "Transfers", image = R.drawable.ic_cat_user))
        list.add(OnboardingModel(21, title = "Dividends", image = R.drawable.ic_cat_bank_charge))
        list.add(OnboardingModel(22, title = "Personal", image = R.drawable.ic_cat_director))
        list.add(
            OnboardingModel(
                23,
                title = "Corporation Tax",
                image = R.drawable.ic_cat_entertainment
            )
        )
        list.add(OnboardingModel(24, title = "VAT", image = R.drawable.ic_cat_home))
        list.add(
            OnboardingModel(
                25,
                title = "Client Refunds",
                image = R.drawable.ic_cat_food_drink
            )
        )

        return list
    }

}