package com.ubsidifinance.ui.confirm_request

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.blue383A48
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.pink_EEBED3
import com.ubsidifinance.ui.theme.yellow_F3DC3D
import com.ubsidifinance.utils.isResume
import kotlin.random.Random

@Composable
fun RequestSuccessOrFailScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    isSuccess: Boolean = Random.nextBoolean()
) {

    Column(modifier = modifier.padding(24.dp)) {
        Column(
            modifier = modifier
                .fillMaxWidth()
                .weight(1f),
            verticalArrangement = Arrangement.Center,
            horizontalAlignment = Alignment.CenterHorizontally
        ) {
            Icon(
                tint = blue383A48,
                painter = painterResource(if (isSuccess) R.drawable.ic_check else R.drawable.ic_close),
                contentDescription = "Document Check",
                modifier = modifier
                    .align(Alignment.CenterHorizontally)
                    .background(if (isSuccess) yellow_F3DC3D else pink_EEBED3, CircleShape)
                    .clip(CircleShape)
                    .border(0.8.dp, blue383A48, CircleShape)
                    .padding(16.dp)
                    .size(40.dp)
                    .padding(if (isSuccess) 0.dp else 10.dp)
            )

            TextComponent(
                text = if (isSuccess) "Your request was successful!" else "Request failed!",
                modifier = modifier.padding(top = 24.dp),
                style = TextStyle(
                    textAlign = TextAlign.Center,
                    color = MaterialTheme.colorScheme.onSecondary,
                    fontSize = 32.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_bold, FontWeight.W700)
                    )
                )
            )

            TextComponent(
                text = if (isSuccess) "Request was successful! Don't forget to check your request details again." else "The request failed, check your internet connection, if failure still occurs, please contact Support.",
                modifier = modifier.padding(top = 8.dp),
                style = TextStyle(
                    color = grey_9499A5,
                    textAlign = TextAlign.Center,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_regular, FontWeight.W400)
                    )
                )
            )


        }

        ButtonComponent(
            text = if (isSuccess) "Request Details" else "Try Again",
            modifier = modifier.padding(top = 10.dp),
            onClick = {

            },
            colors = ButtonDefaults.buttonColors(
                containerColor = MaterialTheme.colorScheme.surfaceBright,
                contentColor = black1E1E1E,
                disabledContentColor = Color.White,
                disabledContainerColor = MaterialTheme.colorScheme.primary.copy(alpha = 0.5f)
            )
        )

        ButtonComponent(
            modifier = modifier.padding(top = 16.dp),
            text = "Home",
            onClick = {
                if (navController.isResume()) {
                    navController.popBackStack()
                }
            }
        )

    }

}