package com.ubsidifinance.ui.confirm_transfer

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.blue316AFF

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ConfirmTransferScreen(
    modifier: Modifier = Modifier,
    onDismissRequest: () -> Unit,
    onConfirmation: () -> Unit,
) {

    val scrollState = rememberScrollState()


    BaseBottomSheetDialog(onDismiss = onDismissRequest) {

        Column(
            modifier = modifier
                .padding(24.dp)
                .fillMaxWidth()
        ) {

            HorizontalDividerComponent(
                thickness = 6.dp, modifier = modifier
                    .width(50.dp)
                    .clip(CircleShape)
                    .align(Alignment.CenterHorizontally)
            )

            Row(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp),
                verticalAlignment = Alignment.CenterVertically,
            ) {

                Icon(
                    painter = painterResource(R.drawable.ic_back_arrow),
                    contentDescription = null,
                    modifier = Modifier
                        .clip(CircleShape)
                        .clickable(onClick = onDismissRequest)
                        .size(24.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )

                TextComponent(
                    text = "Confirm Transfer",
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    modifier = modifier
                        .weight(1f)
                        .padding(horizontal = 12.dp),
                    fontSize = 18.sp,
                    color = MaterialTheme.colorScheme.surfaceDim
                )

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = null,
                    modifier = Modifier
                        .clip(CircleShape)
                        .clickable(onClick = onDismissRequest)
                        .size(24.dp)
                        .padding(7.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )

            }

            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .weight(1f, false)
                    .verticalScroll(scrollState)
            ) {

                TextComponent(
                    text = "Amount:£500",
                    modifier = modifier.padding(top = 24.dp),
                    color = MaterialTheme.colorScheme.inversePrimary,
                    fontSize = 24.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_bold, FontWeight.W700)
                    )
                )

                TextComponent(
                    text = "From",
                    modifier = modifier.padding(top = 24.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W400)
                    )
                )

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = modifier
                        .padding(vertical = 8.dp)
                ) {

                    Image(
                        painter = painterResource(R.drawable.img_app_logo),
                        contentDescription = "",
                        modifier = modifier
                            .size(38.dp)
                            .background(blue316AFF, CircleShape)
                            .padding(2.dp)
                    )

                    Column(
                        modifier = modifier
                            .weight(1f)
                            .padding(start = 8.dp)
                    ) {

                        TextComponent(
                            text = "Nibs Solutions Ltd",
                            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                            modifier = modifier,
                            fontSize = 16.sp,
                            color = MaterialTheme.colorScheme.inversePrimary
                        )

                        TextComponent(
                            text = "Sort Code: 20-23-23",
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                            modifier = modifier
                                .padding(top = 6.dp),
                            fontSize = 14.sp,
                            color = MaterialTheme.colorScheme.inverseOnSurface
                        )

                        TextComponent(
                            text = "Account Number: 24455423",
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                            modifier = modifier
                                .padding(top = 6.dp),
                            fontSize = 14.sp,
                            color = MaterialTheme.colorScheme.inverseOnSurface
                        )
                    }

                }

                TextComponent(
                    text = "To",
                    modifier = modifier.padding(top = 24.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W400)
                    )
                )

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = modifier
                        .padding(vertical = 8.dp)
                ) {
                    Image(
                        painter = painterResource(R.drawable.img_nationwide_bank),
                        contentDescription = null,
                        modifier = modifier
                            .size(44.dp)
                            .clip(CircleShape)
                            .clickable {

                            },
                    )

                    Column(
                        modifier = modifier
                            .weight(1f)
                            .padding(start = 8.dp)
                    ) {

                        TextComponent(
                            text = "Mikasa Ackerman",
                            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                            modifier = modifier,
                            fontSize = 16.sp,
                            color = MaterialTheme.colorScheme.inversePrimary
                        )

                        TextComponent(
                            text = "Sort Code: 20-23-23",
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                            modifier = modifier
                                .padding(top = 6.dp),
                            fontSize = 14.sp,
                            color = MaterialTheme.colorScheme.inverseOnSurface
                        )

                        TextComponent(
                            text = "Account Number: 24455423",
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                            modifier = modifier
                                .padding(top = 6.dp),
                            fontSize = 14.sp,
                            color = MaterialTheme.colorScheme.inverseOnSurface
                        )
                    }

                }

                HorizontalDividerComponent(
                    modifier = modifier.padding(top = 12.dp),
                    thickness = 1.dp
                )

                TextComponent(
                    text = "Date",
                    modifier = modifier.padding(top = 8.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W400)
                    )
                )

                TextComponent(
                    text = "3 February 2024",
                    modifier = modifier.padding(top = 8.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_semi_bold, FontWeight.W600)
                    )
                )

                TextComponent(
                    text = "Transaction Fee",
                    modifier = modifier.padding(top = 16.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W400)
                    )
                )

                TextComponent(
                    text = "GBP 0.00",
                    modifier = modifier.padding(top = 8.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_semi_bold, FontWeight.W600)
                    )
                )

                TextComponent(
                    text = "Reference",
                    modifier = modifier.padding(top = 16.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W400)
                    )
                )

                TextComponent(
                    text = "Friday’s dinner",
                    modifier = modifier.padding(top = 8.dp),
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_semi_bold, FontWeight.W600)
                    )
                )

            }

            ButtonComponent(
                text = "Confirm and Transfer",
                modifier = modifier.padding(top = 30.dp),
                onClick = {
                    onDismissRequest.invoke()
                    onConfirmation.invoke()

                }
            )

        }
    }

}