package com.ubsidifinance.ui.confirm_transfer

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.blue383A48
import com.ubsidifinance.ui.theme.greyB7BAC3
import com.ubsidifinance.ui.theme.pink_EEBED3
import com.ubsidifinance.ui.theme.yellow_F3DC3D
import com.ubsidifinance.utils.isResume
import kotlin.random.Random

@Composable
fun PaymentSuccessOrFailScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    isSuccess: Boolean = Random.nextBoolean()
) {

    val scrollState = rememberScrollState()

    Column(modifier = modifier.padding(24.dp)) {

        Column(
            modifier = modifier
                .weight(1f)
                .fillMaxWidth()
                .verticalScroll(scrollState)
                .padding(bottom = 24.dp)
        ) {

            Icon(
                tint = blue383A48,
                painter = painterResource(if (isSuccess) R.drawable.ic_check else R.drawable.ic_close),
                contentDescription = "Document Check",
                modifier = modifier
                    .padding(top = 24.dp)
                    .align(Alignment.Start)
                    .background(if (isSuccess) yellow_F3DC3D else pink_EEBED3, CircleShape)
                    .clip(CircleShape)
                    .border(0.8.dp, blue383A48, CircleShape)
                    .padding(16.dp)
                    .size(40.dp)
                    .padding(if (isSuccess) 0.dp else 10.dp)
            )

            TextComponent(
                text = if (isSuccess) "Transfer successful" else "Transfer failed",
                color = MaterialTheme.colorScheme.onSecondary,
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_bold, FontWeight.W500)
                )
            )

            Row(
                modifier = modifier.padding(top = 10.dp, bottom = 24.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                TextComponent(
                    text = "£",
                    fontSize = 40.sp,
                    color = greyB7BAC3,
                    fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W700))
                )

                TextComponent(
                    text = "500",
                    fontSize = 40.sp,
                    color = MaterialTheme.colorScheme.onSecondary,
                    fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W700))
                )

            }


            TextComponent(
                text = "Receiver",
                modifier = modifier,
                color = MaterialTheme.colorScheme.scrim,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "Mikasa Ackerman",
                modifier = modifier.padding(top = 4.dp),
                color = MaterialTheme.colorScheme.onSecondary,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_semi_bold, FontWeight.W600)
                )
            )

            TextComponent(
                text = "Sort Code: 20-29-29",
                modifier = modifier.padding(top = 4.dp),
                color = MaterialTheme.colorScheme.inverseOnSurface,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "Account Number: 512311928",
                modifier = modifier.padding(top = 4.dp),
                color = MaterialTheme.colorScheme.inverseOnSurface,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "Receiving bank",
                modifier = modifier.padding(top = 12.dp),
                color = MaterialTheme.colorScheme.scrim,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            Row(
                modifier = modifier.padding(top = 4.dp),
                verticalAlignment = Alignment.CenterVertically
            ) {
                Image(
                    painter = painterResource(R.drawable.img_nationwide_bank),
                    contentDescription = null,
                    modifier = modifier
                        .size(24.dp)
                        .clip(CircleShape),
                )

                TextComponent(
                    text = "Nationwide Bank",
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    modifier = modifier.padding(horizontal = 8.dp),
                    fontSize = 16.sp,
                    color = MaterialTheme.colorScheme.onSecondary
                )
            }

            TextComponent(
                text = "Reference",
                modifier = modifier.padding(top = 12.dp),
                color = MaterialTheme.colorScheme.scrim,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "Friday’s dinner",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 4.dp),
                fontSize = 16.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )
            TextComponent(
                text = "Transaction date",
                modifier = modifier.padding(top = 12.dp),
                color = MaterialTheme.colorScheme.scrim,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "12 May 2024, 9:31 AM",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 4.dp),
                fontSize = 16.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Transaction ID",
                modifier = modifier.padding(top = 12.dp),
                color = MaterialTheme.colorScheme.scrim,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W400)
                )
            )

            TextComponent(
                text = "1OS91739101032887117",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 4.dp),
                fontSize = 16.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

        }

        ButtonComponent(
            text = if (isSuccess) "Share PDF" else "Try Again",
            modifier = modifier.padding(top = 10.dp),
            onClick = {

            },
            colors = ButtonDefaults.buttonColors(
                containerColor = MaterialTheme.colorScheme.surfaceBright,
                contentColor = black1E1E1E,
                disabledContentColor = Color.White,
                disabledContainerColor = MaterialTheme.colorScheme.primary.copy(alpha = 0.5f)
            )
        )

        ButtonComponent(
            modifier = modifier.padding(top = 24.dp),
            text = "Home",
            onClick = {
                if (navController.isResume()) {
                    navController.popBackStack()
                }
            }
        )
    }

}