package com.ubsidifinance.ui.forget_password.mobile_number

import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.imePadding
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.dailog.CountryDialog
import com.ubsidifinance.dailog.CountryDialogForgetPassword
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.LoginUiState
import com.ubsidifinance.model.state.MobileNumberUiState
import com.ubsidifinance.ui.theme.grey_B3B3B3
import com.ubsidifinance.ui.theme.red_900B09
import com.ubsidifinance.utils.fromForgetPasswordScreen
import com.ubsidifinance.utils.getExampleMobileNumber
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.verifyMobileScreen

@Composable
fun ForgetPasswordMobileNumber(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    forgetPasswordMobileNumberViewmodel: ForgetPasswordMobileNumberViewmodel = hiltViewModel()
) {
    val context = LocalContext.current
    val state = forgetPasswordMobileNumberViewmodel.uiEvent.value
    if (state.showCountryPicker) {
        CountryDialogForgetPassword(
            navController = navController,
            viewmodel = forgetPasswordMobileNumberViewmodel,
            onDismissRequest = {
                forgetPasswordMobileNumberViewmodel.onEvent(
                    MobileNumberUiState.OnShowCountryDialog(
                        false
                    )
                )
            })
    }
    LaunchedEffect(Unit) {
        forgetPasswordMobileNumberViewmodel.fetchCountry(context)
    }
    Column(modifier = modifier
        .imePadding()
        .padding(24.dp)) {
        Icon(
            painter = painterResource(R.drawable.ic_back_arrow),
            contentDescription = null,
            modifier = modifier
                .padding(top = 12.dp)
                .size(18.dp)
                .clickable {
                    if (navController.isResume()) {
                        navController.popBackStack()
                    }
                },
            tint = MaterialTheme.colorScheme.inversePrimary
        )

        TextComponent(
            text = stringResource(R.string.password_recovery), fontFamily = FontFamily(
                Font(
                    R.font.inter_semi_bold,
                    FontWeight.W600
                ),
            ),
            modifier = modifier.padding(top = 26.dp),
            fontSize = 24.sp,
            color = MaterialTheme.colorScheme.onSecondary
        )

        TextComponent(
            text = stringResource(R.string.password_recovery_subtitle),
            fontSize = 16.sp,
            modifier = modifier.padding(top = 8.dp),
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            color = MaterialTheme.colorScheme.inverseOnSurface
        )

        BasicTextField(
            value = state.mobileNo,
            onValueChange = {
                forgetPasswordMobileNumberViewmodel.onEvent(
                    MobileNumberUiState.OnNumberChange(
                        it.filter { txt -> txt.isDigit() }
                    ))
                forgetPasswordMobileNumberViewmodel.onEvent(
                    MobileNumberUiState.OnError(
                        it.isEmpty(), error = "Please enter mobile number"
                    )
                )
            },
            keyboardActions = KeyboardActions(),
            keyboardOptions = KeyboardOptions(
                imeAction = ImeAction.Done,
                keyboardType = KeyboardType.Number
            ),
            visualTransformation = VisualTransformation.None,
            singleLine = true,
            textStyle = TextStyle(
                fontSize = 14.sp,
                color = MaterialTheme.colorScheme.secondary,
                fontFamily = FontFamily(
                    Font(
                        R.font.inter_medium,
                        FontWeight.W600
                    )
                )
            ),
            modifier = modifier
                .fillMaxWidth()
                .padding(top = 24.dp)
                .border(
                    1.dp, MaterialTheme.colorScheme.surfaceContainerLow,
                    RoundedCornerShape(10.dp)
                )
                .padding(horizontal = 12.dp, vertical = 8.dp),
            decorationBox = { innerTextField ->
                Row(verticalAlignment = Alignment.CenterVertically) {
                    Row(
                        modifier
                            .size(44.dp, 24.dp)
                            .clickable {
                                forgetPasswordMobileNumberViewmodel.onEvent(
                                    MobileNumberUiState.OnShowCountryDialog(
                                        true
                                    )
                                )
                            },
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        TextComponent(text = state.selectedCountry.flag, fontSize = 24.sp)
                        Icon(
                            painter = painterResource(R.drawable.ic_down_arrow),
                            contentDescription = null,
                            tint = MaterialTheme.colorScheme.onSecondary,
                            modifier = modifier
                                .padding(start = 4.dp, top = 2.dp)
                                .size(16.dp)
                                .padding(2.dp)
                                .align(Alignment.CenterVertically)
                        )
                    }

                    TextComponent(
                        text = state.selectedCountry.dial_code,
                        fontSize = 14.sp,
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        modifier = modifier.padding(start = 8.dp, end = 4.dp),
                        color = MaterialTheme.colorScheme.onSecondary
                    )

                    Box(modifier.weight(1f)) {
                        if (state.mobileNo.isEmpty()) {
                            TextComponent(
                                text = getExampleMobileNumber(state.selectedCountry.code, true),
                                fontSize = 14.sp,
                                color = grey_B3B3B3,
                                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600))
                            )
                        }
                        innerTextField()
                    }
                }

            }
        )

        if (state.isError) {
            TextComponent(
                text = state.error,
                color = red_900B09,
                fontSize = 16.sp,
                style = MaterialTheme.typography.bodyMedium,
                modifier = Modifier.padding(start = 4.dp, top = 8.dp)
            )
        }

        Spacer(modifier = modifier.weight(1F))
        ButtonComponent(
            text = "Next",
            onClick = {
              /*  if (navController.isResume()) {
                    val model = RegisterModel()
                    model.mobileNo = state.mobileNo
                    model.countryCode = state.selectedCountry.dial_code
                    model.type = fromForgetPasswordScreen
                    navController.navigate(model)
                }*/
                forgetPasswordMobileNumberViewmodel.sendOtp(state.mobileNo)
            },
            modifier = modifier.padding(top = 32.dp)
        )
    }


}