package com.ubsidifinance.ui.forget_password.mobile_number

import android.content.Context
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import com.ubsidifinance.R
import com.ubsidifinance.base.ApiResult
import com.ubsidifinance.model.CountryModel
import com.ubsidifinance.model.state.MobileNumberState
import com.ubsidifinance.model.state.MobileNumberUiState
import com.ubsidifinance.network.repo.AuthRepo
import com.ubsidifinance.utils.Preferences
import com.ubsidifinance.utils.toNonNullString
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ForgetPasswordMobileNumberViewmodel @Inject constructor(
    private val repo: AuthRepo,
    private val preferences: Preferences
) : ViewModel() {

    private val _uiState = mutableStateOf(MobileNumberState())
    val uiEvent = _uiState

    fun onEvent(event: MobileNumberUiState) {
        when (event) {
            is MobileNumberUiState.OnNumberChange -> {
                _uiState.value = _uiState.value.copy(mobileNo = event.mobile)
            }

            is MobileNumberUiState.OnChangeSelectedCountry -> {
                _uiState.value = _uiState.value.copy(selectedCountry = event.countryModel)
            }

            is MobileNumberUiState.OnCountryValueChange -> {}
            is MobileNumberUiState.OnShowCountryDialog -> {
                _uiState.value = _uiState.value.copy(showCountryPicker = event.isShow)
            }

            is MobileNumberUiState.OnError -> {
                _uiState.value =
                    _uiState.value.copy(
                        isError = event.isError,
                        error = event.error,
                    )
            }

            is MobileNumberUiState.OnCloseDialog -> {

            }
        }

    }

    fun fetchCountry(context: Context) {
        val jsonString = context.resources.openRawResource(R.raw.country)
            .bufferedReader()
            .use { it.readText() }

        val gson = Gson()
        val type = object : TypeToken<ArrayList<CountryModel>>() {}.type
        val list = gson.fromJson<ArrayList<CountryModel>>(jsonString, type)

        _uiState.value = _uiState.value.copy(
            countryList = list,
            filterCountryList = list,
            selectedCountry = list.first { it -> it.code == "GB" })

    }

    fun sendOtp(email: String) {
        val mobile = _uiState.value.mobileNo

        viewModelScope.launch {
            repo.sendOtp(email)
                .collect { response ->
                    when (response) {
                        is ApiResult.Error -> {
                            _uiState.value =
                                _uiState.value.copy(
//                                    isLoading = false,
                                    isError = true,
                                    error = response.message,
//                                    title = "Error"
                                )
                        }

                        ApiResult.Loading -> {
                            _uiState.value =
                                _uiState.value.copy(
//                                    isLoading = true,
                                )
                        }

                        is ApiResult.Success -> {
                            preferences.loginUserModel = response.data
                            _uiState.value =
                                _uiState.value.copy(
//                                    isLoading = false,
                                )
                        }
                    }
                }
        }
    }
}