package com.ubsidifinance.ui.forget_password.reset_success

import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.register.verify_mobile.VerifyMobileViewmodel
import com.ubsidifinance.utils.isResume

@Composable
fun ResetPasswordSuccessScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewmodel: VerifyMobileViewmodel = hiltViewModel()
) {
    val state = viewmodel.uiEvent.value

    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            Image(
                painter = painterResource(R.drawable.ic_success),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 10.dp)
                    .size(52.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
            )

            TextComponent(
                text = stringResource(R.string.reset_successful),
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 20.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )
            TextComponent(
                text = stringResource(R.string.re_login_to_get_started),
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )
            Image(
                painter = painterResource(R.drawable.ic_success_reset),
                contentDescription = null,
                modifier = modifier
                    .fillMaxWidth()
                    .height(220.dp)
                    .padding(top = 35.dp)
                    .clickable {

                    },
            )
        }

        ButtonComponent(
            text = "Login",
            enable = true,
            onClick = {
                if (navController.isResume()) {
                    navController.navigate(Screens.Login.name) {
                        popUpTo(Screens.Login.name) {
                            inclusive = true
                        }
                    }
                }
            })
    }

}