package com.ubsidifinance.ui.forget_password.set_new_password

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.VisualTransformation
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.LabelWithTextField
import com.ubsidifinance.component.PasswordRulesChecklist
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.VerifyMobileUiState
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.register.verify_mobile.VerifyMobileViewmodel
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.setUpPinScreen

@Composable
fun SetNewPasswordScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewmodel: VerifyMobileViewmodel = hiltViewModel(),
    registerModel: RegisterModel
) {
    val state = viewmodel.uiEvent.value

    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {

            if (registerModel.isFromRegister) {
                HeaderProgress(currentPage = 10)
            }

            Icon(
                painter = painterResource(R.drawable.img_app_logo),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 10.dp)
                    .size(52.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.primary
            )

            TextComponent(
                text = stringResource(R.string.please_set_password),
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 20.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )
            Spacer(modifier = Modifier.height(16.dp))
            LabelWithTextField(
                label = "",
                visualTransformation = if (state.isVisiblePassword) VisualTransformation.None else PasswordVisualTransformation(),
                placeHolder = "Enter Password",
                keyboardOptions = KeyboardOptions(
                    keyboardType = KeyboardType.Password,
                    imeAction = ImeAction.Done
                ),
                value = state.password,
                suffix = {
                    Icon(
                        painter = painterResource(if (!state.isVisiblePassword) R.drawable.ic_hide_password else R.drawable.ic_show_password),
                        contentDescription = null,
                        tint = MaterialTheme.colorScheme.secondary,
                        modifier = modifier
                            .clickable {
                                viewmodel.onEvent(VerifyMobileUiState.OnPasswordVisibilityChange)
                            }
                    )
                },
                modifier = modifier.padding(top = 32.dp),
                onValueChange = {
                    viewmodel.onEvent(VerifyMobileUiState.OnPasswordChange(it))
                }
            )
            Spacer(modifier = Modifier.height(8.dp))
            LabelWithTextField(
                label = "",
                visualTransformation = if (state.isVisibleConfirmPassword) VisualTransformation.None else PasswordVisualTransformation(),
                placeHolder = "Enter Confirm Password",
                keyboardOptions = KeyboardOptions(
                    keyboardType = KeyboardType.Password,
                    imeAction = ImeAction.Done
                ),
                value = state.confirmPassword,
                suffix = {
                    Icon(
                        painter = painterResource(if (!state.isVisibleConfirmPassword) R.drawable.ic_hide_password else R.drawable.ic_show_password),
                        contentDescription = null,
                        tint = MaterialTheme.colorScheme.secondary,
                        modifier = modifier
                            .clickable {
                                viewmodel.onEvent(VerifyMobileUiState.OnConfirmPasswordVisibilityChange)
                            }
                    )
                },
                modifier = modifier.padding(top = 32.dp),
                onValueChange = {
                    viewmodel.onEvent(VerifyMobileUiState.OnConfirmPasswordChange(it))
                }
            )
            PasswordRulesChecklist(password = state.password)
        }

        ButtonComponent(
            text = "Next",
            enable = state.isEnableButton,
            onClick = {
                if (navController.isResume()) {
                    if (registerModel.isFromRegister) {
                        val model = registerModel
                        model.type = setUpPinScreen
                        navController.navigate(model)
                    } else {
                        navController.navigate(Screens.ResetPasswordSuccessScreen.name)
                    }
                }
            })
    }

}