package com.ubsidifinance.ui.forget_password.verify_otp

import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.imePadding
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.OTPTextField
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.keyboardController
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.VerifyMobileUiState
import com.ubsidifinance.ui.register.verify_mobile.VerifyMobileViewmodel
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_757575
import com.ubsidifinance.ui.theme.red_900B09
import com.ubsidifinance.utils.businessTypeScreen
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.setNewPasswordScreen

@Composable
fun VerifyOtpScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewmodel: VerifyMobileViewmodel = hiltViewModel(),
    registerModel: RegisterModel
) {

    val state = viewmodel.uiEvent.value
    val interaction = remember { MutableInteractionSource() }
    var text by remember { mutableStateOf("") }
    var isError by remember { mutableStateOf(false) }
    val keyboardController = keyboardController()

    LaunchedEffect(Unit) {
        viewmodel.onEvent(VerifyMobileUiState.OnTimerStart)
    }

    Column(modifier = modifier
        .imePadding()
        .padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 12.dp)
                    .size(18.dp)
                    .clickable {
                        if (navController.isResume()) {
                            keyboardController?.hide()
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = stringResource(R.string.verification_code),
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 26.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "${stringResource(R.string.enter_code_we_sent)}${registerModel.countryCode} ${registerModel.mobileNo}",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            OTPTextField(isError = isError, taxDigitLength = 6) { value ->
                text = value
                if (value.length == 6) {
                    isError = text != "111111"
                }
                viewmodel.onEvent(VerifyMobileUiState.OnButtonEnable(!isError))

            }

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier.padding(top = 24.dp)
            ) {
                TextComponent(
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500)),
                    fontSize = 14.sp,
                    modifier = modifier
                        .weight(1f)
                        .padding(end = 5.dp),
                    text = if (isError) "Incorrect Code" else "Didn’t receive an OTP?",
                    color = if (isError) red_900B09 else grey_757575
                )

                TextComponent(
                    text = if (state.isTimerRunning) "Resend in: " + state.timer else "Resend Code",
                    modifier = modifier
                        .weight(1f)
                        .clickable(indication = null, interactionSource = interaction, onClick = {
                            if (!state.isTimerRunning)
                                viewmodel.onEvent(VerifyMobileUiState.OnTimerStart)
                        })
                        .padding(start = 5.dp),
                    style = TextStyle(
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        fontSize = 14.sp,
                        color = blue316AFF,
                        textAlign = TextAlign.End
                    ),
                )
            }
        }

        ButtonComponent(
            text = "Next",
            enable = state.isEnableButton,
            onClick = {
                if (navController.isResume()) {
                    keyboardController?.hide()
                    registerModel.type = setNewPasswordScreen
                    navController.navigate(registerModel)
                }
            })
    }

}