package com.ubsidifinance.ui.forgot_password

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Card
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.window.Dialog
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.viewmodel.compose.LocalViewModelStoreOwner
import androidx.lifecycle.viewmodel.compose.viewModel
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.state.ForgotPasswordUiState
import com.ubsidifinance.utils.isValidEmail
import java.util.UUID

@Composable
fun ForgotPasswordDialog(
    modifier: Modifier = Modifier,
//    viewModel: ForgotPasswordViewModel = hiltViewModel(),
    onDismissRequest: () -> Unit,
    onConfirmation: () -> Unit,
) {

    val viewModelStoreOwner = LocalViewModelStoreOwner.current!!
    val uniqueKey = remember { UUID.randomUUID().toString() }
    val viewModel: ForgotPasswordViewModel = viewModel(
        viewModelStoreOwner = viewModelStoreOwner,
        key = uniqueKey,
        factory = ViewModelProvider.NewInstanceFactory()
    )

    val state = viewModel.uiEvent.value
    val interaction = remember { MutableInteractionSource() }

    Dialog(onDismissRequest = onDismissRequest) {

        Card(
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp),
            shape = RoundedCornerShape(16.dp),
        ) {
            Column(
                modifier = modifier.background(
                    MaterialTheme.colorScheme.background,
                    RoundedCornerShape(16.dp)
                )
            ) {

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = "Close Button",
                    modifier = modifier
                        .align(Alignment.End)
                        .clip(CircleShape)
                        .clickable(
                            indication = null,
                            interactionSource = interaction,
                            onClick = onDismissRequest
                        )
                        .padding(end = 10.dp, top = 10.dp)
                        .size(20.dp)
                        .padding(4.dp)

                )

                Column(
                    modifier = modifier
                        .padding(horizontal = 32.dp)
                        .padding(bottom = 32.dp)
                ) {
                    TextComponent(
                        text = "Forgot Password?",
                        modifier = modifier.padding(bottom = 12.dp),
                        color = MaterialTheme.colorScheme.secondary,
                        fontSize = 24.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_bold, FontWeight.W500)
                        )
                    )

                    TextComponent(
                        text = "Enter your email to reset your password.",
                        color = MaterialTheme.colorScheme.secondary,
                        fontSize = 16.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_regular, FontWeight.W500)
                        )
                    )

                    TextFieldComponent(
                        value = state.emailText,
                        placeholder = "Enter Your Email",
                        keyboardOptions = KeyboardOptions(
                            keyboardType = KeyboardType.Email,
                            imeAction = ImeAction.Done
                        ),
                        modifier = modifier.padding(vertical = 24.dp)
                    ) { value ->
                        viewModel.onEvent(ForgotPasswordUiState.OnEmailChange(value))
                        viewModel.onEvent(ForgotPasswordUiState.ButtonEnable(value.isValidEmail()))

                    }

                    ButtonComponent(
                        text = "Ok",
                        enable = state.isEnableButton,
                        onClick = {
                            onDismissRequest.invoke()
                            onConfirmation.invoke()
                        })


                }

            }
        }

    }


}