package com.ubsidifinance.ui.home_page

import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.gestures.snapping.SnapPosition
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.IntrinsicSize
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.pager.HorizontalPager
import androidx.compose.foundation.pager.PageSize
import androidx.compose.foundation.pager.rememberPagerState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.blur
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.IndicatorComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.dailog.MoreMenuDialog
import com.ubsidifinance.model.CardDetailModel
import com.ubsidifinance.model.TransactionList
import com.ubsidifinance.navigation.Home
import com.ubsidifinance.navigation.Notification
import com.ubsidifinance.navigation.RequestAmount
import com.ubsidifinance.navigation.TransactionDetail
import com.ubsidifinance.navigation.Transactions
import com.ubsidifinance.navigation.TransferAmount
import com.ubsidifinance.ui.theme.black232323
import com.ubsidifinance.ui.theme.black2C2C2C
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.green_009951
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_F5F5F5
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.ui.theme.red_EC221F
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.SearchTransferType
import com.ubsidifinance.utils.isResume

@OptIn(ExperimentalFoundationApi::class)
@Composable
fun HomePageScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    oldGraphNavController: NavController,
    viewmodel: HomePageViewmodel = hiltViewModel()
) {

    val state = viewmodel.uiEvent.value
    val pagerState = rememberPagerState(initialPage = 0, pageCount = {
        state.listOfCard.size
    })
    var isShowMenuDialog by remember { mutableStateOf(false) }

    if (isShowMenuDialog) {
        MoreMenuDialog(
            onDismissRequest = {
                isShowMenuDialog = false
            },
            onConfirmRequest = {

            }
        )
    }

    Column(modifier = modifier.padding(horizontal = 24.dp)) {

        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier.padding(vertical = 12.dp)
        ) {
            Image(
                painter = painterResource(R.drawable.img_app_logo),
                contentDescription = "",
                modifier = modifier
                    .size(38.dp)
                    .background(blue316AFF, CircleShape)
                    .padding(2.dp)
            )

            TextComponent(
                text = "Nibs Solutions Ltd",
                fontSize = 16.sp,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                color = MaterialTheme.colorScheme.inversePrimary,
                modifier = modifier
                    .padding(start = 12.dp)
                    .weight(1f)
            )

            Box(
                modifier = modifier
                    .clickable(onClick = {
                        if (oldGraphNavController.isResume()) {
                            oldGraphNavController.navigate(Notification)
                        }
                    }), contentAlignment = Alignment.Center
            ) {
                Icon(
                    painter = painterResource(R.drawable.ic_notification),
                    contentDescription = "Notification",
                    modifier = modifier.size(18.dp),
                    tint = MaterialTheme.colorScheme.surface
                )
                Box(
                    modifier
                        .align(Alignment.TopEnd)
                        .padding(start = 22.dp, bottom = 20.dp)
                        .background(red_EC221F, CircleShape)
                        .size(19.dp),
                    contentAlignment = Alignment.Center
                ) {
                    TextComponent(
                        text = "1",
                        color = white,
                        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                        fontSize = 14.sp
                    )
                }
            }

        }

        LazyColumn(
            modifier = modifier
                .weight(1f)
        ) {
            item(key = "Content") {
                Column(modifier = modifier.fillMaxWidth()) {

                    TextComponent(
                        text = "Total balance",
                        style = TextStyle(
                            color = grey_9499A5,
                            fontSize = 12.sp,
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                        ),
                        modifier = modifier.align(Alignment.CenterHorizontally)
                    )

                    TextComponent(
                        text = "£52,432",
                        style = TextStyle(
                            color = MaterialTheme.colorScheme.inversePrimary,
                            fontSize = 32.sp,
                            fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold)),
                        ),
                        modifier = modifier
                            .align(Alignment.CenterHorizontally)
                            .padding(top = 6.dp)
                    )

                    HorizontalPager(
                        state = pagerState,
                        pageSpacing = 10.dp,
                        pageSize = PageSize.Fixed(300.dp),
                        snapPosition = SnapPosition.End,
                        modifier = Modifier
                            .align(Alignment.CenterHorizontally)
                            .padding(top = 20.dp),
                    ) { index ->
                        Box(
                            modifier
                                .fillMaxWidth()
                        ) {
                            CardDetailsRowItem(model = state.listOfCard[index])
                        }

                    }

                    IndicatorComponent(
                        modifier = modifier
                            .fillMaxWidth()
                            .padding(top = 16.dp),
                        totalSize = pagerState.pageCount,
                        selectedIndex = pagerState.currentPage,
                        selectColor = MaterialTheme.colorScheme.inverseSurface
                    )

                    Row(
                        modifier = modifier.padding(top = 12.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {

                        ImageWithTextButton(
                            modifier = modifier
                                .weight(1f)
                                .padding(end = 8.dp),
                            icon = R.drawable.ic_back_arrow,
                            rotate = 120f,
                            onClick = {
                                if (oldGraphNavController.isResume()) {
                                    oldGraphNavController.navigate(TransferAmount)
                                }
                            },
                            text = "Transfer"
                        )

                        ImageWithTextButton(
                            modifier = modifier
                                .weight(1f)
                                .padding(end = 8.dp),
                            icon = R.drawable.ic_back_arrow,
                            rotate = 300f,
                            onClick = {
                                if (oldGraphNavController.isResume()) {
                                    oldGraphNavController.navigate(RequestAmount)
                                }
                            },
                            text = "Request"
                        )

                        Icon(
                            painter = painterResource(R.drawable.ic_more_menu),
                            contentDescription = "",
                            modifier = modifier
                                .background(grey_F9F9F9, CircleShape)
                                .clip(CircleShape)
                                .clickable(onClick = {
                                    isShowMenuDialog = true
                                })
                                .padding(12.dp)
                                .size(24.dp)
                                .padding(4.dp),
                            tint = blue316AFF
                        )
                    }

                    Row(
                        modifier = modifier.padding(top = 10.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        TextComponent(
                            text = "Transaction History",
                            style = TextStyle(
                                color = MaterialTheme.colorScheme.surface,
                                fontSize = 16.sp,
                                fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W600)),
                            ),
                            modifier = modifier
                                .weight(1f)
                        )

                        Icon(
                            painter = painterResource(R.drawable.ic_search),
                            contentDescription = "",
                            modifier = modifier
                                .clip(CircleShape)
                                .clickable(onClick = {
                                    if (navController.isResume()) {
                                        navController.navigate(Transactions(type = SearchTransferType)) {
                                            popUpTo(Home) {
                                                saveState = true
                                            }
                                        }
                                    }
                                })
                                .padding(15.dp)
                                .size(20.dp),
                            tint = MaterialTheme.colorScheme.surface

                        )
                    }

                }
            }

            state.listOfTransaction.forEach {

                stickyHeader(key = it.date) {
                    Column(
                        modifier = modifier
                            .fillMaxWidth()
                            .background(MaterialTheme.colorScheme.background)
                            .padding(vertical = 8.dp)
                    ) {
                        TextComponent(
                            text = it.date,
                            fontSize = 14.sp,
                            color = MaterialTheme.colorScheme.surface,
                            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
                        )
                    }
                }

                items(it.listOfTransaction) { item ->
                    TransactionItemRow(model = item, onClick = {
                        if (oldGraphNavController.isResume()) {
                            oldGraphNavController.navigate(TransactionDetail)
                        }
                    })
                }
            }
        }
    }
}

@Composable
fun TransactionItemRow(
    modifier: Modifier = Modifier,
    model: TransactionList,
    onClick: () -> Unit
) {

    Column(modifier = modifier.clickable(onClick = onClick)) {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier.padding(vertical = 16.dp)
        ) {
            Image(
                painter = painterResource(model.image),
                contentDescription = "",
                modifier = modifier
                    .size(40.dp)
                    .clip(CircleShape)
            )

            Column(
                modifier = modifier
                    .weight(1f)
                    .padding(horizontal = 12.dp)
            ) {

                TextComponent(
                    text = model.transactionName,
                    fontSize = 14.sp,
                    color = MaterialTheme.colorScheme.surface,
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W400))
                )

                TextComponent(
                    text = model.transactionDetail,
                    fontSize = 14.sp,
                    modifier = modifier.padding(top = 3.dp),
                    color = MaterialTheme.colorScheme.inverseOnSurface,
                    fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
                )
            }

            TextComponent(
                text = if (model.isCredit) "+ £" + model.amount.toString() else "- £" + model.amount.toString(),
                fontSize = 16.sp,
                color = if (model.isCredit) green_009951 else MaterialTheme.colorScheme.inversePrimary,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600))
            )


        }

        HorizontalDividerComponent(
            modifier = modifier
                .fillMaxWidth()
                .padding(start = 52.dp)
        )
    }

}

@Composable
private fun CardDetailsRowItem(
    modifier: Modifier = Modifier,
    model: CardDetailModel
) {

    Surface(
        shape = RoundedCornerShape(18.dp),
        color = if (model.isLightCard) white else black232323,
        tonalElevation = 2.dp,
        shadowElevation = 4.dp,
        modifier = Modifier
            .padding(start = 5.dp, end = 2.dp)
            .fillMaxWidth()
    ) {
        Column(
            modifier
                .fillMaxWidth()
                .background(if (model.isLightCard) white else black232323, RoundedCornerShape(18.dp))
        ) {
            Column(
                modifier
                    .padding(horizontal = 24.dp)
                    .padding(top = 24.dp, bottom = 10.dp)
            ) {
                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    horizontalArrangement = Arrangement.Absolute.SpaceBetween, modifier = modifier
                        .fillMaxWidth()
                ) {
                    Icon(
                        painter = painterResource(R.drawable.ic_visa),
                        contentDescription = "Card Type",
                        modifier = modifier.size(38.dp, 12.dp),
                        tint = if (model.isLightCard) black232323 else white
//                        contentScale = ContentScale.Fit
                    )

                    Icon(
                        painter = painterResource(R.drawable.img_ubsidi_logo),
                        contentDescription = "Ubsidi Logo",
                        modifier = modifier.size(65.dp, 25.dp),
                        tint = if (model.isLightCard) black232323 else white
                    )
                }

                TextComponent(
                    text = model.cardNumber,
                    fontSize = 16.sp,
                    modifier = modifier
                        .padding(top = 70.dp)
                        .align(Alignment.End),
                    color = if (model.isLightCard) black232323 else white,
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                )

            }

            Box(
                modifier
                    .fillMaxWidth()
                    .height(IntrinsicSize.Min)
                    .background(
                        if (model.isLightCard) grey_F5F5F5 else black2C2C2C,
                        RoundedCornerShape(bottomEnd = 18.dp, bottomStart = 18.dp)
                    )
            ) {

                Box(
                    modifier = modifier
                        .fillMaxWidth()
                        .fillMaxHeight()
                        .blur(10.dp)
                )

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    horizontalArrangement = Arrangement.Absolute.SpaceBetween,
                    modifier = modifier
                        .fillMaxWidth()
                        .padding(horizontal = 24.dp, vertical = 16.dp)
                ) {

                    TextComponent(
                        text = model.name,
                        color = if (model.isLightCard) black232323 else white,
                        fontSize = 12.sp,
                        fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                    )

                    TextComponent(
                        text = model.expiry,
                        color = if (model.isLightCard) black232323 else white,
                        fontSize = 12.sp,
                        fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                    )

                }
            }

        }
    }


}

@Composable
fun ImageWithTextButton(
    modifier: Modifier = Modifier,
    text: String,
    icon: Int,
    rotate: Float = 0f,
    onClick: () -> Unit
) {
    Box(modifier) {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.Center,
            modifier = Modifier
                .background(grey_F9F9F9, RoundedCornerShape(50.dp))
                .fillMaxWidth()
                .clip(RoundedCornerShape(50.dp))
                .clickable(onClick = onClick)
                .padding(vertical = 13.dp, horizontal = 5.dp)
        ) {

            Icon(
                painter = painterResource(icon),
                contentDescription = "",
                modifier = Modifier
                    .rotate(rotate)
                    .size(24.dp)
                    .padding(5.dp),
                tint = blue316AFF
            )

            TextComponent(
                text = text,
                color = black232323,
                fontSize = 14.sp,
                modifier = Modifier.padding(start = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W500))
            )

        }
    }
}