package com.ubsidifinance.ui.new_recipient

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.AccountModel
import com.ubsidifinance.ui.theme.green_15BF64
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.toInitials

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun CheckRecipientScreen(
    modifier: Modifier = Modifier,
    onDismissRequest: () -> Unit,
    onConfirmation: (AccountModel) -> Unit,
    viewmodel: RecipientViewmodel
) {

    val state = viewmodel.uiEvent.value

    BaseBottomSheetDialog(onDismiss = onDismissRequest) {

        Column(
            modifier = modifier
                .padding(24.dp)
                .fillMaxWidth()
        ) {

            HorizontalDividerComponent(
                thickness = 6.dp, modifier = modifier
                    .width(50.dp)
                    .clip(CircleShape)
                    .align(Alignment.CenterHorizontally)
            )

            Row(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp),
                verticalAlignment = Alignment.CenterVertically,
            ) {

                Icon(
                    painter = painterResource(R.drawable.ic_back_arrow),
                    contentDescription = null,
                    modifier = Modifier
                        .clip(CircleShape)
                        .clickable(onClick = onDismissRequest)
                        .size(24.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )

                TextComponent(
                    text = "New recipient",
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    modifier = modifier
                        .weight(1f)
                        .padding(horizontal = 12.dp),
                    fontSize = 18.sp,
                    color = MaterialTheme.colorScheme.surfaceDim
                )

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = null,
                    modifier = Modifier
                        .clip(CircleShape)
                        .clickable(onClick = onDismissRequest)
                        .size(24.dp)
                        .padding(7.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )

            }

            Icon(
                tint = white,
                painter = painterResource(R.drawable.ic_check),
                contentDescription = "Document Check",
                modifier = modifier
                    .padding(top = 24.dp)
                    .align(Alignment.CenterHorizontally)
                    .background(green_15BF64, CircleShape)
                    .clip(CircleShape)
                    .padding(10.dp)
                    .size(35.dp)
            )

            TextComponent(
                text = "Account matches",
                modifier = modifier
                    .align(Alignment.CenterHorizontally)
                    .padding(vertical = 24.dp),
                color = green_15BF64,
                fontSize = 16.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_semi_bold, FontWeight.W600)
                )
            )

            TextComponent(
                text = "Account Holder",
                modifier = modifier,
                color = grey_9499A5,
                fontSize = 14.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W500)
                )
            )

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier.padding(top = 8.dp)
            ) {

                TextComponent(
                    text = state.fullName.toInitials(),
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                    modifier = modifier
                        .padding(vertical = 10.dp)
                        .background(grey_F9F9F9, CircleShape)
                        .padding(10.dp),
                    fontSize = 14.sp,
                    color = grey_9499A5
                )

                TextComponent(
                    text = state.fullName,
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    modifier = modifier.padding(start = 8.dp),
                    fontSize = 14.sp,
                    color = MaterialTheme.colorScheme.inversePrimary
                )

            }

            TextComponent(
                text = "Bank & Account Number",
                modifier = modifier.padding(top = 24.dp),
                color = grey_9499A5,
                fontSize = 14.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W500)
                )
            )

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .padding(vertical = 8.dp)
            ) {
                Image(
                    painter = painterResource(R.drawable.img_nationwide_bank),
                    contentDescription = null,
                    modifier = modifier
                        .padding(top = 10.dp)
                        .size(44.dp)
                        .clip(CircleShape)
                        .clickable {

                        },
                )

                Column(
                    modifier = modifier
                        .weight(1f)
                        .padding(start = 8.dp)
                ) {

                    TextComponent(
                        text = "Nationwide Bank",
                        fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                        modifier = modifier,
                        fontSize = 14.sp,
                        color = MaterialTheme.colorScheme.inversePrimary
                    )

                    TextComponent(
                        text = "Sort Code: ${state.sortCode}",
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        modifier = modifier
                            .padding(top = 6.dp),
                        fontSize = 12.sp,
                        color = grey_9499A5
                    )

                    TextComponent(
                        text = "Account Number: ${state.accountNumber}",
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        modifier = modifier
                            .padding(top = 6.dp),
                        fontSize = 12.sp,
                        color = grey_9499A5
                    )
                }

            }

            ButtonComponent(
                modifier = modifier.padding(top = 24.dp),
                text = "Add Recipient",
                onClick = {
                    val model = AccountModel(
                        1,
                        sortCode = state.sortCode,
                        accountNumber = state.accountNumber,
                        fullName = state.fullName
                    )
                    onDismissRequest.invoke()
                    onConfirmation(model)
                }
            )

        }
    }

}