package com.ubsidifinance.ui.new_recipient

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.model.state.RecipientState
import com.ubsidifinance.model.state.RecipientUiState
import com.ubsidifinance.utils.isValidateEmpty
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class RecipientViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(RecipientState())
    val uiEvent = _uiState

    fun onEvent(event: RecipientUiState) {

        when (event) {

            is RecipientUiState.OnAccountNoChange -> {
                _uiState.value = _uiState.value.copy(accountNumber = event.text)
                checkValidate()
            }

            is RecipientUiState.OnNameChange -> {
                _uiState.value = _uiState.value.copy(fullName = event.text)
                checkValidate()
            }

            is RecipientUiState.OnSortCodeChange -> {
                _uiState.value = _uiState.value.copy(sortCode = event.text)
                checkValidate()
            }

            is RecipientUiState.OnAccountTypeChange -> {
                _uiState.value =
                    _uiState.value.copy(accountType = event.text)
                checkValidate()
            }

            is RecipientUiState.OnCheckAccountChange -> {
                _uiState.value =
                    _uiState.value.copy(isCheckAccount = event.isShow)
                checkValidate()
            }
        }
    }

    fun checkValidate() {
        val accountType = _uiState.value.accountType
        val fullName = _uiState.value.fullName
        val sortCode = _uiState.value.sortCode
        val accountNo = _uiState.value.accountNumber

        _uiState.value =
            _uiState.value.copy(
                isEnableButton = !accountType.isValidateEmpty() &&
                        !fullName.isValidateEmpty() &&
                        !sortCode.isValidateEmpty() &&
                        !accountNo.isValidateEmpty()
            )
    }

}