package com.ubsidifinance.ui.notification

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.NotificationModel
import com.ubsidifinance.ui.theme.grey_646B7C
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.utils.isResume

@Composable
fun NotificationScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    viewmodel: NotificationViewmodel = hiltViewModel()
) {

    val state = viewmodel.uiEvent.value

    Column(modifier = modifier.padding(horizontal = 24.dp)) {
        ActionBarWithBackButton(
            isVisibleBack = true,
            title = "Notifications",
            onBack = {
                if (navController.isResume()) {
                    navController.popBackStack()
                }
            }
        )

        LazyColumn {
            items(state.listOfNotification) {
                NotificationItemRow(model = it)
            }
        }
    }
}

@Composable
fun NotificationItemRow(
    modifier: Modifier = Modifier,
    model: NotificationModel
) {
    Column(modifier = modifier.padding(top = 24.dp)) {
        Row(verticalAlignment = Alignment.CenterVertically) {

            TextComponent(
                text = model.title,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier
                    .padding(end = 5.dp)
                    .weight(1f),
                fontSize = 16.sp,
                color = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = model.date,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500)),
                modifier = modifier.padding(end = 5.dp),
                fontSize = 12.sp,
                color = grey_9499A5
            )
        }

        TextComponent(
            text = model.descriptions,
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            modifier = modifier.padding(end = 5.dp, bottom = 24.dp, top = 5.dp),
            maxLines = 3,
            fontSize = 16.sp,
            color = grey_646B7C
        )

        HorizontalDividerComponent()
    }

}