package com.ubsidifinance.ui.on_boarding

import androidx.compose.foundation.Image
import androidx.compose.foundation.border
import androidx.compose.foundation.gestures.snapping.SnapPosition
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.pager.HorizontalPager
import androidx.compose.foundation.pager.rememberPagerState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_D9D9D9
import com.ubsidifinance.utils.isResume
import kotlinx.coroutines.launch

@Composable
fun OnBoardingScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewModel: OnBoardingViewModel = hiltViewModel()
) {

    val state = viewModel.uiEvent.value
    val scope = rememberCoroutineScope()
    val pagerState = rememberPagerState(initialPage = 0, pageCount = {
        state.list.size
    })

    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(horizontal = 24.dp)
            .padding(bottom = 24.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        HorizontalPager(
            state = pagerState,
            snapPosition = SnapPosition.End,
            modifier = Modifier
                .align(Alignment.CenterHorizontally)
                .weight(1f)
                .padding(top = 10.dp),
        ) { index ->

            Box(
                modifier
                    .fillMaxSize()
                    .align(Alignment.CenterHorizontally),
                contentAlignment = Alignment.BottomCenter
            ) {
                Image(
                    painter = painterResource(state.list[index].image),
                    contentDescription = null,
                    modifier = modifier.fillMaxSize(),
                    contentScale = ContentScale.Fit
                )
            }
        }

        Row(
            horizontalArrangement = Arrangement.Center,
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier
                .padding(bottom = 24.dp)
                .fillMaxWidth()
        ) {
            repeat(state.list.size) {
                Box(
                    modifier = modifier
                        .width(if (it != pagerState.currentPage) 6.dp else 18.dp)
                        .height(6.dp)
                        .border(
                            width = 6.dp,
                            color = if (it != pagerState.currentPage) grey_D9D9D9 else blue316AFF,
                            shape = if (it != pagerState.currentPage) CircleShape else RoundedCornerShape(
                                3.dp
                            )
                        )
                )
                Spacer(modifier = modifier.padding(start = 6.dp))
            }
        }

        TextComponent(
            text = state.list[pagerState.currentPage].title,
            style = MaterialTheme.typography.headlineLarge.copy(
                textAlign = TextAlign.Center,
                color = MaterialTheme.colorScheme.inversePrimary,
            )
        )

        TextComponent(
            text = state.list[pagerState.currentPage].descriptions,
            style = MaterialTheme.typography.bodyMedium.copy(
                textAlign = TextAlign.Center,
                color = grey_9499A5,
            ),
            modifier = modifier.padding(top = 14.dp)
        )

        ButtonComponent(
            modifier = modifier.padding(top = 20.dp),
            text = if (pagerState.currentPage == 2) "Get Started" else "Continue",
            onClick = {
                scope.launch {
                    if (pagerState.currentPage == 2) {
                        if (navController.isResume()) {
                            navController.navigate(Screens.Login.name) {
                                popUpTo(Screens.OnBoarding.name) {
                                    inclusive = true
                                }
                            }
                        }
                    } else {
                        pagerState.scrollToPage(pagerState.currentPage + 1)
                    }
                }
            })
    }


}

