package com.ubsidifinance.ui.pin

import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.fragment.app.FragmentActivity
import androidx.lifecycle.ViewModelProvider
import androidx.lifecycle.viewmodel.compose.LocalViewModelStoreOwner
import androidx.lifecycle.viewmodel.compose.viewModel
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import java.util.UUID

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun AuthenticationDialog(
    modifier: Modifier = Modifier,
    fragmentActivity: FragmentActivity? = null,
    onDismissRequest: () -> Unit,
    onConfirmRequest: () -> Unit,
) {

    val interaction = remember { MutableInteractionSource() }

    val viewModelStoreOwner = LocalViewModelStoreOwner.current!!
    val uniqueKey = remember { UUID.randomUUID().toString() }
    val viewmodel: PinViewmodel = viewModel(
        viewModelStoreOwner = viewModelStoreOwner,
        key = uniqueKey,
        factory = ViewModelProvider.NewInstanceFactory()
    )
    val state = viewmodel.uiEvent.value

    LaunchedEffect(state.pin) {
        if (state.pin.length == 6) {
            onDismissRequest.invoke()
            onConfirmRequest.invoke()
        }
    }

    BaseBottomSheetDialog(onDismiss = onDismissRequest) {
        Column(
            modifier = modifier
                .padding(24.dp)
                .fillMaxWidth()
        ) {

            HorizontalDividerComponent(
                thickness = 6.dp, modifier = modifier
                    .width(50.dp)
                    .clip(CircleShape)
                    .align(Alignment.CenterHorizontally)
            )

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp),
            ) {
                Icon(
                    painter = painterResource(R.drawable.ic_back_arrow),
                    contentDescription = null,
                    modifier = Modifier
                        .clip(CircleShape)
                        .clickable(onClick = onDismissRequest)
                        .size(24.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )

                TextComponent(
                    text = "Authentication",
                    fontSize = 22.sp,
                    modifier = modifier
                        .weight(1f)
                        .padding(start = 12.dp),
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    color = MaterialTheme.colorScheme.surface
                )

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = "Close Button",
                    modifier = modifier
                        .clip(CircleShape)
                        .clickable(
                            indication = null,
                            interactionSource = interaction,
                            onClick = onDismissRequest
                        )
                        .size(20.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )
            }

            TextComponent(
                text = "Enter your PIN",
                color = MaterialTheme.colorScheme.surfaceDim,
                fontSize = 18.sp,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier
                    .padding(vertical = 24.dp)
                    .align(Alignment.CenterHorizontally)
            )

            NumberPad(
                viewmodel = viewmodel,
                fragmentActivity = fragmentActivity,
                onAuthResult = { isSuccess ->
                    if (isSuccess) {
                        onDismissRequest.invoke()
                        onConfirmRequest.invoke()
                    }
                })
        }
    }
}