package com.ubsidifinance.ui.pin

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.heightIn
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.ripple
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color.Companion.Transparent
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.fragment.app.FragmentActivity
import com.ubsidifinance.R
import com.ubsidifinance.biometric.BiometricHelper
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.state.PinUiState
import com.ubsidifinance.ui.theme.blue316AFF

@Composable
fun NumberPad(
    modifier: Modifier = Modifier,
    viewmodel: PinViewmodel,
    isShowBioMetric: Boolean = BiometricHelper.isBiometricAvailable(context = LocalContext.current),
    fragmentActivity: FragmentActivity? = null,
    onAuthResult: (Boolean) -> Unit = {}
) {
    val state = viewmodel.uiEvent.value

    Column(modifier = modifier, horizontalAlignment = Alignment.CenterHorizontally) {

        Row(
            horizontalArrangement = Arrangement.Center,
        ) {
            repeat(6) {
                Box(
                    Modifier
                        .padding(end = 10.dp)
                        .size(12.dp)
                        .clip(CircleShape)
                        .background(color = if (state.pin.length <= it) MaterialTheme.colorScheme.outlineVariant else MaterialTheme.colorScheme.primary)
                )
            }
        }

        Spacer(modifier = Modifier.height(32.dp))

        DialPad(
            viewmodel = viewmodel,
            isShowBioMetric = isShowBioMetric,
            fragmentActivity = fragmentActivity,
            onAuthResult = onAuthResult
        )

    }
}

@Composable
fun DialPad(
    modifier: Modifier = Modifier,
    viewmodel: PinViewmodel,
    fragmentActivity: FragmentActivity? = null,
    onAuthResult: (Boolean) -> Unit,
    isShowBioMetric: Boolean
) {

    var text by remember { mutableStateOf("") }
    val context = fragmentActivity ?: LocalContext.current as FragmentActivity
    val isBiometricAvailable = remember { BiometricHelper.isBiometricAvailable(context) }

    Column(modifier = modifier.fillMaxWidth(), horizontalAlignment = Alignment.CenterHorizontally) {
        Row(
            horizontalArrangement = Arrangement.SpaceEvenly,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 16.dp)
        ) {
            NumberView(text = "1", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "1"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "2", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "2"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "3", isThirdLine = true, onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "3"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
        }

        Row(
            horizontalArrangement = Arrangement.SpaceEvenly,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 16.dp)
        ) {
            NumberView(text = "4", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "4"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "5", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "5"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "6", isThirdLine = true, onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "6"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
        }

        Row(
            horizontalArrangement = Arrangement.SpaceEvenly,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 16.dp)
        ) {
            NumberView(text = "7", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "7"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "8", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "8"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(text = "9", isThirdLine = true, onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "9"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
        }

        Row(
            horizontalArrangement = Arrangement.SpaceEvenly,
            modifier = Modifier
                .fillMaxWidth()
                .padding(top = 16.dp)
        ) {
            NumberView(image = R.drawable.ic_face_lock, onClick = {
                BiometricHelper.showBiometricPrompt(context, onAuthResult = onAuthResult)
            }, isShow = isShowBioMetric)
            NumberView(text = "0", onClick = {
                if (viewmodel.uiEvent.value.pin.length < 6) {
                    text += "0"
                    viewmodel.onEvent(PinUiState.OnDialClick(text))
                }
            })
            NumberView(image = R.drawable.ic_back_key, isThirdLine = true, onClick = {

                text = text.dropLast(1)
                viewmodel.onEvent(PinUiState.OnDialClick(text))

            })
        }
    }
}

@Composable
fun NumberView(
    modifier: Modifier = Modifier,
    text: String? = null,
    image: Int? = null,
    onClick: () -> Unit,
    isThirdLine: Boolean = false,
    isShow: Boolean = true
) {

    val interaction = remember { MutableInteractionSource() }
    val indication = ripple(color = blue316AFF)

    Box(
        modifier
            .padding(end = if (!isThirdLine) 24.dp else 0.dp)
            .background(
                if (isShow && image == null) MaterialTheme.colorScheme.tertiaryContainer else Transparent,
                CircleShape
            )
            .clip(CircleShape)
            .clickable(indication = indication, interactionSource = interaction, onClick = onClick)
            .size(70.dp), contentAlignment = Alignment.Center
    ) {
        if (text != null) {
            TextComponent(
                text = text,
                fontSize = 18.sp,
                color = MaterialTheme.colorScheme.surfaceDim,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = Modifier
            )
        } else {
            if (isShow) {
                Icon(
                    painter = painterResource(image!!),
                    contentDescription = null,
                    modifier = Modifier.heightIn(max = 30.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )
            }
        }
    }
}