package com.ubsidifinance.ui.pin

import androidx.compose.foundation.Image
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.utils.isResume

@Composable
fun PinScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewmodel: PinViewmodel = hiltViewModel()
) {
    val scrollState = rememberScrollState()
    val state = viewmodel.uiEvent.value

    LaunchedEffect(state.pin) {
        if (state.pin.length == 6) {
            if (navController.isResume()) {
                navController.navigate(Screens.HomePage.name) {
                    popUpTo(Screens.Pin.name) {
                        inclusive = true
                    }
                }
            }
        }
    }

    Column(
        modifier = modifier
            .fillMaxSize()
            .verticalScroll(scrollState)
            .padding(horizontal = 24.dp)
    ) {

        Image(
            painter = painterResource(R.drawable.img_logo_with_ubsidi),
            contentDescription = "Logo",
            contentScale = ContentScale.FillHeight,
            modifier = modifier
                .align(Alignment.CenterHorizontally)
                .padding(top = 30.dp)
                .height(83.dp)
        )

        TextComponent(
            text = "Enter your PIN",
            color = MaterialTheme.colorScheme.surfaceDim,
            fontSize = 18.sp,
            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
            modifier = modifier
                .padding(top = 32.dp)
                .align(Alignment.CenterHorizontally)
        )

        NumberPad(
            modifier = modifier
                .padding(top = 32.dp)
                .weight(1f)
                .align(Alignment.CenterHorizontally),
            viewmodel = viewmodel
        )

        TextComponent(
            text = "Forgot PIN",
            fontSize = 14.sp,
            color = MaterialTheme.colorScheme.onPrimary,
            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
            modifier = modifier
                .align(Alignment.CenterHorizontally)
                .padding(top = 32.dp, bottom = 24.dp)
                .clip(RoundedCornerShape(10.dp))
                .clickable {

                }
                .border(1.dp, MaterialTheme.colorScheme.onPrimary, RoundedCornerShape(10.dp))
                .padding(horizontal = 12.dp, vertical = 6.dp)

        )

    }

}