package com.ubsidifinance.ui.recipient_contact

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.model.AccountModel
import com.ubsidifinance.model.state.RecipientContactState
import com.ubsidifinance.model.state.RecipientContactUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class RecipientContactViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(RecipientContactState())
    val uiEvent = _uiState

    init {
        _uiState.value = _uiState.value.copy(
            listOfCategory = getCategoryList(),
            listOfCategoryOriginal = getCategoryList()
        )
    }


    fun onEvent(event: RecipientContactUiState) {
        when (event) {
            is RecipientContactUiState.OnSearchChangeValue -> {
                filterList(event.text)
            }
        }
    }

    private fun filterList(search: String) {

        val list =
            _uiState.value.listOfCategoryOriginal.filter {
                it.fullName.contains(
                    search,
                    true
                ) || it.accountNumber.contains(search, true) ||
                        it.sortCode.contains(search, true)
            }

        _uiState.value = _uiState.value.copy(listOfCategory = list, searchText = search)

    }

    fun getCategoryList(): List<AccountModel> {
        val list = arrayListOf<AccountModel>()

        repeat(10) {

            list.add(
                AccountModel(
                    1,
                    fullName = "Alex King",
                    sortCode = "23-32-32",
                    accountNumber = "31393213"
                )
            )
        }
        return list
    }

}