package com.ubsidifinance.ui.register.business_info

import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.text.KeyboardActions
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.LabelWithTextField
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.BusinessInfoUiState
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.utils.businessInfoScreen
import com.ubsidifinance.utils.directorInfoScreen
import com.ubsidifinance.utils.isResume

@Composable
fun BusinessInfoScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
    viewmodel: BusinessInfoViewmodel = hiltViewModel()
) {

    val indication = remember { MutableInteractionSource() }
    val state = viewmodel.uiEvent.value

    Column(modifier = modifier.padding(24.dp)) {

        Column(modifier = modifier.weight(1f)) {

            HeaderProgress(currentPage = 4)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "Business Information",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Fill in your company details to continue.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            LazyColumn(modifier = modifier.padding(vertical = 24.dp)) {

                item {
                    LabelWithTextField(
                        label = "Company Name or Number",
                        value = state.nameOrNumber,
                        onValueChange = {
                            viewmodel.onEvent(BusinessInfoUiState.OnNameValueChange(it))
                        }
                    )

                    LabelWithTextField(
                        label = "Door Number/Name",
                        modifier = modifier.padding(top = 24.dp),
                        value = state.doorNumber,
                        onValueChange = {
                            viewmodel.onEvent(BusinessInfoUiState.OnDoorNumberValueChange(it))
                        }
                    )

                    Box {
                        Column {
                            LabelWithTextField(
                                label = "Business Postcode",
                                modifier = modifier.padding(top = 24.dp),
                                value = state.postcode,
                                onValueChange = {
                                    viewmodel.onEvent(BusinessInfoUiState.OnPostcodeValueChange(it))
                                }
                            )
                        }

                        TextComponent(
                            text = "Look UP",
                            fontSize = 14.sp,
                            color = blue316AFF,
                            fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold)),
                            modifier = modifier
                                .align(Alignment.CenterEnd)
                                .clickable(
                                    interactionSource = indication,
                                    indication = null,
                                    onClick = {})
                                .padding(top = 45.dp, end = 20.dp)

                        )
                    }

                    TextComponent(
                        text = "Business Address",
                        fontSize = 14.sp,
                        color = MaterialTheme.colorScheme.secondary,
                        modifier = modifier.padding(top = 24.dp),
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W500))
                    )

                    TextFieldComponent(
                        modifier = Modifier
                            .fillMaxWidth()
                            .padding(top = 6.dp),
                        value = state.address,
                        singleLine = false,
                        maxLines = 5,
                        minLines = 5,
                        keyboardOptions = KeyboardOptions(
                            keyboardType = KeyboardType.Text
                        ),
                        onValueChange = {
                            viewmodel.onEvent(BusinessInfoUiState.OnAddressValueChange(it))
                        },
                    )
                }
            }
        }

        ButtonComponent(
            text = "Continue",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = directorInfoScreen
                    navController.navigate(model)
                }
            })
    }

}