package com.ubsidifinance.ui.register.business_type

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color.Companion.Transparent
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.BusinessTypeModel
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.BusinessTypeUiState
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_D9D9D9
import com.ubsidifinance.utils.businessInfoScreen
import com.ubsidifinance.utils.isResume

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun BusinessTypeScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewmodel: BusinessTypeViewmodel = hiltViewModel(),
    registerModel: RegisterModel
) {

    val state = viewmodel.uiEvent.value


    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {

            HeaderProgress(currentPage = 3)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "Select Business Type",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Fill in your company details to continue.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            LazyColumn(modifier = modifier.padding(vertical = 24.dp)) {

                items(state.list, key = { item -> item.id }) {
                    BusinessTypeRow(
                        model = it,
                        onClick = {
                            viewmodel.onEvent(BusinessTypeUiState.OnSelectBusinessChange(it))
                        })
                }
            }

        }

        ButtonComponent(
            text = "Continue",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = businessInfoScreen
                    navController.navigate(model)
                }
            })
    }

}

@Composable
fun BusinessTypeRow(
    modifier: Modifier = Modifier,
    onClick: () -> Unit,
    model: BusinessTypeModel
) {

    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .padding(bottom = 16.dp)
            .border(
                1.dp,
                if (model.isSelected) blue316AFF else grey_D9D9D9,
                RoundedCornerShape(14.dp)
            )
            .clip(RoundedCornerShape(14.dp))
            .clickable(onClick = onClick)
            .padding(horizontal = 20.dp, vertical = 19.dp)
    ) {

        TextComponent(
            modifier = modifier.weight(1f),
            text = model.businessType,
            fontSize = 16.sp,
            color = MaterialTheme.colorScheme.inversePrimary,
            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
        )

        Box(
            modifier = modifier
                .size(20.dp)
                .border(1.dp, if (model.isSelected) blue316AFF else grey_D9D9D9, CircleShape)
                .padding(3.dp)
                .background(if (model.isSelected) blue316AFF else Transparent, CircleShape)
        )
    }

}