package com.ubsidifinance.ui.register.commit

import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.state.CommitUiState
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.privacyPolicy

@Composable
fun CommitScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewModel: CommitViewModel = hiltViewModel()
) {

    val state = viewModel.uiEvent.value
    val interaction = remember { MutableInteractionSource() }

    Column(modifier = modifier.padding(24.dp)) {

        Icon(
            tint = MaterialTheme.colorScheme.onPrimary,
            painter = painterResource(R.drawable.img_app_logo),
            contentDescription = "App Logo",
            modifier = modifier.size(60.dp),
//            contentScale = ContentScale.Fit
        )

        TextComponent(
            text = "Complete your registration In just 4 steps",
            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
            fontSize = 24.sp,
            modifier = modifier.padding(top = 24.dp, bottom = 12.dp),
            color = MaterialTheme.colorScheme.onSecondary
        )

        Column(modifier = modifier.weight(1f)) {
            StepRowDesign(step = "1", des = "Verify your phone number")

            StepRowDesign(step = "2", des = "Submit your business information")

            StepRowDesign(step = "3", des = "Authenticate your identity")

            StepRowDesign(step = "4", des = "Set up your log in information")
        }

        Box(
            modifier = modifier
                .background(
                    MaterialTheme.colorScheme.onSurfaceVariant,
                    RoundedCornerShape(14.dp)
                )
                .padding(12.dp)
        ) {
            Column {

                Row(
                    modifier = modifier.padding(bottom = 10.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Box(
                        contentAlignment = Alignment.Center,
                        modifier = modifier.background(
                            MaterialTheme.colorScheme.onTertiary,
                            CircleShape
                        )
                    ) {
                        Icon(
                            painter = painterResource(R.drawable.ic_shield),
                            contentDescription = null,
                            modifier = modifier.padding(6.dp),
                            tint = MaterialTheme.colorScheme.onPrimary
                        )
                    }

                    TextComponent(
                        text = "Ubsidi is committed to protecting your personal information.",
                        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                        fontSize = 14.sp,
                        modifier = modifier.padding(start = 12.dp),
                        color = MaterialTheme.colorScheme.onSecondary
                    )
                }

                HorizontalDividerComponent(modifier.padding(bottom = 12.dp))

                Row(
                    verticalAlignment = Alignment.CenterVertically,
                    modifier = modifier
                        .padding(start = 12.dp)
                        .clickable(interaction, null, onClick = {
                            viewModel.onEvent(CommitUiState.OnPrivacyChecked)
                        })
                ) {
                    Box(
                        contentAlignment = Alignment.Center,
                        modifier = modifier
                            .size(16.dp)
                            .border(
                                1.dp,
                                MaterialTheme.colorScheme.outline,
                                RoundedCornerShape(4.dp)
                            )
                            .background(
                                if (state.isPrivacyAccept) MaterialTheme.colorScheme.onPrimary else white,
                                RoundedCornerShape(4.dp)
                            )
                    ) {
                        if (state.isPrivacyAccept) {
                            Icon(
                                painter = painterResource(R.drawable.ic_check),
                                contentDescription = null,
                                tint = MaterialTheme.colorScheme.onSurfaceVariant
                            )
                        }
                    }

                    TextComponent(
                        text = privacyPolicy,
                        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                        fontSize = 14.sp,
                        modifier = modifier.padding(start = 12.dp),
                        color = MaterialTheme.colorScheme.onSecondary
                    )
                }
            }
        }

        ButtonComponent(
            modifier = modifier.padding(top = 24.dp),
            enable = state.isPrivacyAccept,
            text = "Next",
            onClick = {
                if (navController.isResume()) {
                    navController.navigate(Screens.PhoneNumber.name)
                }

            })


    }

}

@Composable
fun StepRowDesign(modifier: Modifier = Modifier, step: String, des: String) {

    Row(verticalAlignment = Alignment.CenterVertically) {
        Box(
            modifier = modifier
                .padding(vertical = 8.dp)
                .size(40.dp)
                .background(blue316AFF, CircleShape),
            contentAlignment = Alignment.Center,

            ) {

            TextComponent(
                text = step,
                fontSize = 14.sp,
                color = white,
                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W400))
            )

        }

        TextComponent(
            text = des,
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            fontSize = 14.sp,
            modifier = modifier.padding(start = 12.dp),
            color = MaterialTheme.colorScheme.onSecondary

        )

    }


}