package com.ubsidifinance.ui.register.face_recognize

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Color.Companion.Transparent
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.ui.theme.green_009951
import com.ubsidifinance.ui.theme.red_900B09
import com.ubsidifinance.ui.theme.yellow_F3DC3D
import com.ubsidifinance.utils.capturePhotoScreen
import com.ubsidifinance.utils.isResume

@Composable
fun FaceRecognizeScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
) {
    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            HeaderProgress(currentPage = 9)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        navController.popBackStack()
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "Facial recognition",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            ImageWithBackground(
                modifier = modifier
                    .padding(top = 40.dp)
                    .align(Alignment.CenterHorizontally),
                imageSize = 150.dp
            )

            Row(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 60.dp),
            ) {

                ImageWithText(
                    modifier = modifier.weight(1f),
                    text = "Position your face within the circle",
                    borderColor = green_009951
                )

                Spacer(modifier = modifier.width(16.dp))

                ImageWithText(
                    modifier = modifier.weight(1f),
                    text = "Ensure clear lighting, with no glare",
                )
                Spacer(modifier = modifier.width(16.dp))

                ImageWithText(
                    modifier = modifier.weight(1f),
                    text = "Do not wear sunglasses or a hat",
                    borderColor = red_900B09
                )


            }


        }

        ButtonComponent(
            text = "Start facial recognition",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = capturePhotoScreen
                    navController.navigate(model)
                }
            })
    }
}

@Composable
fun ImageWithBackground(
    modifier: Modifier = Modifier,
    imageSize: Dp,
    borderColor: Color = Transparent
) {
    Box(
        modifier
            .background(yellow_F3DC3D, CircleShape)
            .clip(CircleShape)
            .border(1.dp, borderColor, CircleShape)
    ) {
        Image(
            painter = painterResource(R.drawable.img_character),
            contentDescription = "",
            modifier = Modifier
                .size(imageSize)
                .align(Alignment.BottomCenter)

        )
    }
}

@Composable
fun ImageWithText(
    modifier: Modifier = Modifier,
    text: String,
    borderColor: Color = Transparent
) {
    Column(
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = modifier
    ) {
        ImageWithBackground(
            imageSize = 64.dp,
            borderColor = borderColor
        )

        TextComponent(
            text = text,
            style = TextStyle(
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface,
                fontSize = 14.sp,
                textAlign = TextAlign.Center
            ),
            modifier = Modifier
                .padding(top = 14.dp)
                .align(Alignment.CenterHorizontally)
        )
    }
}