package com.ubsidifinance.ui.register.mobile

import android.content.Context
import android.util.Log
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import com.ubsidifinance.R
import com.ubsidifinance.model.CountryModel
import com.ubsidifinance.model.state.MobileNumberState
import com.ubsidifinance.model.state.MobileNumberUiState
import com.ubsidifinance.utils.getExampleMobileNumber
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class PhoneNumberViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(MobileNumberState())
    val uiEvent = _uiState

    fun onEvent(event: MobileNumberUiState) {
        when (event) {
            is MobileNumberUiState.OnNumberChange -> {
                _uiState.value = _uiState.value.copy(mobileNo = event.mobile)
            }

            is MobileNumberUiState.OnShowCountryDialog -> {
                _uiState.value = _uiState.value.copy(showCountryPicker = event.isShow)
            }

            is MobileNumberUiState.OnCountryValueChange -> {
                filterCountry(event.text)
            }

            is MobileNumberUiState.OnChangeSelectedCountry -> {
                _uiState.value = _uiState.value.copy(selectedCountry = event.countryModel, mobileNo = "")

            }
            else->{

            }
        }
    }

    private fun filterCountry(search: String) {
        val list =
            _uiState.value.countryList.filter {
                it.name.contains(search, true) || it.code.contains(
                    search,
                    true
                ) || it.dial_code.contains(
                    search, true
                )
            }

        _uiState.value = _uiState.value.copy(filterCountryList = list, countrySearch = search)

    }

    fun fetchCountry(context: Context) {
        val jsonString = context.resources.openRawResource(R.raw.country)
            .bufferedReader()
            .use { it.readText() }

        val gson = Gson()
        val type = object : TypeToken<ArrayList<CountryModel>>() {}.type
        val list = gson.fromJson<ArrayList<CountryModel>>(jsonString, type)

        _uiState.value = _uiState.value.copy(
            countryList = list,
            filterCountryList = list,
            selectedCountry = list.first { it -> it.code == "GB" })

    }


}