package com.ubsidifinance.ui.register.preview_document

import android.net.Uri
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import coil3.compose.rememberAsyncImagePainter
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.utils.faceRecognizeScreen
import com.ubsidifinance.utils.isResume
import java.io.File

@Composable
fun PreviewDocumentScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
) {
    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            HeaderProgress(currentPage = 8)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        navController.navigateUp()
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "Please check the photo.",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Make sure your ID information is correct and is clearly visible in the frame.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            LazyColumn(modifier = modifier.padding(vertical = 24.dp)) {
                item {
                    Image(
                        contentDescription = "",
                        painter = rememberAsyncImagePainter(Uri.fromFile(File(registerModel.frontDocument))),
                        contentScale = ContentScale.FillBounds,
                        modifier = modifier
                            .height(200.dp)
                            .fillMaxWidth()
                            .clip(RoundedCornerShape(20.dp))
                    )

                    Image(
                        contentDescription = "",
                        painter = rememberAsyncImagePainter(Uri.fromFile(File(registerModel.backDocument))),
                        contentScale = ContentScale.FillBounds,
                        modifier = modifier
                            .padding(top = 48.dp)
                            .height(200.dp)
                            .fillMaxWidth()
                            .clip(RoundedCornerShape(20.dp))
                    )
                }
            }

        }

        ButtonComponent(
            text = "Confirm",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = faceRecognizeScreen
                    navController.navigate(model)
                }
            })

        ButtonComponent(
            text = "Retake",
            modifier = modifier.padding(top = 16.dp),
            onClick = {
                navController.popBackStack()
                navController.popBackStack()
            },
            colors = ButtonDefaults.buttonColors(
                containerColor = MaterialTheme.colorScheme.surfaceBright,
                contentColor = black1E1E1E,
                disabledContentColor = Color.White,
                disabledContainerColor = MaterialTheme.colorScheme.primary.copy(alpha = 0.5f)
            )
        )

    }
}