package com.ubsidifinance.ui.register.register_id

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.OnboardingModel
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.utils.directorInfoScreen
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.selectIdScreen

@Composable
fun RegisterIdScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
    viewmodel: RegisterIdViewmodel = hiltViewModel()

) {

    val state = viewmodel.uiEvent.value

    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            HeaderProgress(currentPage = 6)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "We need to capture your ID",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Please take a photo of your most recent ID for verification.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            LazyColumn(modifier = modifier.padding(vertical = 24.dp)) {
                items(state.list) {
                    RequiredIdRowItem(model = it)
                }
            }
        }

        ButtonComponent(
            text = "Continue",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = selectIdScreen
                    navController.navigate(model)
                }
            })
    }
}

@Composable
fun RequiredIdRowItem(
    modifier: Modifier = Modifier,
    model: OnboardingModel,
) {
    Column {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier.padding(vertical = 23.dp)
        ) {

            Image(
                painter = painterResource(model.image),
                contentDescription = "",
                modifier = modifier
                    .size(79.dp, 60.dp)
                    .background(MaterialTheme.colorScheme.surfaceBright, RoundedCornerShape(8.dp))
                    .padding(horizontal = 12.dp, vertical = 4.dp)

            )

            TextComponent(
                text = model.title,
                fontSize = 14.sp,
                color = MaterialTheme.colorScheme.onSecondary,
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W500)),
                modifier = modifier.padding(start = 12.dp)
            )


        }

        HorizontalDividerComponent()
    }


}


















