package com.ubsidifinance.ui.register.select_id

import android.Manifest
import android.content.pm.PackageManager
import androidx.activity.compose.rememberLauncherForActivityResult
import androidx.activity.result.contract.ActivityResultContracts
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.saveable.rememberSaveable
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.core.content.ContextCompat
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.dailog.CustomAlertDialog
import com.ubsidifinance.model.OnboardingModel
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.model.state.LoginUiState
import com.ubsidifinance.utils.captureDocumentScreen
import com.ubsidifinance.utils.isResume

@Composable
fun SelectIdScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
    viewmodel: SelectIdViewmodel = hiltViewModel()
) {

    val state = viewmodel.uiEvent.value
    val context = LocalContext.current
    var showRationalDialog by rememberSaveable { mutableStateOf(false) }

    val launcher = rememberLauncherForActivityResult(
        ActivityResultContracts.RequestPermission()
    ) { isGranted: Boolean ->
        if (isGranted) {
            if (navController.isResume()) {
                val model = registerModel
                model.type = captureDocumentScreen
                navController.navigate(model)
            }
        } else {
            showRationalDialog = true
        }
    }

    if (showRationalDialog) {
        CustomAlertDialog(
            title = "Allow camera access",
            text = "To capture and verify your documents, we need access to your device’s camera.",
            onDismissRequest = {
                showRationalDialog = false
            }, onConfirmation = {

            })
    }

    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            HeaderProgress(currentPage = 7)

            Icon(
                painter = painterResource(R.drawable.ic_back_arrow),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 16.dp)
                    .size(24.dp)
                    .padding(5.dp)
                    .clickable {
                        if (navController.isResume()) {
                            navController.popBackStack()
                        }
                    },
                tint = MaterialTheme.colorScheme.inversePrimary
            )

            TextComponent(
                text = "Select ID to upload",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Choose which ID you wish to upload.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            LazyColumn(modifier = modifier.padding(vertical = 24.dp)) {
                items(state.list) {
                    SelectIdRowItem(model = it)
                }
            }
        }

        ButtonComponent(
            text = "Continue",
            onClick = {

                when (PackageManager.PERMISSION_GRANTED) {
                    ContextCompat.checkSelfPermission(
                        context, Manifest.permission.CAMERA
                    ) -> {
                        val model = registerModel
                        model.type = captureDocumentScreen
                        navController.navigate(model)
                    }

                    else -> {
                        launcher.launch(Manifest.permission.CAMERA)
                    }
                }

            })
    }
}

@Composable
fun SelectIdRowItem(
    modifier: Modifier = Modifier,
    model: OnboardingModel,
) {
    Column {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier.padding(vertical = 16.dp)
        ) {

            Image(
                painter = painterResource(model.image),
                contentDescription = "",
                modifier = modifier
                    .size(79.dp, 60.dp)
                    .background(MaterialTheme.colorScheme.surfaceBright, RoundedCornerShape(8.dp))
                    .padding(horizontal = 12.dp, vertical = 4.dp)
            )

            TextComponent(
                text = model.title,
                fontSize = 14.sp,
                color = MaterialTheme.colorScheme.onSecondary,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.Bold)),
                modifier = modifier.padding(start = 12.dp)
            )


        }

        HorizontalDividerComponent()
    }


}
