package com.ubsidifinance.ui.register.setup_pin

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.HeaderProgress
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.pin.NumberPad
import com.ubsidifinance.ui.pin.PinViewmodel
import com.ubsidifinance.utils.isResume

@Composable
fun ConfirmPinScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel,
    viewModel: PinViewmodel = hiltViewModel()
) {
    val state = viewModel.uiEvent.value
    Column(modifier = modifier.padding(24.dp)) {
        Column(modifier = modifier.weight(1f)) {
            HeaderProgress(currentPage = 11)

            Icon(
                painter = painterResource(R.drawable.img_app_logo),
                contentDescription = null,
                modifier = modifier
                    .padding(top = 10.dp)
                    .size(52.dp)
                    .clickable {
                        navController.popBackStack()
                    },
                tint = MaterialTheme.colorScheme.primary
            )

            TextComponent(
                text = "Confirm your 6 digit PIN",
                color = MaterialTheme.colorScheme.surfaceDim,
                fontSize = 24.sp,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier
                    .padding(top = 24.dp)
                    .align(Alignment.CenterHorizontally)
            )

            NumberPad(
                modifier = modifier
                    .padding(top = 32.dp)
                    .weight(1f)
                    .align(Alignment.CenterHorizontally),
                viewmodel = viewModel,
                isShowBioMetric = false
            )
        }

        ButtonComponent(
            enable = state.pin == registerModel.pin,
            modifier = modifier.padding(top = 24.dp),
            text = "Confirm",
            onClick = {
                if (navController.isResume()) {
                    navController.navigate(Screens.SuccessRegisterScreen.name){
                        popUpTo(Screens.Login.name){
                            inclusive = false
                        }
                    }
                }
            }
        )
    }
}