package com.ubsidifinance.ui.register.verify_document

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.RegisterModel
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.setNewPasswordScreen

@Composable
fun VerifyDocumentScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    registerModel: RegisterModel
) {
    Column(
        modifier = modifier
            .fillMaxSize()
            .padding(24.dp)
    ) {
        Column(modifier = modifier.weight(1f)) {

            Spacer(modifier.height(45.dp))

            TextComponent(
                text = "Hold on a moment...",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 24.dp),
                fontSize = 24.sp,
                color = MaterialTheme.colorScheme.onSecondary
            )

            TextComponent(
                text = "Please wait while we verify your ID. You will get notified when it is complete.",
                fontSize = 14.sp,
                modifier = modifier.padding(top = 8.dp),
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            Image(
                modifier = modifier
                    .padding(top = 24.dp)
                    .height(200.dp)
                    .align(Alignment.CenterHorizontally),
                painter = painterResource(R.drawable.img_waiting_document),
                contentDescription = ""
            )

            Spacer(modifier.height(18.dp))

            VerifyIdItemRow(text = "Documents have been uploaded")
            VerifyIdItemRow(text = "Documents accepted")
            VerifyIdItemRow(text = "Selfie accepted")
        }

        ButtonComponent(
            text = "Complete Registration",
            onClick = {
                if (navController.isResume()) {
                    val model = registerModel
                    model.type = setNewPasswordScreen
                    model.isFromRegister = true
                    navController.navigate(model)
                }
            }
        )
    }
}

@Composable
fun VerifyIdItemRow(modifier: Modifier = Modifier, text: String) {

    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier.padding(vertical = 8.dp)
    ) {
        Icon(
            painter = painterResource(R.drawable.ic_check),
            contentDescription = "",
            modifier = modifier
                .background(blue316AFF, CircleShape)
                .padding(6.dp)
                .size(18.dp),
            tint = white,
        )

        TextComponent(
            text = text,
            fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
            modifier = modifier.padding(start = 12.dp),
            color = MaterialTheme.colorScheme.onSecondary,
            fontSize = 14.sp
        )

    }
}