package com.ubsidifinance.ui.register.verify_mobile

import android.annotation.SuppressLint
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.ubsidifinance.model.state.VerifyMobileState
import com.ubsidifinance.model.state.VerifyMobileUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.Job
import kotlinx.coroutines.delay
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class VerifyMobileViewmodel @Inject constructor() : ViewModel() {
    private val _uiState = mutableStateOf(VerifyMobileState())
    val uiEvent = _uiState
    var job: Job? = null

    fun onEvent(event: VerifyMobileUiState) {

        when (event) {
            VerifyMobileUiState.OnTimerStart -> {
                startTimerJob()
            }

            is VerifyMobileUiState.OnButtonEnable -> {
                _uiState.value = _uiState.value.copy(isEnableButton = event.isEnable)
            }

            VerifyMobileUiState.OnPasswordVisibilityChange -> {
                _uiState.value =
                    _uiState.value.copy(isVisiblePassword = !_uiState.value.isVisiblePassword)
            }

            VerifyMobileUiState.OnConfirmPasswordVisibilityChange -> {
                _uiState.value =
                    _uiState.value.copy(isVisibleConfirmPassword = !_uiState.value.isVisibleConfirmPassword)
            }

            is VerifyMobileUiState.OnPasswordChange -> {
                _uiState.value =
                    _uiState.value.copy(
                        password = event.text,
                        isEnableButton = event.text == _uiState.value.password
                    )
            }

            is VerifyMobileUiState.OnConfirmPasswordChange -> {
                _uiState.value =
                    _uiState.value.copy(
                        confirmPassword = event.text,
                        isEnableButton = _uiState.value.password == event.text
                    )
            }
        }

    }

    @SuppressLint("DefaultLocale")
    private fun startTimerJob() {
        job?.cancel()
        job = viewModelScope.launch {
            for (i in 30 downTo 0) {
                _uiState.value = _uiState.value.copy(
                    timer = "00:${String.format("%02d", i)}",
                    isTimerRunning = true
                )
                delay(1000L)
            }
            _uiState.value = _uiState.value.copy(isTimerRunning = false)
        }

    }

}