package com.ubsidifinance.ui.request_amount

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.navigation.RequestAmount
import com.ubsidifinance.navigation.RequestSuccessOrFail
import com.ubsidifinance.ui.confirm_request.ConfirmRequestDialog
import com.ubsidifinance.ui.share_account_detail.ShareAccountDetailsDialog
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.ui.transfer.AmountTextField
import com.ubsidifinance.utils.isResume

@Composable
fun RequestAmountScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
) {

    val scrollSate = rememberScrollState()
    var amount by remember { mutableStateOf("") }
    var isShowShareDialog by remember { mutableStateOf(false) }
    var isShowConfirmRequestDialog by remember { mutableStateOf(false) }

    if (isShowShareDialog) {
        ShareAccountDetailsDialog(
            onDismissRequest = {
                isShowShareDialog = false
            },
            onConfirmation = {

            }
        )
    }

    if (isShowConfirmRequestDialog) {
        ConfirmRequestDialog(
            onDismissRequest = {
                isShowConfirmRequestDialog = false
            },
            onConfirmation = {
                if (navController.isResume()) {
                    navController.navigate(RequestSuccessOrFail) {
                        popUpTo(RequestAmount) {
                            inclusive = true
                        }
                    }
                }
            }
        )
    }

    Column(
        modifier =
            modifier
                .padding(horizontal = 24.dp)
                .padding(bottom = 24.dp)
    ) {

        ActionBarWithBackButton(
            onBack = {
                if (navController.isResume()) {
                    navController.popBackStack()
                }
            },
            title = "Request"
        )

        Column(
            modifier
                .weight(1f)
                .fillMaxSize()
                .verticalScroll(scrollSate)
                .padding(vertical = 24.dp)
        ) {

            TextComponent(
                text = "Request amount",
                modifier = modifier.align(Alignment.CenterHorizontally),
                color = grey_9499A5,
                fontSize = 12.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_regular, FontWeight.W400)
                )
            )

            AmountTextField(text = amount) {
                if (it.length <= 5) {
                    amount = it
//                    viewmodel.onEvent(TransferUiState.OnAmountChange(it))
                }

            }

            TextComponent(
                text = "Share Account Details",
                modifier = modifier
                    .padding(top = 24.dp)
                    .border(1.dp, blue316AFF, RoundedCornerShape(10.dp))
                    .clip(RoundedCornerShape(10.dp))
                    .align(Alignment.CenterHorizontally)
                    .clickable(onClick = {
                        isShowShareDialog = true
                    })
                    .padding(vertical = 5.dp, horizontal = 12.dp),
                color = blue316AFF,
                fontSize = 14.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_medium, FontWeight.W500)
                )
            )


            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp)
                    .shadow(0.5.dp, RoundedCornerShape(20.dp))
                    .background(
                        MaterialTheme.colorScheme.primaryContainer,
                        RoundedCornerShape(20.dp)
                    )
                    .padding(20.dp)
            ) {
                TextComponent(
                    text = "Request to",
                    modifier = modifier,
                    color = grey_9499A5,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W500)
                    )
                )


                Row(
                    modifier = modifier
                        .padding(top = 12.dp)
                        .padding(vertical = 6.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {

                    TextComponent(
                        text = "JA",
                        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                        modifier = modifier
                            .background(grey_F9F9F9, CircleShape)
                            .padding(10.dp),
                        fontSize = 14.sp,
                        color = grey_9499A5
                    )

                    TextComponent(
                        text = "Jamal Ahmed (Admin)",
                        modifier = modifier.padding(start = 12.dp),
                        color = MaterialTheme.colorScheme.inversePrimary,
                        fontSize = 14.sp,
                        fontFamily = FontFamily(
                            Font(R.font.inter_semi_bold, FontWeight.W600)
                        )
                    )

                }

            }

            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 12.dp)
                    .shadow(0.5.dp, RoundedCornerShape(20.dp))
                    .background(
                        MaterialTheme.colorScheme.primaryContainer,
                        RoundedCornerShape(20.dp)
                    )
                    .padding(20.dp)
            ) {
                TextComponent(
                    text = "To account",
                    modifier = modifier,
                    color = grey_9499A5,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W500)
                    )
                )


                Row(
                    modifier = modifier
                        .padding(top = 12.dp)
                        .background(
                            MaterialTheme.colorScheme.onPrimaryContainer,
                            RoundedCornerShape(12.dp)
                        )
                        .padding(10.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {

                    Image(
                        painter = painterResource(R.drawable.img_app_logo),
                        contentDescription = "",
                        modifier = modifier
                            .size(36.dp)
                            .background(blue316AFF, CircleShape)
                            .padding(2.dp)
                    )

                    Row(modifier = modifier.weight(1f)) {
                        Column {
                            TextComponent(
                                text = "Nibs Solutions Ltd",
                                modifier = modifier.padding(start = 16.dp),
                                color = MaterialTheme.colorScheme.inversePrimary,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_semi_bold, FontWeight.W600)
                                )
                            )

                            TextComponent(
                                text = "20-23-23",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )

                            TextComponent(
                                text = "24455423",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )
                        }
                    }

                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Column {
                            TextComponent(
                                text = "Available",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )
                            TextComponent(
                                text = "£22,432",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = MaterialTheme.colorScheme.inversePrimary,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_bold, FontWeight.W700)
                                )
                            )
                        }

                        Icon(
                            painter = painterResource(R.drawable.ic_down_arrow),
                            contentDescription = null,
                            tint = grey_9499A5,
                            modifier = modifier
                                .padding(start = 10.dp)
                                .size(16.dp)
                                .padding(2.dp)
                                .align(Alignment.CenterVertically)
                        )
                    }

                }

            }
        }

        ButtonComponent(
            text = "Continue",
            onClick = {
                isShowConfirmRequestDialog = true
            }
        )
    }

}