package com.ubsidifinance.ui.select_card

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.IntrinsicSize
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.blur
import androidx.compose.ui.draw.clip
import androidx.compose.ui.graphics.Color.Companion.Transparent
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.CardDetailModel
import com.ubsidifinance.ui.theme.black232323
import com.ubsidifinance.ui.theme.black2C2C2C
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_D9D9D9
import com.ubsidifinance.ui.theme.transparent
import com.ubsidifinance.ui.theme.white

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun SelectCardScreen(
    modifier: Modifier = Modifier,
    onDismissRequest: () -> Unit,
    onConfirmRequest: () -> Unit,
) {

    val interaction = remember { MutableInteractionSource() }

    BaseBottomSheetDialog(onDismiss = onDismissRequest) {
        Column(modifier = modifier.padding(32.dp)) {

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .fillMaxWidth()
                    .padding(bottom = 12.dp),
                horizontalArrangement = Arrangement.SpaceBetween
            ) {
                TextComponent(
                    text = "Select Card",
                    fontSize = 22.sp,
                    fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                    color = MaterialTheme.colorScheme.surface
                )

                Icon(
                    painter = painterResource(R.drawable.ic_close),
                    contentDescription = "Close Button",
                    modifier = modifier
                        .clip(CircleShape)
                        .clickable(
                            indication = null,
                            interactionSource = interaction,
                            onClick = onDismissRequest
                        )
                        .size(20.dp)
                        .padding(4.dp),
                    tint = MaterialTheme.colorScheme.inversePrimary
                )
            }

            LazyColumn {
                items(3) {
                    RowSelectCardItem(
                        model = CardDetailModel(
                            id = 1,
                            cardNumber = "**** **** **** 772$it",
                            name = "Sachin",
                            expiry = "0$it/27",
                            cardLastNumber = "772$it",
                            isSelected = it == 2,
                        ),
                        onClick = {
                            onDismissRequest.invoke()
                            onConfirmRequest.invoke()
                        }
                    )
                }
            }
        }
    }
}

@Composable
fun RowSelectCardItem(
    modifier: Modifier = Modifier,
    model: CardDetailModel,
    onClick: () -> Unit = {}
) {

    Row(
        verticalAlignment = Alignment.CenterVertically,
        modifier = modifier
            .clickable(onClick = onClick)
            .padding(vertical = 12.dp)
    ) {
        Surface(
            color = transparent,
            shape = RoundedCornerShape(5.dp), tonalElevation = 4.dp,
            shadowElevation = 10.dp,
        ) {
            Column(
                modifier
                    .size(100.dp, 65.dp)
                    .background(black232323, RoundedCornerShape(5.dp))
            ) {
                Column(
                    modifier
                        .padding(horizontal = 7.dp)
                        .padding(top = 7.dp, bottom = 3.dp)
                ) {

                    Row(
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.Absolute.SpaceBetween,
                        modifier = modifier
                            .fillMaxWidth()
                    ) {
                        Image(
                            painter = painterResource(R.drawable.ic_visa),
                            contentDescription = "Card Type",
                            modifier = modifier.size(12.dp, 5.dp),
                            contentScale = ContentScale.Fit
                        )

                        Image(
                            painter = painterResource(R.drawable.img_ubsidi_logo),
                            contentDescription = "Ubsidi Logo",
                            modifier = modifier.size(19.dp, 8.dp)
                        )

                    }

                    TextComponent(
                        text = model.cardNumber,
                        fontSize = 6.sp,
                        color = white,
                        modifier = modifier
                            .align(Alignment.End)
                            .padding(top = 27.dp),
                        fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                    )
                }

                Box(
                    modifier
                        .fillMaxWidth()
                        .height(IntrinsicSize.Min)
                        .background(
                            black2C2C2C,
                            RoundedCornerShape(bottomEnd = 5.dp, bottomStart = 5.dp)
                        )
                ) {

                    Box(
                        modifier = modifier
                            .fillMaxWidth()
                            .fillMaxHeight()
                            .blur(10.dp)
                    )

                    Row(
                        verticalAlignment = Alignment.CenterVertically,
                        horizontalArrangement = Arrangement.Absolute.SpaceBetween,
                        modifier = modifier
                            .fillMaxWidth()
                            .padding(horizontal = 7.dp, vertical = 4.dp)
                    ) {

                        TextComponent(
                            text = model.name,
                            color = white,
                            fontSize = 5.sp,
                            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                        )

                        TextComponent(
                            text = model.expiry,
                            color = white,
                            fontSize = 5.sp,
                            fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600))
                        )

                    }
                }
            }
        }

        Column(
            modifier = modifier
                .padding(start = 30.dp)
                .weight(1f)
        ) {
            TextComponent(
                text = model.name,
                fontSize = 12.sp,
                color = MaterialTheme.colorScheme.surface,
                fontFamily = FontFamily(
                    Font(
                        R.font.inter_bold,
                        FontWeight.W600
                    )
                )
            )

            TextComponent(
                text = "Card Ending " + model.cardLastNumber,
                fontSize = 12.sp,
                color = MaterialTheme.colorScheme.surface,
                modifier = modifier.padding(top = 4.dp),
                fontFamily = FontFamily(
                    Font(
                        R.font.inter_medium,
                        FontWeight.W400
                    )
                )
            )
        }

        Box(
            modifier = modifier
                .size(20.dp)
                .border(2.dp, if (model.isSelected) blue316AFF else grey_D9D9D9, CircleShape)
                .padding(4.dp)
                .background(if (model.isSelected) blue316AFF else Transparent, CircleShape)
        )

    }


}