package com.ubsidifinance.ui.share_account_detail

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.platform.LocalClipboardManager
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R
import com.ubsidifinance.base.BaseBottomSheetDialog
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.utils.showToast

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun ShareAccountDetailsDialog(
    modifier: Modifier = Modifier,
    onDismissRequest: () -> Unit,
    onConfirmation: () -> Unit,
) {

    val interactionSource = remember { MutableInteractionSource() }

    BaseBottomSheetDialog(onDismiss = onDismissRequest) {

        Column(
            modifier = modifier
                .padding(24.dp)
                .fillMaxWidth()
        ) {

            HorizontalDividerComponent(
                thickness = 6.dp, modifier = modifier
                    .width(50.dp)
                    .clip(CircleShape)
                    .align(Alignment.CenterHorizontally)
            )

            TextComponent(
                text = "Share Account Details",
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier
                    .padding(top = 24.dp)
                    .align(Alignment.CenterHorizontally),
                fontSize = 18.sp,
                color = MaterialTheme.colorScheme.surfaceDim
            )

            TextComponent(
                text = "Use your account details to receive money from other UK bank accounts.",
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                modifier = modifier.padding(top = 15.dp),
                fontSize = 16.sp,
                color = MaterialTheme.colorScheme.inverseOnSurface
            )

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .align(Alignment.End)
                    .padding(vertical = 24.dp)
                    .clickable(
                        onClick = {},
                        interactionSource = interactionSource,
                        indication = null
                    )
            ) {

                TextComponent(
                    text = "Share",
                    fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                    modifier = modifier
                        .padding(end = 6.dp),
                    fontSize = 16.sp,
                    color = blue316AFF
                )

                Icon(
                    modifier = Modifier.size(20.dp),
                    painter = painterResource(R.drawable.ic_share),
                    contentDescription = "",
                    tint = blue316AFF
                )

            }

            RowCopyItem(title = "Account Holder Name", text = "Nibs Solutions Ltd")

            Spacer(modifier.height(24.dp))

            RowCopyItem(title = "Sort Code", text = "20-23-23")

            Spacer(modifier.height(24.dp))

            RowCopyItem(title = "Account Number", text = "24455423")
        }
    }
}

@Composable
fun RowCopyItem(
    modifier: Modifier = Modifier,
    title: String,
    text: String
) {

    val interactionSource = remember { MutableInteractionSource() }
    val clipboardManager = LocalClipboardManager.current
    val context = LocalContext.current

    Row(
        modifier = modifier
            .background(grey_F9F9F9, RoundedCornerShape(10.dp))
            .padding(horizontal = 20.dp, vertical = 10.dp),
        verticalAlignment = Alignment.CenterVertically
    ) {
        Column(modifier = modifier.weight(1f)) {
            TextComponent(
                text = title,
                fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400)),
                modifier = modifier,
                fontSize = 12.sp,
                color = grey_9499A5
            )

            TextComponent(
                text = text,
                fontFamily = FontFamily(Font(R.font.inter_semi_bold, FontWeight.W600)),
                modifier = modifier.padding(top = 4.dp),
                fontSize = 14.sp,
                color = black1E1E1E
            )
        }

        Icon(
            modifier = Modifier
                .size(24.dp)
                .clickable(interactionSource = interactionSource, indication = null, onClick = {
                    clipboardManager.setText(AnnotatedString(text))
                    context.showToast("Copied to clipboard")
                }),
            painter = painterResource(R.drawable.ic_copy),
            contentDescription = "",
            tint = blue316AFF
        )
    }

}