package com.ubsidifinance.ui.splash

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavHostController
import com.ubsidifinance.R
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.model.state.SplashScreenState
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.ui.theme.white
import kotlinx.coroutines.flow.collectLatest

@Composable
fun SplashScreen(
    modifier: Modifier = Modifier,
    navController: NavHostController,
    viewModel: SplashViewModel = hiltViewModel()
) {

    LaunchedEffect(true) {
        viewModel.state.collectLatest {
            when (it) {
                is SplashScreenState.NavigateToNextScreen -> {
                    navController.navigate(it.route) {
                        popUpTo(Screens.Splash.name) {
                            inclusive = true
                        }
                    }
                }
            }
        }
    }

    Scaffold { innerPadding ->
        Box(
            modifier = modifier
                .fillMaxSize()
                .background(MaterialTheme.colorScheme.onBackground)
                .padding(innerPadding),
            contentAlignment = Alignment.Center
        ) {

            Column(horizontalAlignment = Alignment.CenterHorizontally) {

                Image(
                    painter = painterResource(R.drawable.img_app_logo),
                    contentDescription = "App Logo"
                )

                Image(
                    painter = painterResource(R.drawable.img_ubsidi_logo),
                    contentDescription = "Ubsidi Logo",
                    modifier = modifier
                        .padding(top = 12.dp)
                        .width(108.dp)
                        .height(41.dp),
                    contentScale = ContentScale.FillBounds
                )

                TextComponent(
                    text = "Finance",
                    style = MaterialTheme.typography.headlineMedium,
                    modifier = modifier.padding(top = 5.dp)
                )
            }

            CircularProgressIndicator(
                modifier = Modifier
                    .padding(bottom = 60.dp)
                    .width(42.dp)
                    .align(Alignment.BottomCenter),
                color = white,
                trackColor = white.copy(alpha = 0.5f),
            )
        }
    }

}