package com.ubsidifinance.ui.splash

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.ubsidifinance.model.state.SplashScreenEvent
import com.ubsidifinance.model.state.SplashScreenState
import com.ubsidifinance.navigation.Screens
import com.ubsidifinance.utils.Preferences
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.delay
import kotlinx.coroutines.flow.MutableSharedFlow
import kotlinx.coroutines.flow.asSharedFlow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class SplashViewModel @Inject constructor(preferences: Preferences) : ViewModel() {

    private val _state = MutableSharedFlow<SplashScreenState>()
    val state = _state.asSharedFlow()

    init {

        onEvent(SplashScreenEvent.OnNextScreen(if (preferences.isBoardingScreen) Screens.OnBoarding.name else Screens.Login.name))
    }

    fun onEvent(event: SplashScreenEvent) {
        when (event) {
            is SplashScreenEvent.OnNextScreen -> {
                viewModelScope.launch {
                    delay(3000)
                    _state.emit(SplashScreenState.NavigateToNextScreen(event.route))
                }
            }
        }
    }

}