package com.ubsidifinance.ui.theme

import android.os.Build
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.darkColorScheme
import androidx.compose.material3.dynamicDarkColorScheme
import androidx.compose.material3.dynamicLightColorScheme
import androidx.compose.material3.lightColorScheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.platform.LocalContext

private val DarkColorScheme = darkColorScheme(
    primary = blue316AFF,
    secondary = white,
    tertiary = black232323,
    background = black111315,
    onBackground = black111315,
    inversePrimary = white,
    scrim = grey_676767,
    surface = grey_D9D9D9,
    surfaceBright = white,
    surfaceDim = white,
    outlineVariant = grey_D9D9D9,
    tertiaryContainer = black131313,
    onPrimary = white,
    onSecondary = white,
    onSurfaceVariant = black171717,
    onTertiary = black282828,
    outline = black171717,
    surfaceContainerLow = black333333,
    inverseOnSurface = white,
    primaryContainer = black171717,
    onPrimaryContainer = black111315,
    onSurface = black2C2C2C,
    inverseSurface = black232323,
    surfaceContainerHigh = white
)

private val LightColorScheme = lightColorScheme(
    primary = blue316AFF,
    secondary = black0A0E19,
    tertiary = white,
    background = white,
    onBackground = blue316AFF,
    inversePrimary = black232323,
    scrim = grey_B3B3B3,
    surface = black1E1E1E,
    surfaceBright = grey_F5F5F5,
    surfaceDim = blue17223C,
    outlineVariant = grey_F4F4F4,
    tertiaryContainer = grey_F9F9F9,
    onPrimary = blue316AFF,
    onSecondary = black1E1E1E,
    onSurfaceVariant = grey_F5F5F5,
    onTertiary = grey_D9D9D9,
    outline = grey_757575,
    surfaceContainerLow = grey_D9D9D9,
    inverseOnSurface = grey_757575,
    onTertiaryContainer = black2C2C2C,
    primaryContainer = white,
    onPrimaryContainer = grey_F5F5F5,
    onSurface = grey_F5F5F5,
    inverseSurface = blue316AFF,
    surfaceContainerHigh = black303030


    /* Other default colors to override
    background = Color(0xFFFFFBFE),
    surface = Color(0xFFFFFBFE),
    onPrimary = Color.White,
    onSecondary = Color.White,
    onTertiary = Color.White,
    onBackground = Color(0xFF1C1B1F),
    onSurface = Color(0xFF1C1B1F),
    */
)

@Composable
fun UbsidiFinanceTheme(
    darkTheme: Boolean = isSystemInDarkTheme(),
    // Dynamic color is available on Android 12+
    dynamicColor: Boolean = false,
    content: @Composable () -> Unit
) {
    val colorScheme = when {
        dynamicColor && Build.VERSION.SDK_INT >= Build.VERSION_CODES.S -> {
            val context = LocalContext.current
            if (darkTheme) dynamicDarkColorScheme(context) else dynamicLightColorScheme(context)
        }

        darkTheme -> DarkColorScheme
        else -> LightColorScheme
    }

    MaterialTheme(
        colorScheme = colorScheme,
        typography = Typography,
        shapes = shapes,
        content = content
    )
}