package com.ubsidifinance.ui.theme

import androidx.compose.foundation.shape.GenericShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Shapes
import androidx.compose.material3.Typography
import androidx.compose.ui.geometry.CornerRadius
import androidx.compose.ui.geometry.Rect
import androidx.compose.ui.geometry.RoundRect
import androidx.compose.ui.graphics.Path
import androidx.compose.ui.graphics.Shape
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.ubsidifinance.R

val Typography = Typography(
    bodyLarge = TextStyle(
        fontFamily = FontFamily.Default,
        fontWeight = FontWeight.Normal,
        fontSize = 16.sp,
        lineHeight = 24.sp,
        letterSpacing = 0.5.sp
    ),
    titleLarge = TextStyle(
        fontSize = 32.sp,
        fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.Bold))
    ),
    headlineLarge = TextStyle(
        fontSize = 32.sp,
        fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.Bold))
    ),
    headlineMedium = TextStyle(
        fontSize = 20.sp,
        letterSpacing = 0.0.sp,
        color = white,
        fontFamily = FontFamily(Font(R.font.visbycf_medium, FontWeight.Bold))
    ),
    bodyMedium = TextStyle(
        fontSize = 16.sp,
        letterSpacing = 0.0.sp,
        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W400))
    ),
    labelSmall = TextStyle(
        fontSize = 14.sp,
        letterSpacing = 0.0.sp,
        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W500))
    ),
    bodySmall = TextStyle(
        fontSize = 14.sp,
        letterSpacing = 0.0.sp,
        textAlign = TextAlign.Start,
        fontFamily = FontFamily(Font(R.font.inter_regular, FontWeight.W500))
    )
    /* Other default text styles to override
    titleLarge = TextStyle(
        fontFamily = FontFamily.Default,
        fontWeight = FontWeight.Normal,
        fontSize = 22.sp,
        lineHeight = 28.sp,
        letterSpacing = 0.sp
    ),
    labelSmall = TextStyle(
        fontFamily = FontFamily.Default,
        fontWeight = FontWeight.Medium,
        fontSize = 11.sp,
        lineHeight = 16.sp,
        letterSpacing = 0.5.sp
    )
    */
)

val TopBottomCutCircleShape: Shape = GenericShape { size, _ ->
    val path = Path().apply {
        addRoundRect(
            RoundRect(
                rect = Rect(0f, 0f, size.width, size.height),
                topLeft = CornerRadius(0f, 0f),
                topRight = CornerRadius(0f, 0f),
                bottomLeft = CornerRadius(size.width / 2, size.height / 2),
                bottomRight = CornerRadius(size.width / 2, size.height / 2)
            )
        )
    }
    addPath(path)
}

val shapes = Shapes(
    extraSmall = RoundedCornerShape(14.dp),
    small = RoundedCornerShape(8.dp),
    medium = RoundedCornerShape(16.dp),
    large = RoundedCornerShape(24.dp),
    extraLarge = RoundedCornerShape(40.dp)
)
