package com.ubsidifinance.ui.transaction

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.R
import com.ubsidifinance.model.TransactionList
import com.ubsidifinance.model.TransactionModel
import com.ubsidifinance.model.state.SearchTransactionState
import com.ubsidifinance.model.state.SearchTransactionUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject
import kotlin.random.Random

@HiltViewModel
class SearchTransactionViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(SearchTransactionState())
    val uiEvent = _uiState

    init {
        _uiState.value = _uiState.value.copy(listOfTransaction = getTransactionList())
    }

    fun onEvent(event: SearchTransactionUiState) {
        when (event) {
            is SearchTransactionUiState.OnSearchTextChange -> {
                _uiState.value = _uiState.value.copy(searchQuery = event.text)
            }

            is SearchTransactionUiState.FilterDialog -> {
                _uiState.value = _uiState.value.copy(isShowFilterDialog = event.isShow)
            }
        }

    }


    fun getTransactionList(): List<TransactionModel> {
        val list = arrayListOf<TransactionModel>()
        val subList = arrayListOf<TransactionList>()

        repeat(3) {
            subList.add(
                TransactionList(
                    it,
                    transactionName = "HSBC $it",
                    transactionDetail = "Payment for invoice #12345.",
                    image = R.drawable.img_hsbc_bank_logo,
                    amount = 100f,
                    isCredit = Random.nextBoolean()
                )
            )
        }

        list.add(
            TransactionModel(
                date = "Today",
                listOfTransaction = subList
            )
        )

        list.add(
            TransactionModel(
                date = "Tomorrow",
                listOfTransaction = subList
            )
        )

        list.add(
            TransactionModel(
                date = "16 May 2024",
                listOfTransaction = subList
            )
        )

        return list
    }

}