package com.ubsidifinance.ui.transaction.filter_transaction

import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import com.ubsidifinance.model.RadioButtonModel
import com.ubsidifinance.model.state.TransactionFilterState
import com.ubsidifinance.model.state.TransactionFilterUiState
import dagger.hilt.android.lifecycle.HiltViewModel
import javax.inject.Inject

@HiltViewModel
class TransactionFilterViewmodel @Inject constructor() : ViewModel() {

    private val _uiState = mutableStateOf(TransactionFilterState())
    val uiEvent = _uiState

    init {
        _uiState.value = _uiState.value.copy(
            listOfTransactionType = listOf("All", "Credits", "Debits"),
            listOfDateRange = getDateRangeList()
        )
    }

    fun onEvent(event: TransactionFilterUiState) {
        when (event) {

            is TransactionFilterUiState.OnSelectedIndexChange -> {
                _uiState.value = _uiState.value.copy(selectedTransactionIndex = event.index)
            }

            is TransactionFilterUiState.OnSelectedDateRangChange -> {
                val list = _uiState.value.listOfDateRange
                val newList = list.map { it.copy(isSelected = it.id == event.model.id) }
                _uiState.value = _uiState.value.copy(
                    listOfDateRange = newList,
                    isDateRange = event.model.id == 4
                )
            }

            is TransactionFilterUiState.OnDatePicker -> {

                _uiState.value = _uiState.value.copy(
                    isShowDatePicker = event.isShow,
                    isFromDate = event.isFromDate
                )
            }

            is TransactionFilterUiState.OnDateChange -> {
                if (event.isFromDate) {
                    _uiState.value = _uiState.value.copy(dateFrom = event.date)
                } else {
                    _uiState.value = _uiState.value.copy(dateTo = event.date)
                }
            }

            is TransactionFilterUiState.OnMinTransactionChange -> {
                _uiState.value = _uiState.value.copy(minTransaction = event.text)
            }

            is TransactionFilterUiState.OnMaxTransactionChange -> {
                _uiState.value = _uiState.value.copy(maxTransaction = event.text)
            }

            is TransactionFilterUiState.OnCategoryDialog -> {
                _uiState.value = _uiState.value.copy(isShowCategoryDialog = event.isShow)
            }

            is TransactionFilterUiState.OnCategoryChange -> {
                _uiState.value = _uiState.value.copy(selectedCategory = event.model)
            }
        }
    }

    private fun getDateRangeList(): List<RadioButtonModel> {
        val list = arrayListOf<RadioButtonModel>()

        list.add(RadioButtonModel(1, title = "Entire History", isSelected = true))
        list.add(RadioButtonModel(2, title = "Last 30 Days", isSelected = false))
        list.add(RadioButtonModel(3, title = "Last 90 Days", isSelected = false))
        list.add(RadioButtonModel(4, title = "Date Range", isSelected = false))

        return list
    }

}