package com.ubsidifinance.ui.transaction_detail

import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.em
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.BarChart
import com.ubsidifinance.component.HorizontalDividerComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.ui.theme.black0A0E19
import com.ubsidifinance.ui.theme.black1E1E1E
import com.ubsidifinance.ui.theme.black2C2C2C
import com.ubsidifinance.ui.theme.grey_757575
import com.ubsidifinance.ui.theme.grey_F5F5F5
import com.ubsidifinance.ui.theme.red_C00F0C
import com.ubsidifinance.utils.isResume

@Composable
fun TransactionDetailScreen(
    modifier: Modifier = Modifier,
    navController: NavController
) {

    var isExpandedDropdown by remember { mutableStateOf(false) }

    val scrollSate = rememberScrollState()
    Column(
        modifier =
            modifier
                .padding(horizontal = 24.dp)
    ) {

        ActionBarWithBackButton(onBack = {
            if (navController.isResume()) {
                navController.popBackStack()
            }
        })

        Column(
            modifier
                .weight(1f)
                .verticalScroll(scrollSate)
        ) {

            TextComponent(
                text = "HSBC",
                modifier = modifier.align(Alignment.CenterHorizontally),
                color = MaterialTheme.colorScheme.onSecondary,
                fontSize = 22.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_bold, FontWeight.W600)
                )
            )


            Image(
                painter = painterResource(R.drawable.img_hsbc_bank_logo),
                contentDescription = "",
                modifier = modifier
                    .padding(top = 16.dp)
                    .clip(CircleShape)
                    .size(80.dp)
                    .align(Alignment.CenterHorizontally)
            )

            TextComponent(
                text = "Bank Charges",
                color = MaterialTheme.colorScheme.surfaceBright,
                fontSize = 14.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_regular, FontWeight.W400)
                ),
                modifier = modifier
                    .padding(top = 16.dp)
                    .background(black2C2C2C, RoundedCornerShape(8.dp))
                    .padding(8.dp)
                    .align(Alignment.CenterHorizontally)
            )

            TextComponent(
                text = "Direct Debit",
                style = TextStyle(
                    color = MaterialTheme.colorScheme.surface,
                    fontSize = 16.sp,
                    textAlign = TextAlign.Center,
                    fontFamily = FontFamily(
                        Font(R.font.inter_semi_bold, FontWeight.Bold)
                    )
                ),
                modifier = modifier
                    .padding(top = 16.dp)
                    .align(Alignment.CenterHorizontally)
            )

            TextComponent(
                text = "Transaction ID: 89698615\n" +
                        "Date: 12 Feb 2024  Time: 20:45\n" +
                        "Reference: Mortgage",
                style = TextStyle(
                    lineHeight = 1.4.em,
                    color = grey_757575,
                    fontSize = 14.sp,
                    textAlign = TextAlign.Center,
                    fontFamily = FontFamily(
                        Font(R.font.inter_regular, FontWeight.W400)
                    )
                ),
                modifier = modifier
                    .padding(top = 2.dp)
                    .align(Alignment.CenterHorizontally)
            )

            TextComponent(
                text = "-£1,256.00",
                style = TextStyle(
                    color = red_C00F0C,
                    fontSize = 44.sp,
                    textAlign = TextAlign.Center,
                    fontFamily = FontFamily(
                        Font(R.font.inter_bold, FontWeight.W400)
                    )
                ),
                modifier = modifier
                    .padding(top = 16.dp)
                    .align(Alignment.CenterHorizontally)
            )

            Box(
                modifier = modifier
                    .padding(vertical = 16.dp)
                    .fillMaxWidth()
                    .height(250.dp)
                    .background(grey_F5F5F5, RoundedCornerShape(16.dp))
                    .padding(16.dp)
            ) {
                Column {

                    Column(modifier = modifier.weight(1f)) {
                        Row(verticalAlignment = Alignment.CenterVertically) {

                            TextComponent(
                                text = "Total spent last six months ",
                                fontFamily = FontFamily(
                                    Font(
                                        R.font.inter_regular,
                                        FontWeight.W400
                                    )
                                ),
                                fontSize = 14.sp,
                                color = grey_757575,
                                modifier = Modifier.weight(1f)
                            )

                            Box {
                                TextComponent(
                                    text = "Monthly",
                                    fontFamily = FontFamily(
                                        Font(
                                            R.font.inter_regular,
                                            FontWeight.W400
                                        )
                                    ),
                                    fontSize = 16.sp,
                                    color = black0A0E19,
                                    modifier = Modifier.clickable(onClick = {
                                        isExpandedDropdown = true
                                    })
                                )
                                DropdownMenu(
                                    modifier = modifier,
                                    expanded = isExpandedDropdown,
                                    onDismissRequest = {
                                        isExpandedDropdown = false
                                    }
                                ) {
                                    RowDropDown(item = "Month")
                                }
                            }


                            Icon(
                                tint = black0A0E19,
                                painter =
                                    painterResource(R.drawable.ic_down_arrow),
                                contentDescription = "",
                                modifier = modifier
                                    .padding(start = 2.dp)
                                    .size(12.dp)
                                    .padding(2.dp)
                            )
                        }

                        TextComponent(
                            text = "£11,779.99",
                            fontFamily = FontFamily(
                                Font(
                                    R.font.inter_semi_bold,
                                    FontWeight.W600
                                )
                            ),
                            fontSize = 24.sp,
                            color = black1E1E1E,
                            modifier = Modifier
                                .padding(top = 4.dp)
                                .weight(1f)
                        )
                    }
                    BarChart(
                        values = listOf(40f, 20f, 60f, 50f, 70f, 30f)
                    )
                }

            }

            RowMoreOptions(text = "Recur payment", icon = R.drawable.ic_repeat)
            RowMoreOptions(text = "Share PDF", icon = R.drawable.ic_recur_payment)
            RowMoreOptions(text = "Add attachment", icon = R.drawable.ic_attach)

            Row(
                verticalAlignment = Alignment.CenterVertically,
                modifier = modifier
                    .clickable(onClick = {})
                    .padding(vertical = 7.dp)
            ) {
                Icon(
                    tint = MaterialTheme.colorScheme.onSecondary,
                    painter = painterResource(R.drawable.ic_warning),
                    contentDescription = "",
                    modifier = modifier
                        .size(40.dp)
                )
                TextComponent(
                    text = "Need help with this transaction?",
                    style = TextStyle(
                        color = MaterialTheme.colorScheme.onSecondary,
                        fontSize = 16.sp,
                        textAlign = TextAlign.Start,
                        fontFamily = FontFamily(
                            Font(R.font.inter_regular, FontWeight.W400)
                        )
                    ),
                    modifier = Modifier
                        .padding(start = 7.dp)
                        .weight(1f)
                )

                Icon(
                    painter = painterResource(R.drawable.ic_down_arrow),
                    contentDescription = "",
                    modifier = Modifier.rotate(270f),
                    tint = MaterialTheme.colorScheme.onSecondary
                )

            }

        }
    }
}

@Composable
fun RowDropDown(
    modifier: Modifier = Modifier,
    item: String
) {
    TextComponent(
        text = item,
        fontFamily = FontFamily(
            Font(
                R.font.inter_regular,
                FontWeight.W400
            )
        ),
        fontSize = 14.sp,
        color = MaterialTheme.colorScheme.inverseOnSurface,
        modifier = modifier.padding(horizontal = 15.dp)
    )
}

@Composable
fun RowMoreOptions(
    modifier: Modifier = Modifier,
    text: String,
    icon: Int
) {

    Column {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = modifier
                .clickable(onClick = {})
                .padding(vertical = 7.dp)
        ) {
            Icon(
                tint = MaterialTheme.colorScheme.onSecondary,
                painter = painterResource(icon),
                contentDescription = "",
                modifier = modifier
                    .size(40.dp)
                    .padding(11.dp)
            )

            TextComponent(
                text = text,
                style = TextStyle(
                    color = MaterialTheme.colorScheme.onSecondary,
                    fontSize = 16.sp,
                    textAlign = TextAlign.Start,
                    fontFamily = FontFamily(
                        Font(R.font.inter_regular, FontWeight.W400)
                    )
                ),
                modifier = Modifier
                    .padding(start = 7.dp)
                    .weight(1f)
            )

            Icon(
                painter = painterResource(R.drawable.ic_down_arrow),
                contentDescription = "",
                modifier = Modifier.rotate(270f),
                tint = MaterialTheme.colorScheme.onSecondary
            )

        }

        HorizontalDividerComponent(modifier = modifier.padding(start = 50.dp))
    }

}