package com.ubsidifinance.ui.transfer

import android.annotation.SuppressLint
import androidx.compose.foundation.Image
import androidx.compose.foundation.background
import androidx.compose.foundation.border
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.imePadding
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.foundation.text.BasicTextField
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.clip
import androidx.compose.ui.draw.shadow
import androidx.compose.ui.graphics.SolidColor
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.fragment.app.FragmentActivity
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.navigation.NavController
import com.ubsidifinance.R
import com.ubsidifinance.biometric.BiometricHelper
import com.ubsidifinance.component.ActionBarWithBackButton
import com.ubsidifinance.component.ButtonComponent
import com.ubsidifinance.component.TextComponent
import com.ubsidifinance.component.TextFieldComponent
import com.ubsidifinance.model.state.TransferUiState
import com.ubsidifinance.navigation.PaymentSuccessOrFail
import com.ubsidifinance.navigation.TransferAmount
import com.ubsidifinance.ui.confirm_transfer.ConfirmTransferScreen
import com.ubsidifinance.ui.recipient_contact.RecipientContactDialog
import com.ubsidifinance.ui.theme.black232323
import com.ubsidifinance.ui.theme.blue316AFF
import com.ubsidifinance.ui.theme.greyB7BAC3
import com.ubsidifinance.ui.theme.grey_9499A5
import com.ubsidifinance.ui.theme.grey_B3B3B3
import com.ubsidifinance.ui.theme.grey_F9F9F9
import com.ubsidifinance.ui.theme.white
import com.ubsidifinance.utils.isResume
import com.ubsidifinance.utils.isValidateEmpty
import com.ubsidifinance.utils.toInitials
import kotlinx.coroutines.launch

@SuppressLint("ContextCastToActivity")
@Composable
fun TransferScreen(
    modifier: Modifier = Modifier,
    navController: NavController,
    viewmodel: TransferViewmodel = hiltViewModel()
) {
    val scrollSate = rememberScrollState()
    val scope = rememberCoroutineScope()
    val context = LocalContext.current as FragmentActivity
    val state = viewmodel.uiEvent.value
    var isShowDialog by remember { mutableStateOf(false) }
    var isShowConfirmDialog by remember { mutableStateOf(false) }

    if (isShowConfirmDialog) {
        ConfirmTransferScreen(
            onConfirmation = {
                BiometricHelper.showBiometricPrompt(context) { isUnlock ->
                    if (isUnlock) {
                        scope.launch {
                            if (navController.isResume()) {
                                navController.navigate(PaymentSuccessOrFail) {
                                    popUpTo(TransferAmount) {
                                        inclusive = true
                                    }
                                }
                            }
                        }
                    }
                }
            },
            onDismissRequest = {
                isShowConfirmDialog = false
            }
        )
    }

    if (isShowDialog) {
        RecipientContactDialog(
            onConfirmation = {
                viewmodel.onEvent(TransferUiState.OnAccountModelChange(it))
            },
            onDismissRequest = {
                isShowDialog = false
            }
        )
    }

    Column(
        modifier =
            modifier
                .imePadding()
                .padding(horizontal = 24.dp)
    ) {

        ActionBarWithBackButton(
            onBack = {
                if (navController.isResume()) {
                    navController.popBackStack()
                }
            },
            title = "Transfer"
        )

        Column(
            modifier
                .weight(1f)
                .fillMaxSize()
                .verticalScroll(scrollSate)
                .padding(vertical = 24.dp)
        ) {

            TextComponent(
                text = "Transfer amount",
                modifier = modifier.align(Alignment.CenterHorizontally),
                color = grey_9499A5,
                fontSize = 12.sp,
                fontFamily = FontFamily(
                    Font(R.font.inter_regular, FontWeight.W400)
                )
            )

            AmountTextField(text = state.amount) {
                if (it.length <= 5) {
                    viewmodel.onEvent(TransferUiState.OnAmountChange(it))
                }

            }

            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp)
                    .shadow(0.5.dp, RoundedCornerShape(20.dp))
                    .background(
                        MaterialTheme.colorScheme.primaryContainer,
                        RoundedCornerShape(20.dp)
                    )
                    .padding(20.dp)
            ) {
                TextComponent(
                    text = "Transfer amount",
                    modifier = modifier,
                    color = grey_9499A5,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W500)
                    )
                )

                Row(
                    modifier = modifier.padding(vertical = 12.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {

                    if (state.accountModel.fullName.isValidateEmpty()) {
                        TextComponent(
                            text = "Choose Recipient",
                            modifier = modifier.weight(1f),
                            color = MaterialTheme.colorScheme.inversePrimary,
                            fontSize = 14.sp,
                            fontFamily = FontFamily(
                                Font(R.font.inter_semi_bold, FontWeight.W600)
                            )
                        )

                        TextComponent(
                            text = "Select",
                            modifier = modifier
                                .padding(vertical = 8.dp)
                                .background(blue316AFF, RoundedCornerShape(10.dp))
                                .clip(RoundedCornerShape(10.dp))
                                .clickable(onClick = {
                                    isShowDialog = true
                                })
                                .padding(vertical = 5.dp, horizontal = 12.dp),
                            color = white,
                            fontSize = 14.sp,
                            fontFamily = FontFamily(
                                Font(R.font.inter_medium, FontWeight.W500)
                            )
                        )
                    } else {
                        TextComponent(
                            text = state.accountModel.fullName.toInitials(),
                            fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                            modifier = modifier
                                .background(grey_F9F9F9, CircleShape)
                                .padding(10.dp),
                            fontSize = 14.sp,
                            color = grey_9499A5
                        )

                        Column(
                            modifier = modifier
                                .padding(horizontal = 8.dp)
                                .weight(1f)
                        ) {
                            TextComponent(
                                text = state.accountModel.fullName,
                                fontFamily = FontFamily(
                                    Font(
                                        R.font.inter_semi_bold,
                                        FontWeight.W600
                                    )
                                ),
                                modifier = modifier,
                                fontSize = 14.sp,
                                color = MaterialTheme.colorScheme.inversePrimary
                            )

                            TextComponent(
                                text = "Sort Code: ${state.accountModel.sortCode} \nAccount Number: ${state.accountModel.accountNumber}",
                                fontFamily = FontFamily(Font(R.font.inter_medium, FontWeight.W600)),
                                modifier = modifier
                                    .padding(top = 6.dp),
                                fontSize = 12.sp,
                                color = grey_9499A5
                            )
                        }

                        TextComponent(
                            text = "Change",
                            modifier = modifier
                                .padding(vertical = 8.dp)
                                .border(1.dp, blue316AFF, RoundedCornerShape(10.dp))
                                .clip(RoundedCornerShape(10.dp))
                                .clickable(onClick = {
                                    isShowDialog = true
                                })
                                .padding(vertical = 5.dp, horizontal = 12.dp),
                            color = blue316AFF,
                            fontSize = 14.sp,
                            fontFamily = FontFamily(
                                Font(R.font.inter_medium, FontWeight.W500)
                            )
                        )
                    }

                }

                TextFieldComponent(
                    placeholder = "Reference",
                    modifier = modifier.padding(top = 12.dp),
                    value = "",
                    keyboardOptions = KeyboardOptions(imeAction = ImeAction.Done),
                    onValueChange = {

                    })
            }

            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp)
                    .shadow(0.5.dp, RoundedCornerShape(20.dp))
                    .background(
                        MaterialTheme.colorScheme.primaryContainer,
                        RoundedCornerShape(20.dp)
                    )
                    .padding(20.dp)
            ) {
                TextComponent(
                    text = "From",
                    modifier = modifier,
                    color = grey_9499A5,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W500)
                    )
                )

                Row(
                    modifier = modifier
                        .padding(top = 12.dp)
                        .background(
                            MaterialTheme.colorScheme.onPrimaryContainer,
                            RoundedCornerShape(12.dp)
                        )
                        .padding(10.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {

                    Image(
                        painter = painterResource(R.drawable.img_app_logo),
                        contentDescription = "",
                        modifier = modifier
                            .size(36.dp)
                            .background(blue316AFF, CircleShape)
                            .padding(2.dp)
                    )

                    Row(modifier = modifier.weight(1f)) {
                        Column {
                            TextComponent(
                                text = "Nibs Solutions Ltd",
                                modifier = modifier.padding(start = 16.dp),
                                color = MaterialTheme.colorScheme.inversePrimary,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_semi_bold, FontWeight.W600)
                                )
                            )

                            TextComponent(
                                text = "20-23-23",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )

                            TextComponent(
                                text = "24455423",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )
                        }
                    }

                    Row(verticalAlignment = Alignment.CenterVertically) {
                        Column {
                            TextComponent(
                                text = "Available",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )
                            TextComponent(
                                text = "£22,432",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = MaterialTheme.colorScheme.inversePrimary,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_bold, FontWeight.W700)
                                )
                            )
                        }

                        Icon(
                            painter = painterResource(R.drawable.ic_down_arrow),
                            contentDescription = null,
                            tint = grey_9499A5,
                            modifier = modifier
                                .padding(start = 10.dp)
                                .size(16.dp)
                                .padding(2.dp)
                                .align(Alignment.CenterVertically)
                        )
                    }

                }

            }

            Column(
                modifier = modifier
                    .fillMaxWidth()
                    .padding(top = 24.dp)
                    .shadow(0.5.dp, RoundedCornerShape(20.dp))
                    .background(
                        MaterialTheme.colorScheme.primaryContainer,
                        RoundedCornerShape(20.dp)
                    )
                    .padding(20.dp)
            ) {
                TextComponent(
                    text = "Date",
                    modifier = modifier,
                    color = grey_9499A5,
                    fontSize = 14.sp,
                    fontFamily = FontFamily(
                        Font(R.font.inter_medium, FontWeight.W500)
                    )
                )

                Row(
                    modifier = modifier
                        .padding(top = 12.dp)
                        .background(
                            MaterialTheme.colorScheme.onPrimaryContainer,
                            RoundedCornerShape(12.dp)
                        )
                        .padding(10.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {

                    Row(modifier = modifier.weight(1f)) {
                        Column {
                            TextComponent(
                                text = "Faster Payments",
                                modifier = modifier.padding(start = 16.dp),
                                color = MaterialTheme.colorScheme.inversePrimary,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_semi_bold, FontWeight.W600)
                                )
                            )

                            TextComponent(
                                text = "Today: 3 Feb 2024",
                                modifier = modifier.padding(start = 16.dp, top = 4.dp),
                                color = grey_9499A5,
                                fontSize = 12.sp,
                                fontFamily = FontFamily(
                                    Font(R.font.inter_regular, FontWeight.W400)
                                )
                            )

                        }
                    }

                    Icon(
                        painter = painterResource(R.drawable.ic_calendar),
                        contentDescription = null,
                        tint = black232323,
                        modifier = modifier
                            .padding(start = 10.dp)
                            .size(20.dp)
                            .padding(2.dp)
                            .align(Alignment.CenterVertically)
                    )

                    Icon(
                        painter = painterResource(R.drawable.ic_down_arrow),
                        contentDescription = null,
                        tint = grey_9499A5,
                        modifier = modifier
                            .padding(start = 10.dp)
                            .size(16.dp)
                            .padding(2.dp)
                            .align(Alignment.CenterVertically)
                    )
                }

            }


        }

        ButtonComponent(
            modifier = modifier.padding(bottom = 10.dp),
            text = "Continue",
            onClick = {
                isShowConfirmDialog = true
            }
        )
    }
}

@Composable
fun AmountTextField(
    modifier: Modifier = Modifier,
    text: String,
    onValueChange: (String) -> Unit
) {
    Row {
        Spacer(modifier.weight(0.4f))
        BasicTextField(
            cursorBrush = SolidColor(blue316AFF),
            textStyle = TextStyle(
                fontSize = 40.sp,
                textAlign = TextAlign.Start,
                color = MaterialTheme.colorScheme.inversePrimary,
                fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W700))
            ),
            maxLines = 1,
            singleLine = true,
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Decimal),
            modifier = Modifier
                .padding(top = 16.dp)
                .weight(0.5f),
            onValueChange = onValueChange,
            value = text,
            decorationBox = { innerTextField ->

                Row(verticalAlignment = Alignment.CenterVertically) {
                    TextComponent(
                        text = "£",
                        fontSize = 40.sp,
                        color = greyB7BAC3,
                        fontFamily = FontFamily(Font(R.font.inter_bold, FontWeight.W700))
                    )

                    Box(
                        modifier = Modifier
                            .weight(1F)
                            .padding(start = 4.dp)
                    ) {
                        if (text.isValidateEmpty()) {
                            TextComponent(
                                text = "00.00",
                                fontSize = 40.sp,
                                color = grey_B3B3B3,
                                fontFamily = FontFamily(
                                    Font(
                                        R.font.inter_medium,
                                        FontWeight.W600
                                    )
                                )
                            )
                        }
                        innerTextField()
                    }
                }
            }
        )
        Spacer(modifier.weight(0.2f))
    }
}