package com.ubsidifinance.utils

import android.util.Base64
import com.ubsidifinance.BuildConfig
import java.nio.charset.StandardCharsets
import java.security.Key
import java.security.MessageDigest
import javax.crypto.Cipher
import javax.crypto.spec.IvParameterSpec
import javax.crypto.spec.SecretKeySpec


class EasyAES @JvmOverloads constructor(key: String, bit: Int = 128, iv: String? = null) {

    private var key: Key? = null
    private var iv: IvParameterSpec? = null
    private var cipher: Cipher? = null

    init {
        if (bit == 256) {
            this.key = SecretKeySpec(key.toByteArray(StandardCharsets.UTF_8), ALGORITHM)
        } else {
            this.key = SecretKeySpec(key.toByteArray(StandardCharsets.UTF_8), ALGORITHM)
        }

        if (iv != null) {
            this.iv = IvParameterSpec(iv.toByteArray(StandardCharsets.UTF_8))
        } else {
            this.iv = DEFAULT_IV
        }

        init()
    }

    private fun init() {
        try {
            cipher = Cipher.getInstance(TRANSFORMATION)
        } catch (ex: Exception) {
            throw RuntimeException(ex.message)
        }
    }

    fun encrypt(str: String): String {
        try {
            return encrypt(str.toByteArray(charset("UTF-8")))
        } catch (ex: Exception) {
            throw RuntimeException(ex.message)
        }
    }

    fun encrypt(data: ByteArray): String {
        try {
            cipher!!.init(Cipher.ENCRYPT_MODE, key, iv)
            val encryptData = cipher!!.doFinal(data)
            return String(Base64.encode(encryptData, Base64.DEFAULT), charset("UTF-8"))
        } catch (ex: Exception) {
            throw RuntimeException(ex.message)
        }
    }

    fun decrypt(str: String?): String {
        try {
            return decrypt(Base64.decode(str, Base64.DEFAULT))
        } catch (ex: Exception) {
            throw RuntimeException(ex.message)
        }
    }

    fun decrypt(data: ByteArray): String {
        try {
            cipher!!.init(Cipher.DECRYPT_MODE, key, iv)
            val decryptData = cipher!!.doFinal(data)
            return String(decryptData, charset("UTF-8"))
        } catch (ex: Exception) {
            throw RuntimeException(ex.message)
        }
    }

    companion object {

        private val DEFAULT_IV =
            IvParameterSpec(byteArrayOf(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))

        private const val ALGORITHM = "AES"
        private const val TRANSFORMATION = "AES/CBC/PKCS5Padding"

        private fun getHash(algorithm: String, text: String): ByteArray {
            try {
                return getHash(algorithm, text.toByteArray(charset("UTF-8")))
            } catch (ex: Exception) {
                throw RuntimeException(ex.message)
            }
        }

        private fun getHash(algorithm: String, data: ByteArray): ByteArray {
            try {
                val digest = MessageDigest.getInstance(algorithm)
                digest.update(data)
                return digest.digest()
            } catch (ex: Exception) {
                throw RuntimeException(ex.message)
            }
        }

        fun encryptString(content: String): String {
            //Set password and iv string here
            val ea = EasyAES(BuildConfig.aes_key, 256, BuildConfig.aes_iv)
            return ea.encrypt(content)
        }

        fun decryptString(content: String?): String? {
            var result: String? = null
            try {
                //Set password and iv string here
                val ea = EasyAES(BuildConfig.aes_key, 256, BuildConfig.aes_iv)
                result = ea.decrypt(content)
            } catch (ex: Exception) {
                ex.printStackTrace()
            }
            return result
        }
    }
}