package com.ubsidifinance.utils

import android.content.Context
import android.net.Uri
import android.util.Log
import com.google.mlkit.vision.common.InputImage
import com.google.mlkit.vision.face.FaceDetection
import com.google.mlkit.vision.face.FaceDetectorOptions
import java.io.File

fun detectFaceInImage(imageFile: File, onResult: (Boolean) -> Unit = {}, context: Context) {
    val image = InputImage.fromFilePath(context, Uri.fromFile(imageFile))

    val detector = FaceDetection.getClient(
        FaceDetectorOptions.Builder()
            .setPerformanceMode(FaceDetectorOptions.PERFORMANCE_MODE_FAST)
            .build()
    )

    detector.process(image)
        .addOnSuccessListener { faces ->
            if (faces.isNotEmpty()) {
                Log.d("FaceCheck", "✅ Face detected!")
                onResult(true)
            } else {
                Log.d("FaceCheck", "❌ No face found.")
                onResult(false)
            }
        }
        .addOnFailureListener { e ->
            Log.e("FaceCheck", "Detection failed", e)
            onResult(false)
        }
}

