package com.ubsidifinance.utils

import android.content.Context
import android.content.SharedPreferences
import androidx.core.content.edit
import com.ubsidifinance.R
import com.ubsidifinance.model.UserModel
import kotlinx.serialization.json.Json

class Preferences(context: Context) {

    private val PREF_NAME = context.getString(R.string.app_name)
    private val IS_BOARDING = "is_boarding"
    private val LOGGED_IN_USER_MODEL = "LOGGED_IN_USER_MODEL"

    private val userPreferences: SharedPreferences? =
        context.getSharedPreferences(PREF_NAME, Context.MODE_PRIVATE)

    fun getToken(token: String?): String? {
        return userPreferences!!.getString(token, null)
    }

    val headerTokens: Map<String?, String?>
        get() {
            val xToken = getToken("x-token")
            val xRefreshToken = getToken("x-refresh-token")
            val map: MutableMap<String?, String?> = HashMap()
            if (xToken != null) map["x-token"] = xToken
            if (xRefreshToken != null) map["x-refresh-token"] = xRefreshToken
            return map
        }

    fun saveHeaderTokens(xToken: String?, rToken: String?) {
        userPreferences!!.edit {
            putString("x-token", xToken)
            putString("x-refresh-token", rToken)
        }
    }

    var isBoardingScreen: Boolean
        get() = userPreferences!!.getBoolean(IS_BOARDING, true)
        set(value) = userPreferences!!.edit { putBoolean(IS_BOARDING, value) }

    var loginUserModel: UserModel?
        get() {
            val jsonModel = userPreferences?.getString(LOGGED_IN_USER_MODEL, null)
            return jsonModel?.let {
                try {
                    Json.decodeFromString<UserModel>(it)
                } catch (e: Exception) {
                    e.printStackTrace()
                    null
                }
            }
        }
        set(value) {
            val json = if (value != null) Json.encodeToString(value) else null
            userPreferences?.edit {
                putString(LOGGED_IN_USER_MODEL, json)
            }
        }

}